/* This file is auto-generated by opth-gen.awk.  */

#ifndef OPTIONS_H
#define OPTIONS_H

#include "flag-types.h"

#include "config/mips/mips-opts.h"

#if !defined(IN_LIBGCC2) && !defined(IN_TARGET_LIBS) && !defined(IN_RTS)
#ifndef GENERATOR_FILE
#if !defined(IN_LIBGCC2) && !defined(IN_TARGET_LIBS)
struct GTY(()) gcc_options
#else
struct gcc_options
#endif
{
#endif
#ifdef GENERATOR_FILE
extern HOST_WIDE_INT frame_larger_than_size;
#else
  HOST_WIDE_INT x_frame_larger_than_size;
#define frame_larger_than_size global_options.x_frame_larger_than_size
#endif
#ifdef GENERATOR_FILE
extern HOST_WIDE_INT function_entry_patch_area_size;
#else
  HOST_WIDE_INT x_function_entry_patch_area_size;
#define function_entry_patch_area_size global_options.x_function_entry_patch_area_size
#endif
#ifdef GENERATOR_FILE
extern HOST_WIDE_INT function_entry_patch_area_start;
#else
  HOST_WIDE_INT x_function_entry_patch_area_start;
#define function_entry_patch_area_start global_options.x_function_entry_patch_area_start
#endif
#ifdef GENERATOR_FILE
extern HOST_WIDE_INT larger_than_size;
#else
  HOST_WIDE_INT x_larger_than_size;
#define larger_than_size global_options.x_larger_than_size
#endif
#ifdef GENERATOR_FILE
extern bool dump_base_name_prefixed;
#else
  bool x_dump_base_name_prefixed;
#define dump_base_name_prefixed global_options.x_dump_base_name_prefixed
#endif
#ifdef GENERATOR_FILE
extern bool exit_after_options;
#else
  bool x_exit_after_options;
#define exit_after_options global_options.x_exit_after_options
#endif
#ifdef GENERATOR_FILE
extern bool flag_disable_hsa;
#else
  bool x_flag_disable_hsa;
#define flag_disable_hsa global_options.x_flag_disable_hsa
#endif
#ifdef GENERATOR_FILE
extern bool flag_dump_all_passed;
#else
  bool x_flag_dump_all_passed;
#define flag_dump_all_passed global_options.x_flag_dump_all_passed
#endif
#ifdef GENERATOR_FILE
extern bool flag_opts_finished;
#else
  bool x_flag_opts_finished;
#define flag_opts_finished global_options.x_flag_opts_finished
#endif
#ifdef GENERATOR_FILE
extern bool flag_stack_usage_info;
#else
  bool x_flag_stack_usage_info;
#define flag_stack_usage_info global_options.x_flag_stack_usage_info
#endif
#ifdef GENERATOR_FILE
extern bool flag_warn_unused_result;
#else
  bool x_flag_warn_unused_result;
#define flag_warn_unused_result global_options.x_flag_warn_unused_result
#endif
#ifdef GENERATOR_FILE
extern bool in_lto_p;
#else
  bool x_in_lto_p;
#define in_lto_p global_options.x_in_lto_p
#endif
#ifdef GENERATOR_FILE
extern bool use_gnu_debug_info_extensions;
#else
  bool x_use_gnu_debug_info_extensions;
#define use_gnu_debug_info_extensions global_options.x_use_gnu_debug_info_extensions
#endif
#ifdef GENERATOR_FILE
extern bool warn_frame_larger_than;
#else
  bool x_warn_frame_larger_than;
#define warn_frame_larger_than global_options.x_warn_frame_larger_than
#endif
#ifdef GENERATOR_FILE
extern bool warn_larger_than;
#else
  bool x_warn_larger_than;
#define warn_larger_than global_options.x_warn_larger_than
#endif
#ifdef GENERATOR_FILE
extern char *help_enum_printed;
#else
  char * x_help_enum_printed;
#define help_enum_printed global_options.x_help_enum_printed
#endif
#ifdef GENERATOR_FILE
extern char *help_printed;
#else
  char * x_help_printed;
#define help_printed global_options.x_help_printed
#endif
#ifdef GENERATOR_FILE
extern const char *main_input_basename;
#else
  const char * x_main_input_basename;
#define main_input_basename global_options.x_main_input_basename
#endif
#ifdef GENERATOR_FILE
extern const char *main_input_filename;
#else
  const char * x_main_input_filename;
#define main_input_filename global_options.x_main_input_filename
#endif
#ifdef GENERATOR_FILE
extern enum debug_info_levels debug_info_level;
#else
  enum debug_info_levels x_debug_info_level;
#define debug_info_level global_options.x_debug_info_level
#endif
#ifdef GENERATOR_FILE
extern enum debug_info_type write_symbols;
#else
  enum debug_info_type x_write_symbols;
#define write_symbols global_options.x_write_symbols
#endif
#ifdef GENERATOR_FILE
extern enum debug_struct_file debug_struct_generic[DINFO_USAGE_NUM_ENUMS];
#else
  enum debug_struct_file x_debug_struct_generic[DINFO_USAGE_NUM_ENUMS];
#define debug_struct_generic global_options.x_debug_struct_generic
#endif
#ifdef GENERATOR_FILE
extern enum debug_struct_file debug_struct_ordinary[DINFO_USAGE_NUM_ENUMS];
#else
  enum debug_struct_file x_debug_struct_ordinary[DINFO_USAGE_NUM_ENUMS];
#define debug_struct_ordinary global_options.x_debug_struct_ordinary
#endif
#ifdef GENERATOR_FILE
extern enum dwarf_gnat_encodings gnat_encodings;
#else
  enum dwarf_gnat_encodings x_gnat_encodings;
#define gnat_encodings global_options.x_gnat_encodings
#endif
#ifdef GENERATOR_FILE
extern enum stack_check_type flag_stack_check;
#else
  enum stack_check_type x_flag_stack_check;
#define flag_stack_check global_options.x_flag_stack_check
#endif
#ifdef GENERATOR_FILE
extern int *param_values;
#else
  int * x_param_values;
#define param_values global_options.x_param_values
#endif
#ifdef GENERATOR_FILE
extern int flag_complex_method;
#else
  int x_flag_complex_method;
#define flag_complex_method global_options.x_flag_complex_method
#endif
#ifdef GENERATOR_FILE
extern int flag_debug_asm;
#else
  int x_flag_debug_asm;
#define flag_debug_asm global_options.x_flag_debug_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_rtl_in_asm;
#else
  int x_flag_dump_rtl_in_asm;
#define flag_dump_rtl_in_asm global_options.x_flag_dump_rtl_in_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_gen_aux_info;
#else
  int x_flag_gen_aux_info;
#define flag_gen_aux_info global_options.x_flag_gen_aux_info
#endif
#ifdef GENERATOR_FILE
extern int flag_generate_lto;
#else
  int x_flag_generate_lto;
#define flag_generate_lto global_options.x_flag_generate_lto
#endif
#ifdef GENERATOR_FILE
extern int flag_generate_offload;
#else
  int x_flag_generate_offload;
#define flag_generate_offload global_options.x_flag_generate_offload
#endif
#ifdef GENERATOR_FILE
extern int flag_incremental_link;
#else
  int x_flag_incremental_link;
#define flag_incremental_link global_options.x_flag_incremental_link
#endif
#ifdef GENERATOR_FILE
extern int flag_print_asm_name;
#else
  int x_flag_print_asm_name;
#define flag_print_asm_name global_options.x_flag_print_asm_name
#endif
#ifdef GENERATOR_FILE
extern int flag_shlib;
#else
  int x_flag_shlib;
#define flag_shlib global_options.x_flag_shlib
#endif
#ifdef GENERATOR_FILE
extern int main_input_baselength;
#else
  int x_main_input_baselength;
#define main_input_baselength global_options.x_main_input_baselength
#endif
#ifdef GENERATOR_FILE
extern int optimize;
#else
  int x_optimize;
#define optimize global_options.x_optimize
#endif
#ifdef GENERATOR_FILE
extern int optimize_debug;
#else
  int x_optimize_debug;
#define optimize_debug global_options.x_optimize_debug
#endif
#ifdef GENERATOR_FILE
extern int optimize_fast;
#else
  int x_optimize_fast;
#define optimize_fast global_options.x_optimize_fast
#endif
#ifdef GENERATOR_FILE
extern int optimize_size;
#else
  int x_optimize_size;
#define optimize_size global_options.x_optimize_size
#endif
#ifdef GENERATOR_FILE
extern int rtl_dump_and_exit;
#else
  int x_rtl_dump_and_exit;
#define rtl_dump_and_exit global_options.x_rtl_dump_and_exit
#endif
#ifdef GENERATOR_FILE
extern int target_flags;
#else
  int x_target_flags;
#define target_flags global_options.x_target_flags
#endif
#ifdef GENERATOR_FILE
extern unsigned int flag_sanitize;
#else
  unsigned int x_flag_sanitize;
#define flag_sanitize global_options.x_flag_sanitize
#endif
#ifdef GENERATOR_FILE
extern unsigned int flag_sanitize_coverage;
#else
  unsigned int x_flag_sanitize_coverage;
#define flag_sanitize_coverage global_options.x_flag_sanitize_coverage
#endif
#ifdef GENERATOR_FILE
extern unsigned int flag_sanitize_recover;
#else
  unsigned int x_flag_sanitize_recover;
#define flag_sanitize_recover global_options.x_flag_sanitize_recover
#endif
#ifdef GENERATOR_FILE
extern unsigned int help_columns;
#else
  unsigned int x_help_columns;
#define help_columns global_options.x_help_columns
#endif
#ifdef GENERATOR_FILE
extern unsigned int initial_max_fld_align;
#else
  unsigned int x_initial_max_fld_align;
#define initial_max_fld_align global_options.x_initial_max_fld_align
#endif
#ifdef GENERATOR_FILE
extern void *flag_instrument_functions_exclude_files;
#else
  void * x_flag_instrument_functions_exclude_files;
#define flag_instrument_functions_exclude_files global_options.x_flag_instrument_functions_exclude_files
#endif
#ifdef GENERATOR_FILE
extern void *flag_instrument_functions_exclude_functions;
#else
  void * x_flag_instrument_functions_exclude_functions;
#define flag_instrument_functions_exclude_functions global_options.x_flag_instrument_functions_exclude_functions
#endif
#ifdef GENERATOR_FILE
extern int help_flag;
#else
  int x_help_flag;
#define help_flag global_options.x_help_flag
#endif
#ifdef GENERATOR_FILE
extern int no_sysroot_suffix;
#else
  int x_no_sysroot_suffix;
#define no_sysroot_suffix global_options.x_no_sysroot_suffix
#endif
#ifdef GENERATOR_FILE
extern int flag_preprocess_only;
#else
  int x_flag_preprocess_only;
#define flag_preprocess_only global_options.x_flag_preprocess_only
#endif
#ifdef GENERATOR_FILE
extern int g_switch_value;
#else
  int x_g_switch_value;
#define g_switch_value global_options.x_g_switch_value
#endif
#ifdef GENERATOR_FILE
extern int warn_abi;
#else
  int x_warn_abi;
#define warn_abi global_options.x_warn_abi
#endif
#ifdef GENERATOR_FILE
extern int warn_abi_tag;
#else
  int x_warn_abi_tag;
#define warn_abi_tag global_options.x_warn_abi_tag
#endif
#ifdef GENERATOR_FILE
extern int warn_address;
#else
  int x_warn_address;
#define warn_address global_options.x_warn_address
#endif
#ifdef GENERATOR_FILE
extern int warn_aggregate_return;
#else
  int x_warn_aggregate_return;
#define warn_aggregate_return global_options.x_warn_aggregate_return
#endif
#ifdef GENERATOR_FILE
extern int warn_aggressive_loop_optimizations;
#else
  int x_warn_aggressive_loop_optimizations;
#define warn_aggressive_loop_optimizations global_options.x_warn_aggressive_loop_optimizations
#endif
#ifdef GENERATOR_FILE
extern int warn_aliasing;
#else
  int x_warn_aliasing;
#define warn_aliasing global_options.x_warn_aliasing
#endif
#ifdef GENERATOR_FILE
extern int warn_align_commons;
#else
  int x_warn_align_commons;
#define warn_align_commons global_options.x_warn_align_commons
#endif
#ifdef GENERATOR_FILE
extern int warn_aligned_new;
#else
  int x_warn_aligned_new;
#define warn_aligned_new global_options.x_warn_aligned_new
#endif
#ifdef GENERATOR_FILE
extern const char *warn_alloc_size_limit;
#else
  const char *x_warn_alloc_size_limit;
#define warn_alloc_size_limit global_options.x_warn_alloc_size_limit
#endif
#ifdef GENERATOR_FILE
extern int warn_alloc_zero;
#else
  int x_warn_alloc_zero;
#define warn_alloc_zero global_options.x_warn_alloc_zero
#endif
#ifdef GENERATOR_FILE
extern int warn_alloca;
#else
  int x_warn_alloca;
#define warn_alloca global_options.x_warn_alloca
#endif
#ifdef GENERATOR_FILE
extern int warn_alloca_limit;
#else
  int x_warn_alloca_limit;
#define warn_alloca_limit global_options.x_warn_alloca_limit
#endif
#ifdef GENERATOR_FILE
extern int warn_ampersand;
#else
  int x_warn_ampersand;
#define warn_ampersand global_options.x_warn_ampersand
#endif
#ifdef GENERATOR_FILE
extern int warn_argument_mismatch;
#else
  int x_warn_argument_mismatch;
#define warn_argument_mismatch global_options.x_warn_argument_mismatch
#endif
#ifdef GENERATOR_FILE
extern int warn_array_bounds;
#else
  int x_warn_array_bounds;
#define warn_array_bounds global_options.x_warn_array_bounds
#endif
#ifdef GENERATOR_FILE
extern int warn_array_temporaries;
#else
  int x_warn_array_temporaries;
#define warn_array_temporaries global_options.x_warn_array_temporaries
#endif
#ifdef GENERATOR_FILE
extern int warn_assign_intercept;
#else
  int x_warn_assign_intercept;
#define warn_assign_intercept global_options.x_warn_assign_intercept
#endif
#ifdef GENERATOR_FILE
extern int warn_attributes;
#else
  int x_warn_attributes;
#define warn_attributes global_options.x_warn_attributes
#endif
#ifdef GENERATOR_FILE
extern int warn_bad_function_cast;
#else
  int x_warn_bad_function_cast;
#define warn_bad_function_cast global_options.x_warn_bad_function_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_bool_compare;
#else
  int x_warn_bool_compare;
#define warn_bool_compare global_options.x_warn_bool_compare
#endif
#ifdef GENERATOR_FILE
extern int warn_bool_op;
#else
  int x_warn_bool_op;
#define warn_bool_op global_options.x_warn_bool_op
#endif
#ifdef GENERATOR_FILE
extern int warn_builtin_declaraion_mismatch;
#else
  int x_warn_builtin_declaraion_mismatch;
#define warn_builtin_declaraion_mismatch global_options.x_warn_builtin_declaraion_mismatch
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_builtin_macro_redefined;
#else
  int x_cpp_warn_builtin_macro_redefined;
#define cpp_warn_builtin_macro_redefined global_options.x_cpp_warn_builtin_macro_redefined
#endif
#ifdef GENERATOR_FILE
extern int warn_cxx_compat;
#else
  int x_warn_cxx_compat;
#define warn_cxx_compat global_options.x_warn_cxx_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_cxx11_compat;
#else
  int x_warn_cxx11_compat;
#define warn_cxx11_compat global_options.x_warn_cxx11_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_cxx14_compat;
#else
  int x_warn_cxx14_compat;
#define warn_cxx14_compat global_options.x_warn_cxx14_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_cxx17_compat;
#else
  int x_warn_cxx17_compat;
#define warn_cxx17_compat global_options.x_warn_cxx17_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_c_binding_type;
#else
  int x_warn_c_binding_type;
#define warn_c_binding_type global_options.x_warn_c_binding_type
#endif
#ifdef GENERATOR_FILE
extern int warn_c90_c99_compat;
#else
  int x_warn_c90_c99_compat;
#define warn_c90_c99_compat global_options.x_warn_c90_c99_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_c99_c11_compat;
#else
  int x_warn_c99_c11_compat;
#define warn_c99_c11_compat global_options.x_warn_c99_c11_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_cast_align;
#else
  int x_warn_cast_align;
#define warn_cast_align global_options.x_warn_cast_align
#endif
#ifdef GENERATOR_FILE
extern int warn_cast_function_type;
#else
  int x_warn_cast_function_type;
#define warn_cast_function_type global_options.x_warn_cast_function_type
#endif
#ifdef GENERATOR_FILE
extern int warn_cast_qual;
#else
  int x_warn_cast_qual;
#define warn_cast_qual global_options.x_warn_cast_qual
#endif
#ifdef GENERATOR_FILE
extern int warn_catch_value;
#else
  int x_warn_catch_value;
#define warn_catch_value global_options.x_warn_catch_value
#endif
#ifdef GENERATOR_FILE
extern int warn_char_subscripts;
#else
  int x_warn_char_subscripts;
#define warn_char_subscripts global_options.x_warn_char_subscripts
#endif
#ifdef GENERATOR_FILE
extern int warn_character_truncation;
#else
  int x_warn_character_truncation;
#define warn_character_truncation global_options.x_warn_character_truncation
#endif
#ifdef GENERATOR_FILE
extern int warn_chkp;
#else
  int x_warn_chkp;
#define warn_chkp global_options.x_warn_chkp
#endif
#ifdef GENERATOR_FILE
extern int warn_class_memaccess;
#else
  int x_warn_class_memaccess;
#define warn_class_memaccess global_options.x_warn_class_memaccess
#endif
#ifdef GENERATOR_FILE
extern int warn_clobbered;
#else
  int x_warn_clobbered;
#define warn_clobbered global_options.x_warn_clobbered
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_comment;
#else
  int x_cpp_warn_comment;
#define cpp_warn_comment global_options.x_cpp_warn_comment
#endif
#ifdef GENERATOR_FILE
extern int warn_compare_reals;
#else
  int x_warn_compare_reals;
#define warn_compare_reals global_options.x_warn_compare_reals
#endif
#ifdef GENERATOR_FILE
extern int warn_conditionally_supported;
#else
  int x_warn_conditionally_supported;
#define warn_conditionally_supported global_options.x_warn_conditionally_supported
#endif
#ifdef GENERATOR_FILE
extern int warn_conversion;
#else
  int x_warn_conversion;
#define warn_conversion global_options.x_warn_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_conversion_extra;
#else
  int x_warn_conversion_extra;
#define warn_conversion_extra global_options.x_warn_conversion_extra
#endif
#ifdef GENERATOR_FILE
extern int warn_conversion_null;
#else
  int x_warn_conversion_null;
#define warn_conversion_null global_options.x_warn_conversion_null
#endif
#ifdef GENERATOR_FILE
extern int warn_coverage_mismatch;
#else
  int x_warn_coverage_mismatch;
#define warn_coverage_mismatch global_options.x_warn_coverage_mismatch
#endif
#ifdef GENERATOR_FILE
extern int warn_cpp;
#else
  int x_warn_cpp;
#define warn_cpp global_options.x_warn_cpp
#endif
#ifdef GENERATOR_FILE
extern int warn_ctor_dtor_privacy;
#else
  int x_warn_ctor_dtor_privacy;
#define warn_ctor_dtor_privacy global_options.x_warn_ctor_dtor_privacy
#endif
#ifdef GENERATOR_FILE
extern int warn_dangling_else;
#else
  int x_warn_dangling_else;
#define warn_dangling_else global_options.x_warn_dangling_else
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_date_time;
#else
  int x_cpp_warn_date_time;
#define cpp_warn_date_time global_options.x_cpp_warn_date_time
#endif
#ifdef GENERATOR_FILE
extern int warn_declaration_after_statement;
#else
  int x_warn_declaration_after_statement;
#define warn_declaration_after_statement global_options.x_warn_declaration_after_statement
#endif
#ifdef GENERATOR_FILE
extern int warn_delete_incomplete;
#else
  int x_warn_delete_incomplete;
#define warn_delete_incomplete global_options.x_warn_delete_incomplete
#endif
#ifdef GENERATOR_FILE
extern int warn_delnonvdtor;
#else
  int x_warn_delnonvdtor;
#define warn_delnonvdtor global_options.x_warn_delnonvdtor
#endif
#ifdef GENERATOR_FILE
extern int warn_deprecated;
#else
  int x_warn_deprecated;
#define warn_deprecated global_options.x_warn_deprecated
#endif
#ifdef GENERATOR_FILE
extern int warn_deprecated_decl;
#else
  int x_warn_deprecated_decl;
#define warn_deprecated_decl global_options.x_warn_deprecated_decl
#endif
#ifdef GENERATOR_FILE
extern int warn_designated_init;
#else
  int x_warn_designated_init;
#define warn_designated_init global_options.x_warn_designated_init
#endif
#ifdef GENERATOR_FILE
extern int warn_disabled_optimization;
#else
  int x_warn_disabled_optimization;
#define warn_disabled_optimization global_options.x_warn_disabled_optimization
#endif
#ifdef GENERATOR_FILE
extern int warn_discarded_array_qualifiers;
#else
  int x_warn_discarded_array_qualifiers;
#define warn_discarded_array_qualifiers global_options.x_warn_discarded_array_qualifiers
#endif
#ifdef GENERATOR_FILE
extern int warn_discarded_qualifiers;
#else
  int x_warn_discarded_qualifiers;
#define warn_discarded_qualifiers global_options.x_warn_discarded_qualifiers
#endif
#ifdef GENERATOR_FILE
extern int warn_div_by_zero;
#else
  int x_warn_div_by_zero;
#define warn_div_by_zero global_options.x_warn_div_by_zero
#endif
#ifdef GENERATOR_FILE
extern int warn_do_subscript;
#else
  int x_warn_do_subscript;
#define warn_do_subscript global_options.x_warn_do_subscript
#endif
#ifdef GENERATOR_FILE
extern int warn_double_promotion;
#else
  int x_warn_double_promotion;
#define warn_double_promotion global_options.x_warn_double_promotion
#endif
#ifdef GENERATOR_FILE
extern int warn_duplicate_decl_specifier;
#else
  int x_warn_duplicate_decl_specifier;
#define warn_duplicate_decl_specifier global_options.x_warn_duplicate_decl_specifier
#endif
#ifdef GENERATOR_FILE
extern int warn_duplicated_branches;
#else
  int x_warn_duplicated_branches;
#define warn_duplicated_branches global_options.x_warn_duplicated_branches
#endif
#ifdef GENERATOR_FILE
extern int warn_duplicated_cond;
#else
  int x_warn_duplicated_cond;
#define warn_duplicated_cond global_options.x_warn_duplicated_cond
#endif
#ifdef GENERATOR_FILE
extern int warn_ecpp;
#else
  int x_warn_ecpp;
#define warn_ecpp global_options.x_warn_ecpp
#endif
#ifdef GENERATOR_FILE
extern int warn_empty_body;
#else
  int x_warn_empty_body;
#define warn_empty_body global_options.x_warn_empty_body
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_endif_labels;
#else
  int x_cpp_warn_endif_labels;
#define cpp_warn_endif_labels global_options.x_cpp_warn_endif_labels
#endif
#ifdef GENERATOR_FILE
extern int warn_enum_compare;
#else
  int x_warn_enum_compare;
#define warn_enum_compare global_options.x_warn_enum_compare
#endif
#ifdef GENERATOR_FILE
extern int warnings_are_errors;
#else
  int x_warnings_are_errors;
#define warnings_are_errors global_options.x_warnings_are_errors
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_expansion_to_defined;
#else
  int x_cpp_warn_expansion_to_defined;
#define cpp_warn_expansion_to_defined global_options.x_cpp_warn_expansion_to_defined
#endif
#ifdef GENERATOR_FILE
extern int extra_warnings;
#else
  int x_extra_warnings;
#define extra_warnings global_options.x_extra_warnings
#endif
#ifdef GENERATOR_FILE
extern int warn_extra_semi;
#else
  int x_warn_extra_semi;
#define warn_extra_semi global_options.x_warn_extra_semi
#endif
#ifdef GENERATOR_FILE
extern int flag_fatal_errors;
#else
  int x_flag_fatal_errors;
#define flag_fatal_errors global_options.x_flag_fatal_errors
#endif
#ifdef GENERATOR_FILE
extern int warn_float_conversion;
#else
  int x_warn_float_conversion;
#define warn_float_conversion global_options.x_warn_float_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_float_equal;
#else
  int x_warn_float_equal;
#define warn_float_equal global_options.x_warn_float_equal
#endif
#ifdef GENERATOR_FILE
extern int warn_format_contains_nul;
#else
  int x_warn_format_contains_nul;
#define warn_format_contains_nul global_options.x_warn_format_contains_nul
#endif
#ifdef GENERATOR_FILE
extern int warn_format_extra_args;
#else
  int x_warn_format_extra_args;
#define warn_format_extra_args global_options.x_warn_format_extra_args
#endif
#ifdef GENERATOR_FILE
extern int warn_format_nonliteral;
#else
  int x_warn_format_nonliteral;
#define warn_format_nonliteral global_options.x_warn_format_nonliteral
#endif
#ifdef GENERATOR_FILE
extern int warn_format_overflow;
#else
  int x_warn_format_overflow;
#define warn_format_overflow global_options.x_warn_format_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_format_security;
#else
  int x_warn_format_security;
#define warn_format_security global_options.x_warn_format_security
#endif
#ifdef GENERATOR_FILE
extern int warn_format_signedness;
#else
  int x_warn_format_signedness;
#define warn_format_signedness global_options.x_warn_format_signedness
#endif
#ifdef GENERATOR_FILE
extern int warn_format_trunc;
#else
  int x_warn_format_trunc;
#define warn_format_trunc global_options.x_warn_format_trunc
#endif
#ifdef GENERATOR_FILE
extern int warn_format_y2k;
#else
  int x_warn_format_y2k;
#define warn_format_y2k global_options.x_warn_format_y2k
#endif
#ifdef GENERATOR_FILE
extern int warn_format_zero_length;
#else
  int x_warn_format_zero_length;
#define warn_format_zero_length global_options.x_warn_format_zero_length
#endif
#ifdef GENERATOR_FILE
extern int warn_format;
#else
  int x_warn_format;
#define warn_format global_options.x_warn_format
#endif
#ifdef GENERATOR_FILE
extern int warn_frame_address;
#else
  int x_warn_frame_address;
#define warn_frame_address global_options.x_warn_frame_address
#endif
#ifdef GENERATOR_FILE
extern int warn_free_nonheap_object;
#else
  int x_warn_free_nonheap_object;
#define warn_free_nonheap_object global_options.x_warn_free_nonheap_object
#endif
#ifdef GENERATOR_FILE
extern int flag_warn_frontend_loop_interchange;
#else
  int x_flag_warn_frontend_loop_interchange;
#define flag_warn_frontend_loop_interchange global_options.x_flag_warn_frontend_loop_interchange
#endif
#ifdef GENERATOR_FILE
extern int warn_function_elimination;
#else
  int x_warn_function_elimination;
#define warn_function_elimination global_options.x_warn_function_elimination
#endif
#ifdef GENERATOR_FILE
extern int warn_hsa;
#else
  int x_warn_hsa;
#define warn_hsa global_options.x_warn_hsa
#endif
#ifdef GENERATOR_FILE
extern int warn_if_not_aligned;
#else
  int x_warn_if_not_aligned;
#define warn_if_not_aligned global_options.x_warn_if_not_aligned
#endif
#ifdef GENERATOR_FILE
extern int warn_ignored_attributes;
#else
  int x_warn_ignored_attributes;
#define warn_ignored_attributes global_options.x_warn_ignored_attributes
#endif
#ifdef GENERATOR_FILE
extern int warn_ignored_qualifiers;
#else
  int x_warn_ignored_qualifiers;
#define warn_ignored_qualifiers global_options.x_warn_ignored_qualifiers
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit;
#else
  int x_warn_implicit;
#define warn_implicit global_options.x_warn_implicit
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit_fallthrough;
#else
  int x_warn_implicit_fallthrough;
#define warn_implicit_fallthrough global_options.x_warn_implicit_fallthrough
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit_function_declaration;
#else
  int x_warn_implicit_function_declaration;
#define warn_implicit_function_declaration global_options.x_warn_implicit_function_declaration
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit_int;
#else
  int x_warn_implicit_int;
#define warn_implicit_int global_options.x_warn_implicit_int
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit_interface;
#else
  int x_warn_implicit_interface;
#define warn_implicit_interface global_options.x_warn_implicit_interface
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit_procedure;
#else
  int x_warn_implicit_procedure;
#define warn_implicit_procedure global_options.x_warn_implicit_procedure
#endif
#ifdef GENERATOR_FILE
extern int warn_incompatible_pointer_types;
#else
  int x_warn_incompatible_pointer_types;
#define warn_incompatible_pointer_types global_options.x_warn_incompatible_pointer_types
#endif
#ifdef GENERATOR_FILE
extern int warn_inh_var_ctor;
#else
  int x_warn_inh_var_ctor;
#define warn_inh_var_ctor global_options.x_warn_inh_var_ctor
#endif
#ifdef GENERATOR_FILE
extern int warn_init_self;
#else
  int x_warn_init_self;
#define warn_init_self global_options.x_warn_init_self
#endif
#ifdef GENERATOR_FILE
extern int warn_inline;
#else
  int x_warn_inline;
#define warn_inline global_options.x_warn_inline
#endif
#ifdef GENERATOR_FILE
extern int warn_int_conversion;
#else
  int x_warn_int_conversion;
#define warn_int_conversion global_options.x_warn_int_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_int_in_bool_context;
#else
  int x_warn_int_in_bool_context;
#define warn_int_in_bool_context global_options.x_warn_int_in_bool_context
#endif
#ifdef GENERATOR_FILE
extern int warn_int_to_pointer_cast;
#else
  int x_warn_int_to_pointer_cast;
#define warn_int_to_pointer_cast global_options.x_warn_int_to_pointer_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_integer_division;
#else
  int x_warn_integer_division;
#define warn_integer_division global_options.x_warn_integer_division
#endif
#ifdef GENERATOR_FILE
extern int warn_intrinsic_shadow;
#else
  int x_warn_intrinsic_shadow;
#define warn_intrinsic_shadow global_options.x_warn_intrinsic_shadow
#endif
#ifdef GENERATOR_FILE
extern int warn_intrinsics_std;
#else
  int x_warn_intrinsics_std;
#define warn_intrinsics_std global_options.x_warn_intrinsics_std
#endif
#ifdef GENERATOR_FILE
extern int warn_invalid_memory_model;
#else
  int x_warn_invalid_memory_model;
#define warn_invalid_memory_model global_options.x_warn_invalid_memory_model
#endif
#ifdef GENERATOR_FILE
extern int warn_invalid_offsetof;
#else
  int x_warn_invalid_offsetof;
#define warn_invalid_offsetof global_options.x_warn_invalid_offsetof
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_invalid_pch;
#else
  int x_cpp_warn_invalid_pch;
#define cpp_warn_invalid_pch global_options.x_cpp_warn_invalid_pch
#endif
#ifdef GENERATOR_FILE
extern int warn_jump_misses_init;
#else
  int x_warn_jump_misses_init;
#define warn_jump_misses_init global_options.x_warn_jump_misses_init
#endif
#ifdef GENERATOR_FILE
extern int warn_line_truncation;
#else
  int x_warn_line_truncation;
#define warn_line_truncation global_options.x_warn_line_truncation
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_literal_suffix;
#else
  int x_cpp_warn_literal_suffix;
#define cpp_warn_literal_suffix global_options.x_cpp_warn_literal_suffix
#endif
#ifdef GENERATOR_FILE
extern int warn_logical_not_paren;
#else
  int x_warn_logical_not_paren;
#define warn_logical_not_paren global_options.x_warn_logical_not_paren
#endif
#ifdef GENERATOR_FILE
extern int warn_logical_op;
#else
  int x_warn_logical_op;
#define warn_logical_op global_options.x_warn_logical_op
#endif
#ifdef GENERATOR_FILE
extern int warn_long_long;
#else
  int x_warn_long_long;
#define warn_long_long global_options.x_warn_long_long
#endif
#ifdef GENERATOR_FILE
extern int warn_lto_type_mismatch;
#else
  int x_warn_lto_type_mismatch;
#define warn_lto_type_mismatch global_options.x_warn_lto_type_mismatch
#endif
#ifdef GENERATOR_FILE
extern int warn_main;
#else
  int x_warn_main;
#define warn_main global_options.x_warn_main
#endif
#ifdef GENERATOR_FILE
extern int warn_maybe_uninitialized;
#else
  int x_warn_maybe_uninitialized;
#define warn_maybe_uninitialized global_options.x_warn_maybe_uninitialized
#endif
#ifdef GENERATOR_FILE
extern int warn_memset_elt_size;
#else
  int x_warn_memset_elt_size;
#define warn_memset_elt_size global_options.x_warn_memset_elt_size
#endif
#ifdef GENERATOR_FILE
extern int warn_memset_transposed_args;
#else
  int x_warn_memset_transposed_args;
#define warn_memset_transposed_args global_options.x_warn_memset_transposed_args
#endif
#ifdef GENERATOR_FILE
extern int warn_misleading_indentation;
#else
  int x_warn_misleading_indentation;
#define warn_misleading_indentation global_options.x_warn_misleading_indentation
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_attributes;
#else
  int x_warn_missing_attributes;
#define warn_missing_attributes global_options.x_warn_missing_attributes
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_braces;
#else
  int x_warn_missing_braces;
#define warn_missing_braces global_options.x_warn_missing_braces
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_declarations;
#else
  int x_warn_missing_declarations;
#define warn_missing_declarations global_options.x_warn_missing_declarations
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_field_initializers;
#else
  int x_warn_missing_field_initializers;
#define warn_missing_field_initializers global_options.x_warn_missing_field_initializers
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_missing_include_dirs;
#else
  int x_cpp_warn_missing_include_dirs;
#define cpp_warn_missing_include_dirs global_options.x_cpp_warn_missing_include_dirs
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_parameter_type;
#else
  int x_warn_missing_parameter_type;
#define warn_missing_parameter_type global_options.x_warn_missing_parameter_type
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_prototypes;
#else
  int x_warn_missing_prototypes;
#define warn_missing_prototypes global_options.x_warn_missing_prototypes
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_multichar;
#else
  int x_cpp_warn_multichar;
#define cpp_warn_multichar global_options.x_cpp_warn_multichar
#endif
#ifdef GENERATOR_FILE
extern int warn_multiple_inheritance;
#else
  int x_warn_multiple_inheritance;
#define warn_multiple_inheritance global_options.x_warn_multiple_inheritance
#endif
#ifdef GENERATOR_FILE
extern int warn_multistatement_macros;
#else
  int x_warn_multistatement_macros;
#define warn_multistatement_macros global_options.x_warn_multistatement_macros
#endif
#ifdef GENERATOR_FILE
extern int warn_namespaces;
#else
  int x_warn_namespaces;
#define warn_namespaces global_options.x_warn_namespaces
#endif
#ifdef GENERATOR_FILE
extern int warn_narrowing;
#else
  int x_warn_narrowing;
#define warn_narrowing global_options.x_warn_narrowing
#endif
#ifdef GENERATOR_FILE
extern int warn_nested_externs;
#else
  int x_warn_nested_externs;
#define warn_nested_externs global_options.x_warn_nested_externs
#endif
#ifdef GENERATOR_FILE
extern int warn_noexcept;
#else
  int x_warn_noexcept;
#define warn_noexcept global_options.x_warn_noexcept
#endif
#ifdef GENERATOR_FILE
extern int warn_noexcept_type;
#else
  int x_warn_noexcept_type;
#define warn_noexcept_type global_options.x_warn_noexcept_type
#endif
#ifdef GENERATOR_FILE
extern int warn_nontemplate_friend;
#else
  int x_warn_nontemplate_friend;
#define warn_nontemplate_friend global_options.x_warn_nontemplate_friend
#endif
#ifdef GENERATOR_FILE
extern int warn_nonvdtor;
#else
  int x_warn_nonvdtor;
#define warn_nonvdtor global_options.x_warn_nonvdtor
#endif
#ifdef GENERATOR_FILE
extern int warn_nonnull;
#else
  int x_warn_nonnull;
#define warn_nonnull global_options.x_warn_nonnull
#endif
#ifdef GENERATOR_FILE
extern int warn_nonnull_compare;
#else
  int x_warn_nonnull_compare;
#define warn_nonnull_compare global_options.x_warn_nonnull_compare
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_normalize;
#else
  int x_cpp_warn_normalize;
#define cpp_warn_normalize global_options.x_cpp_warn_normalize
#endif
#ifdef GENERATOR_FILE
extern int warn_null_dereference;
#else
  int x_warn_null_dereference;
#define warn_null_dereference global_options.x_warn_null_dereference
#endif
#ifdef GENERATOR_FILE
extern int warn_odr_violations;
#else
  int x_warn_odr_violations;
#define warn_odr_violations global_options.x_warn_odr_violations
#endif
#ifdef GENERATOR_FILE
extern int warn_old_style_cast;
#else
  int x_warn_old_style_cast;
#define warn_old_style_cast global_options.x_warn_old_style_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_old_style_declaration;
#else
  int x_warn_old_style_declaration;
#define warn_old_style_declaration global_options.x_warn_old_style_declaration
#endif
#ifdef GENERATOR_FILE
extern int warn_old_style_definition;
#else
  int x_warn_old_style_definition;
#define warn_old_style_definition global_options.x_warn_old_style_definition
#endif
#ifdef GENERATOR_FILE
extern int warn_openmp_simd;
#else
  int x_warn_openmp_simd;
#define warn_openmp_simd global_options.x_warn_openmp_simd
#endif
#ifdef GENERATOR_FILE
extern int warn_overflow;
#else
  int x_warn_overflow;
#define warn_overflow global_options.x_warn_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_overlength_strings;
#else
  int x_warn_overlength_strings;
#define warn_overlength_strings global_options.x_warn_overlength_strings
#endif
#ifdef GENERATOR_FILE
extern int warn_overloaded_virtual;
#else
  int x_warn_overloaded_virtual;
#define warn_overloaded_virtual global_options.x_warn_overloaded_virtual
#endif
#ifdef GENERATOR_FILE
extern int warn_override_init;
#else
  int x_warn_override_init;
#define warn_override_init global_options.x_warn_override_init
#endif
#ifdef GENERATOR_FILE
extern int warn_override_init_side_effects;
#else
  int x_warn_override_init_side_effects;
#define warn_override_init_side_effects global_options.x_warn_override_init_side_effects
#endif
#ifdef GENERATOR_FILE
extern int warn_packed;
#else
  int x_warn_packed;
#define warn_packed global_options.x_warn_packed
#endif
#ifdef GENERATOR_FILE
extern int warn_packed_bitfield_compat;
#else
  int x_warn_packed_bitfield_compat;
#define warn_packed_bitfield_compat global_options.x_warn_packed_bitfield_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_packed_not_aligned;
#else
  int x_warn_packed_not_aligned;
#define warn_packed_not_aligned global_options.x_warn_packed_not_aligned
#endif
#ifdef GENERATOR_FILE
extern int warn_padded;
#else
  int x_warn_padded;
#define warn_padded global_options.x_warn_padded
#endif
#ifdef GENERATOR_FILE
extern int warn_parentheses;
#else
  int x_warn_parentheses;
#define warn_parentheses global_options.x_warn_parentheses
#endif
#ifdef GENERATOR_FILE
extern int pedantic;
#else
  int x_pedantic;
#define pedantic global_options.x_pedantic
#endif
#ifdef GENERATOR_FILE
extern int warn_placement_new;
#else
  int x_warn_placement_new;
#define warn_placement_new global_options.x_warn_placement_new
#endif
#ifdef GENERATOR_FILE
extern int warn_pmf2ptr;
#else
  int x_warn_pmf2ptr;
#define warn_pmf2ptr global_options.x_warn_pmf2ptr
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_arith;
#else
  int x_warn_pointer_arith;
#define warn_pointer_arith global_options.x_warn_pointer_arith
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_compare;
#else
  int x_warn_pointer_compare;
#define warn_pointer_compare global_options.x_warn_pointer_compare
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_sign;
#else
  int x_warn_pointer_sign;
#define warn_pointer_sign global_options.x_warn_pointer_sign
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_to_int_cast;
#else
  int x_warn_pointer_to_int_cast;
#define warn_pointer_to_int_cast global_options.x_warn_pointer_to_int_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_pragmas;
#else
  int x_warn_pragmas;
#define warn_pragmas global_options.x_warn_pragmas
#endif
#ifdef GENERATOR_FILE
extern int warn_property_assign_default;
#else
  int x_warn_property_assign_default;
#define warn_property_assign_default global_options.x_warn_property_assign_default
#endif
#ifdef GENERATOR_FILE
extern int warn_protocol;
#else
  int x_warn_protocol;
#define warn_protocol global_options.x_warn_protocol
#endif
#ifdef GENERATOR_FILE
extern int warn_psabi;
#else
  int x_warn_psabi;
#define warn_psabi global_options.x_warn_psabi
#endif
#ifdef GENERATOR_FILE
extern int warn_real_q_constant;
#else
  int x_warn_real_q_constant;
#define warn_real_q_constant global_options.x_warn_real_q_constant
#endif
#ifdef GENERATOR_FILE
extern int warn_realloc_lhs;
#else
  int x_warn_realloc_lhs;
#define warn_realloc_lhs global_options.x_warn_realloc_lhs
#endif
#ifdef GENERATOR_FILE
extern int warn_realloc_lhs_all;
#else
  int x_warn_realloc_lhs_all;
#define warn_realloc_lhs_all global_options.x_warn_realloc_lhs_all
#endif
#ifdef GENERATOR_FILE
extern int warn_redundant_decls;
#else
  int x_warn_redundant_decls;
#define warn_redundant_decls global_options.x_warn_redundant_decls
#endif
#ifdef GENERATOR_FILE
extern int warn_register;
#else
  int x_warn_register;
#define warn_register global_options.x_warn_register
#endif
#ifdef GENERATOR_FILE
extern int warn_reorder;
#else
  int x_warn_reorder;
#define warn_reorder global_options.x_warn_reorder
#endif
#ifdef GENERATOR_FILE
extern int warn_restrict;
#else
  int x_warn_restrict;
#define warn_restrict global_options.x_warn_restrict
#endif
#ifdef GENERATOR_FILE
extern int warn_return_local_addr;
#else
  int x_warn_return_local_addr;
#define warn_return_local_addr global_options.x_warn_return_local_addr
#endif
#ifdef GENERATOR_FILE
extern int warn_return_type;
#else
  int x_warn_return_type;
#define warn_return_type global_options.x_warn_return_type
#endif
#ifdef GENERATOR_FILE
extern int warn_selector;
#else
  int x_warn_selector;
#define warn_selector global_options.x_warn_selector
#endif
#ifdef GENERATOR_FILE
extern int warn_sequence_point;
#else
  int x_warn_sequence_point;
#define warn_sequence_point global_options.x_warn_sequence_point
#endif
#ifdef GENERATOR_FILE
extern int warn_shadow;
#else
  int x_warn_shadow;
#define warn_shadow global_options.x_warn_shadow
#endif
#ifdef GENERATOR_FILE
extern int warn_shadow_ivar;
#else
  int x_warn_shadow_ivar;
#define warn_shadow_ivar global_options.x_warn_shadow_ivar
#endif
#ifdef GENERATOR_FILE
extern int warn_shadow_compatible_local;
#else
  int x_warn_shadow_compatible_local;
#define warn_shadow_compatible_local global_options.x_warn_shadow_compatible_local
#endif
#ifdef GENERATOR_FILE
extern int warn_shadow_local;
#else
  int x_warn_shadow_local;
#define warn_shadow_local global_options.x_warn_shadow_local
#endif
#ifdef GENERATOR_FILE
extern int warn_shift_count_negative;
#else
  int x_warn_shift_count_negative;
#define warn_shift_count_negative global_options.x_warn_shift_count_negative
#endif
#ifdef GENERATOR_FILE
extern int warn_shift_count_overflow;
#else
  int x_warn_shift_count_overflow;
#define warn_shift_count_overflow global_options.x_warn_shift_count_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_shift_negative_value;
#else
  int x_warn_shift_negative_value;
#define warn_shift_negative_value global_options.x_warn_shift_negative_value
#endif
#ifdef GENERATOR_FILE
extern int warn_shift_overflow;
#else
  int x_warn_shift_overflow;
#define warn_shift_overflow global_options.x_warn_shift_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_sign_compare;
#else
  int x_warn_sign_compare;
#define warn_sign_compare global_options.x_warn_sign_compare
#endif
#ifdef GENERATOR_FILE
extern int warn_sign_conversion;
#else
  int x_warn_sign_conversion;
#define warn_sign_conversion global_options.x_warn_sign_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_sign_promo;
#else
  int x_warn_sign_promo;
#define warn_sign_promo global_options.x_warn_sign_promo
#endif
#ifdef GENERATOR_FILE
extern int warn_sized_deallocation;
#else
  int x_warn_sized_deallocation;
#define warn_sized_deallocation global_options.x_warn_sized_deallocation
#endif
#ifdef GENERATOR_FILE
extern int warn_sizeof_array_argument;
#else
  int x_warn_sizeof_array_argument;
#define warn_sizeof_array_argument global_options.x_warn_sizeof_array_argument
#endif
#ifdef GENERATOR_FILE
extern int warn_sizeof_pointer_div;
#else
  int x_warn_sizeof_pointer_div;
#define warn_sizeof_pointer_div global_options.x_warn_sizeof_pointer_div
#endif
#ifdef GENERATOR_FILE
extern int warn_sizeof_pointer_memaccess;
#else
  int x_warn_sizeof_pointer_memaccess;
#define warn_sizeof_pointer_memaccess global_options.x_warn_sizeof_pointer_memaccess
#endif
#ifdef GENERATOR_FILE
extern int warn_stack_protect;
#else
  int x_warn_stack_protect;
#define warn_stack_protect global_options.x_warn_stack_protect
#endif
#ifdef GENERATOR_FILE
extern int warn_stack_usage;
#else
  int x_warn_stack_usage;
#define warn_stack_usage global_options.x_warn_stack_usage
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_aliasing;
#else
  int x_warn_strict_aliasing;
#define warn_strict_aliasing global_options.x_warn_strict_aliasing
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_null_sentinel;
#else
  int x_warn_strict_null_sentinel;
#define warn_strict_null_sentinel global_options.x_warn_strict_null_sentinel
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_overflow;
#else
  int x_warn_strict_overflow;
#define warn_strict_overflow global_options.x_warn_strict_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_prototypes;
#else
  int x_warn_strict_prototypes;
#define warn_strict_prototypes global_options.x_warn_strict_prototypes
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_selector_match;
#else
  int x_warn_strict_selector_match;
#define warn_strict_selector_match global_options.x_warn_strict_selector_match
#endif
#ifdef GENERATOR_FILE
extern int warn_stringop_overflow;
#else
  int x_warn_stringop_overflow;
#define warn_stringop_overflow global_options.x_warn_stringop_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_stringop_truncation;
#else
  int x_warn_stringop_truncation;
#define warn_stringop_truncation global_options.x_warn_stringop_truncation
#endif
#ifdef GENERATOR_FILE
extern int warn_subobject_linkage;
#else
  int x_warn_subobject_linkage;
#define warn_subobject_linkage global_options.x_warn_subobject_linkage
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_cold;
#else
  int x_warn_suggest_attribute_cold;
#define warn_suggest_attribute_cold global_options.x_warn_suggest_attribute_cold
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_const;
#else
  int x_warn_suggest_attribute_const;
#define warn_suggest_attribute_const global_options.x_warn_suggest_attribute_const
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_format;
#else
  int x_warn_suggest_attribute_format;
#define warn_suggest_attribute_format global_options.x_warn_suggest_attribute_format
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_malloc;
#else
  int x_warn_suggest_attribute_malloc;
#define warn_suggest_attribute_malloc global_options.x_warn_suggest_attribute_malloc
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_noreturn;
#else
  int x_warn_suggest_attribute_noreturn;
#define warn_suggest_attribute_noreturn global_options.x_warn_suggest_attribute_noreturn
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_pure;
#else
  int x_warn_suggest_attribute_pure;
#define warn_suggest_attribute_pure global_options.x_warn_suggest_attribute_pure
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_final_methods;
#else
  int x_warn_suggest_final_methods;
#define warn_suggest_final_methods global_options.x_warn_suggest_final_methods
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_final_types;
#else
  int x_warn_suggest_final_types;
#define warn_suggest_final_types global_options.x_warn_suggest_final_types
#endif
#ifdef GENERATOR_FILE
extern int warn_override;
#else
  int x_warn_override;
#define warn_override global_options.x_warn_override
#endif
#ifdef GENERATOR_FILE
extern int warn_surprising;
#else
  int x_warn_surprising;
#define warn_surprising global_options.x_warn_surprising
#endif
#ifdef GENERATOR_FILE
extern int warn_switch;
#else
  int x_warn_switch;
#define warn_switch global_options.x_warn_switch
#endif
#ifdef GENERATOR_FILE
extern int warn_switch_bool;
#else
  int x_warn_switch_bool;
#define warn_switch_bool global_options.x_warn_switch_bool
#endif
#ifdef GENERATOR_FILE
extern int warn_switch_default;
#else
  int x_warn_switch_default;
#define warn_switch_default global_options.x_warn_switch_default
#endif
#ifdef GENERATOR_FILE
extern int warn_switch_enum;
#else
  int x_warn_switch_enum;
#define warn_switch_enum global_options.x_warn_switch_enum
#endif
#ifdef GENERATOR_FILE
extern int warn_switch_unreachable;
#else
  int x_warn_switch_unreachable;
#define warn_switch_unreachable global_options.x_warn_switch_unreachable
#endif
#ifdef GENERATOR_FILE
extern int warn_sync_nand;
#else
  int x_warn_sync_nand;
#define warn_sync_nand global_options.x_warn_sync_nand
#endif
#ifdef GENERATOR_FILE
extern int warn_synth;
#else
  int x_warn_synth;
#define warn_synth global_options.x_warn_synth
#endif
#ifdef GENERATOR_FILE
extern int warn_system_headers;
#else
  int x_warn_system_headers;
#define warn_system_headers global_options.x_warn_system_headers
#endif
#ifdef GENERATOR_FILE
extern int warn_tabs;
#else
  int x_warn_tabs;
#define warn_tabs global_options.x_warn_tabs
#endif
#ifdef GENERATOR_FILE
extern int warn_target_lifetime;
#else
  int x_warn_target_lifetime;
#define warn_target_lifetime global_options.x_warn_target_lifetime
#endif
#ifdef GENERATOR_FILE
extern int warn_tautological_compare;
#else
  int x_warn_tautological_compare;
#define warn_tautological_compare global_options.x_warn_tautological_compare
#endif
#ifdef GENERATOR_FILE
extern int warn_templates;
#else
  int x_warn_templates;
#define warn_templates global_options.x_warn_templates
#endif
#ifdef GENERATOR_FILE
extern int warn_terminate;
#else
  int x_warn_terminate;
#define warn_terminate global_options.x_warn_terminate
#endif
#ifdef GENERATOR_FILE
extern int warn_traditional;
#else
  int x_warn_traditional;
#define warn_traditional global_options.x_warn_traditional
#endif
#ifdef GENERATOR_FILE
extern int warn_traditional_conversion;
#else
  int x_warn_traditional_conversion;
#define warn_traditional_conversion global_options.x_warn_traditional_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_trampolines;
#else
  int x_warn_trampolines;
#define warn_trampolines global_options.x_warn_trampolines
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_trigraphs;
#else
  int x_cpp_warn_trigraphs;
#define cpp_warn_trigraphs global_options.x_cpp_warn_trigraphs
#endif
#ifdef GENERATOR_FILE
extern int warn_type_limits;
#else
  int x_warn_type_limits;
#define warn_type_limits global_options.x_warn_type_limits
#endif
#ifdef GENERATOR_FILE
extern int warn_undeclared_selector;
#else
  int x_warn_undeclared_selector;
#define warn_undeclared_selector global_options.x_warn_undeclared_selector
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_undef;
#else
  int x_cpp_warn_undef;
#define cpp_warn_undef global_options.x_cpp_warn_undef
#endif
#ifdef GENERATOR_FILE
extern int warn_undefined_do_loop;
#else
  int x_warn_undefined_do_loop;
#define warn_undefined_do_loop global_options.x_warn_undefined_do_loop
#endif
#ifdef GENERATOR_FILE
extern int warn_underflow;
#else
  int x_warn_underflow;
#define warn_underflow global_options.x_warn_underflow
#endif
#ifdef GENERATOR_FILE
extern int warn_uninitialized;
#else
  int x_warn_uninitialized;
#define warn_uninitialized global_options.x_warn_uninitialized
#endif
#ifdef GENERATOR_FILE
extern int warn_unknown_pragmas;
#else
  int x_warn_unknown_pragmas;
#define warn_unknown_pragmas global_options.x_warn_unknown_pragmas
#endif
#ifdef GENERATOR_FILE
extern int warn_unsuffixed_float_constants;
#else
  int x_warn_unsuffixed_float_constants;
#define warn_unsuffixed_float_constants global_options.x_warn_unsuffixed_float_constants
#endif
#ifdef GENERATOR_FILE
extern int warn_unused;
#else
  int x_warn_unused;
#define warn_unused global_options.x_warn_unused
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_but_set_parameter;
#else
  int x_warn_unused_but_set_parameter;
#define warn_unused_but_set_parameter global_options.x_warn_unused_but_set_parameter
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_but_set_variable;
#else
  int x_warn_unused_but_set_variable;
#define warn_unused_but_set_variable global_options.x_warn_unused_but_set_variable
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_const_variable;
#else
  int x_warn_unused_const_variable;
#define warn_unused_const_variable global_options.x_warn_unused_const_variable
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_dummy_argument;
#else
  int x_warn_unused_dummy_argument;
#define warn_unused_dummy_argument global_options.x_warn_unused_dummy_argument
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_function;
#else
  int x_warn_unused_function;
#define warn_unused_function global_options.x_warn_unused_function
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_label;
#else
  int x_warn_unused_label;
#define warn_unused_label global_options.x_warn_unused_label
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_local_typedefs;
#else
  int x_warn_unused_local_typedefs;
#define warn_unused_local_typedefs global_options.x_warn_unused_local_typedefs
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_unused_macros;
#else
  int x_cpp_warn_unused_macros;
#define cpp_warn_unused_macros global_options.x_cpp_warn_unused_macros
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_parameter;
#else
  int x_warn_unused_parameter;
#define warn_unused_parameter global_options.x_warn_unused_parameter
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_result;
#else
  int x_warn_unused_result;
#define warn_unused_result global_options.x_warn_unused_result
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_value;
#else
  int x_warn_unused_value;
#define warn_unused_value global_options.x_warn_unused_value
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_variable;
#else
  int x_warn_unused_variable;
#define warn_unused_variable global_options.x_warn_unused_variable
#endif
#ifdef GENERATOR_FILE
extern int warn_use_without_only;
#else
  int x_warn_use_without_only;
#define warn_use_without_only global_options.x_warn_use_without_only
#endif
#ifdef GENERATOR_FILE
extern int warn_useless_cast;
#else
  int x_warn_useless_cast;
#define warn_useless_cast global_options.x_warn_useless_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_varargs;
#else
  int x_warn_varargs;
#define warn_varargs global_options.x_warn_varargs
#endif
#ifdef GENERATOR_FILE
extern int cpp_warn_variadic_macros;
#else
  int x_cpp_warn_variadic_macros;
#define cpp_warn_variadic_macros global_options.x_cpp_warn_variadic_macros
#endif
#ifdef GENERATOR_FILE
extern int warn_vector_operation_performance;
#else
  int x_warn_vector_operation_performance;
#define warn_vector_operation_performance global_options.x_warn_vector_operation_performance
#endif
#ifdef GENERATOR_FILE
extern int warn_virtual_inheritance;
#else
  int x_warn_virtual_inheritance;
#define warn_virtual_inheritance global_options.x_warn_virtual_inheritance
#endif
#ifdef GENERATOR_FILE
extern int warn_virtual_move_assign;
#else
  int x_warn_virtual_move_assign;
#define warn_virtual_move_assign global_options.x_warn_virtual_move_assign
#endif
#ifdef GENERATOR_FILE
extern int warn_vla;
#else
  int x_warn_vla;
#define warn_vla global_options.x_warn_vla
#endif
#ifdef GENERATOR_FILE
extern int warn_vla_limit;
#else
  int x_warn_vla_limit;
#define warn_vla_limit global_options.x_warn_vla_limit
#endif
#ifdef GENERATOR_FILE
extern int warn_volatile_register_var;
#else
  int x_warn_volatile_register_var;
#define warn_volatile_register_var global_options.x_warn_volatile_register_var
#endif
#ifdef GENERATOR_FILE
extern int warn_write_strings;
#else
  int x_warn_write_strings;
#define warn_write_strings global_options.x_warn_write_strings
#endif
#ifdef GENERATOR_FILE
extern int warn_zero_as_null_pointer_constant;
#else
  int x_warn_zero_as_null_pointer_constant;
#define warn_zero_as_null_pointer_constant global_options.x_warn_zero_as_null_pointer_constant
#endif
#ifdef GENERATOR_FILE
extern int warn_zerotrip;
#else
  int x_warn_zerotrip;
#define warn_zerotrip global_options.x_warn_zerotrip
#endif
#ifdef GENERATOR_FILE
extern const char *aux_info_file_name;
#else
  const char *x_aux_info_file_name;
#define aux_info_file_name global_options.x_aux_info_file_name
#endif
#ifdef GENERATOR_FILE
extern const char *aux_base_name;
#else
  const char *x_aux_base_name;
#define aux_base_name global_options.x_aux_base_name
#endif
#ifdef GENERATOR_FILE
extern const char *dump_base_name;
#else
  const char *x_dump_base_name;
#define dump_base_name global_options.x_dump_base_name
#endif
#ifdef GENERATOR_FILE
extern const char *dump_dir_name;
#else
  const char *x_dump_dir_name;
#define dump_dir_name global_options.x_dump_dir_name
#endif
#ifdef GENERATOR_FILE
extern int flag_pic;
#else
  int x_flag_pic;
#define flag_pic global_options.x_flag_pic
#endif
#ifdef GENERATOR_FILE
extern int flag_pie;
#else
  int x_flag_pie;
#define flag_pie global_options.x_flag_pie
#endif
#ifdef GENERATOR_FILE
extern int flag_abi_compat_version;
#else
  int x_flag_abi_compat_version;
#define flag_abi_compat_version global_options.x_flag_abi_compat_version
#endif
#ifdef GENERATOR_FILE
extern int flag_abi_version;
#else
  int x_flag_abi_version;
#define flag_abi_version global_options.x_flag_abi_version
#endif
#ifdef GENERATOR_FILE
extern int flag_access_control;
#else
  int x_flag_access_control;
#define flag_access_control global_options.x_flag_access_control
#endif
#ifdef GENERATOR_FILE
extern const char *ada_specs_parent;
#else
  const char *x_ada_specs_parent;
#define ada_specs_parent global_options.x_ada_specs_parent
#endif
#ifdef GENERATOR_FILE
extern int flag_aggressive_function_elimination;
#else
  int x_flag_aggressive_function_elimination;
#define flag_aggressive_function_elimination global_options.x_flag_aggressive_function_elimination
#endif
#ifdef GENERATOR_FILE
extern int flag_aggressive_loop_optimizations;
#else
  int x_flag_aggressive_loop_optimizations;
#define flag_aggressive_loop_optimizations global_options.x_flag_aggressive_loop_optimizations
#endif
#ifdef GENERATOR_FILE
extern int flag_align_commons;
#else
  int x_flag_align_commons;
#define flag_align_commons global_options.x_flag_align_commons
#endif
#ifdef GENERATOR_FILE
extern int align_functions;
#else
  int x_align_functions;
#define align_functions global_options.x_align_functions
#endif
#ifdef GENERATOR_FILE
extern int align_jumps;
#else
  int x_align_jumps;
#define align_jumps global_options.x_align_jumps
#endif
#ifdef GENERATOR_FILE
extern int align_labels;
#else
  int x_align_labels;
#define align_labels global_options.x_align_labels
#endif
#ifdef GENERATOR_FILE
extern int align_loops;
#else
  int x_align_loops;
#define align_loops global_options.x_align_loops
#endif
#ifdef GENERATOR_FILE
extern int aligned_new_threshold;
#else
  int x_aligned_new_threshold;
#define aligned_new_threshold global_options.x_aligned_new_threshold
#endif
#ifdef GENERATOR_FILE
extern int flag_all_intrinsics;
#else
  int x_flag_all_intrinsics;
#define flag_all_intrinsics global_options.x_flag_all_intrinsics
#endif
#ifdef GENERATOR_FILE
extern int flag_allow_leading_underscore;
#else
  int x_flag_allow_leading_underscore;
#define flag_allow_leading_underscore global_options.x_flag_allow_leading_underscore
#endif
#ifdef GENERATOR_FILE
extern int flag_allow_parameterless_variadic_functions;
#else
  int x_flag_allow_parameterless_variadic_functions;
#define flag_allow_parameterless_variadic_functions global_options.x_flag_allow_parameterless_variadic_functions
#endif
#ifdef GENERATOR_FILE
extern void *common_deferred_options;
#else
  void *x_common_deferred_options;
#define common_deferred_options global_options.x_common_deferred_options
#endif
#ifdef GENERATOR_FILE
extern int flag_no_asm;
#else
  int x_flag_no_asm;
#define flag_no_asm global_options.x_flag_no_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_associative_math;
#else
  int x_flag_associative_math;
#define flag_associative_math global_options.x_flag_associative_math
#endif
#ifdef GENERATOR_FILE
extern int flag_asynchronous_unwind_tables;
#else
  int x_flag_asynchronous_unwind_tables;
#define flag_asynchronous_unwind_tables global_options.x_flag_asynchronous_unwind_tables
#endif
#ifdef GENERATOR_FILE
extern int flag_auto_inc_dec;
#else
  int x_flag_auto_inc_dec;
#define flag_auto_inc_dec global_options.x_flag_auto_inc_dec
#endif
#ifdef GENERATOR_FILE
extern int flag_auto_profile;
#else
  int x_flag_auto_profile;
#define flag_auto_profile global_options.x_flag_auto_profile
#endif
#ifdef GENERATOR_FILE
extern const char *auto_profile_file;
#else
  const char *x_auto_profile_file;
#define auto_profile_file global_options.x_auto_profile_file
#endif
#ifdef GENERATOR_FILE
extern int flag_automatic;
#else
  int x_flag_automatic;
#define flag_automatic global_options.x_flag_automatic
#endif
#ifdef GENERATOR_FILE
extern int flag_backslash;
#else
  int x_flag_backslash;
#define flag_backslash global_options.x_flag_backslash
#endif
#ifdef GENERATOR_FILE
extern int flag_backtrace;
#else
  int x_flag_backtrace;
#define flag_backtrace global_options.x_flag_backtrace
#endif
#ifdef GENERATOR_FILE
extern int flag_blas_matmul_limit;
#else
  int x_flag_blas_matmul_limit;
#define flag_blas_matmul_limit global_options.x_flag_blas_matmul_limit
#endif
#ifdef GENERATOR_FILE
extern int flag_bounds_check;
#else
  int x_flag_bounds_check;
#define flag_bounds_check global_options.x_flag_bounds_check
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_on_count_reg;
#else
  int x_flag_branch_on_count_reg;
#define flag_branch_on_count_reg global_options.x_flag_branch_on_count_reg
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_probabilities;
#else
  int x_flag_branch_probabilities;
#define flag_branch_probabilities global_options.x_flag_branch_probabilities
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_target_load_optimize;
#else
  int x_flag_branch_target_load_optimize;
#define flag_branch_target_load_optimize global_options.x_flag_branch_target_load_optimize
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_target_load_optimize2;
#else
  int x_flag_branch_target_load_optimize2;
#define flag_branch_target_load_optimize2 global_options.x_flag_branch_target_load_optimize2
#endif
#ifdef GENERATOR_FILE
extern int flag_btr_bb_exclusive;
#else
  int x_flag_btr_bb_exclusive;
#define flag_btr_bb_exclusive global_options.x_flag_btr_bb_exclusive
#endif
#ifdef GENERATOR_FILE
extern int flag_building_libgcc;
#else
  int x_flag_building_libgcc;
#define flag_building_libgcc global_options.x_flag_building_libgcc
#endif
#ifdef GENERATOR_FILE
extern int flag_no_builtin;
#else
  int x_flag_no_builtin;
#define flag_no_builtin global_options.x_flag_no_builtin
#endif
#ifdef GENERATOR_FILE
extern int flag_c_prototypes;
#else
  int x_flag_c_prototypes;
#define flag_c_prototypes global_options.x_flag_c_prototypes
#endif
#ifdef GENERATOR_FILE
extern int flag_caller_saves;
#else
  int x_flag_caller_saves;
#define flag_caller_saves global_options.x_flag_caller_saves
#endif
#ifdef GENERATOR_FILE
extern enum cf_protection_level flag_cf_protection;
#else
  enum cf_protection_level x_flag_cf_protection;
#define flag_cf_protection global_options.x_flag_cf_protection
#endif
#ifdef GENERATOR_FILE
extern int flag_check_data_deps;
#else
  int x_flag_check_data_deps;
#define flag_check_data_deps global_options.x_flag_check_data_deps
#endif
#ifdef GENERATOR_FILE
extern int flag_check_new;
#else
  int x_flag_check_new;
#define flag_check_new global_options.x_flag_check_new
#endif
#ifdef GENERATOR_FILE
extern int flag_check_pointer_bounds;
#else
  int x_flag_check_pointer_bounds;
#define flag_check_pointer_bounds global_options.x_flag_check_pointer_bounds
#endif
#ifdef GENERATOR_FILE
extern int flag_checking;
#else
  int x_flag_checking;
#define flag_checking global_options.x_flag_checking
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_incomplete_type;
#else
  int x_flag_chkp_incomplete_type;
#define flag_chkp_incomplete_type global_options.x_flag_chkp_incomplete_type
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_check_read;
#else
  int x_flag_chkp_check_read;
#define flag_chkp_check_read global_options.x_flag_chkp_check_read
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_check_write;
#else
  int x_flag_chkp_check_write;
#define flag_chkp_check_write global_options.x_flag_chkp_check_write
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_first_field_has_own_bounds;
#else
  int x_flag_chkp_first_field_has_own_bounds;
#define flag_chkp_first_field_has_own_bounds global_options.x_flag_chkp_first_field_has_own_bounds
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_flexible_struct_trailing_arrays;
#else
  int x_flag_chkp_flexible_struct_trailing_arrays;
#define flag_chkp_flexible_struct_trailing_arrays global_options.x_flag_chkp_flexible_struct_trailing_arrays
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_instrument_calls;
#else
  int x_flag_chkp_instrument_calls;
#define flag_chkp_instrument_calls global_options.x_flag_chkp_instrument_calls
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_instrument_marked_only;
#else
  int x_flag_chkp_instrument_marked_only;
#define flag_chkp_instrument_marked_only global_options.x_flag_chkp_instrument_marked_only
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_narrow_bounds;
#else
  int x_flag_chkp_narrow_bounds;
#define flag_chkp_narrow_bounds global_options.x_flag_chkp_narrow_bounds
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_narrow_to_innermost_arrray;
#else
  int x_flag_chkp_narrow_to_innermost_arrray;
#define flag_chkp_narrow_to_innermost_arrray global_options.x_flag_chkp_narrow_to_innermost_arrray
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_optimize;
#else
  int x_flag_chkp_optimize;
#define flag_chkp_optimize global_options.x_flag_chkp_optimize
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_store_bounds;
#else
  int x_flag_chkp_store_bounds;
#define flag_chkp_store_bounds global_options.x_flag_chkp_store_bounds
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_zero_dynamic_size_as_infinite;
#else
  int x_flag_chkp_zero_dynamic_size_as_infinite;
#define flag_chkp_zero_dynamic_size_as_infinite global_options.x_flag_chkp_zero_dynamic_size_as_infinite
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_use_fast_string_functions;
#else
  int x_flag_chkp_use_fast_string_functions;
#define flag_chkp_use_fast_string_functions global_options.x_flag_chkp_use_fast_string_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_use_nochk_string_functions;
#else
  int x_flag_chkp_use_nochk_string_functions;
#define flag_chkp_use_nochk_string_functions global_options.x_flag_chkp_use_nochk_string_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_use_static_bounds;
#else
  int x_flag_chkp_use_static_bounds;
#define flag_chkp_use_static_bounds global_options.x_flag_chkp_use_static_bounds
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_use_static_const_bounds;
#else
  int x_flag_chkp_use_static_const_bounds;
#define flag_chkp_use_static_const_bounds global_options.x_flag_chkp_use_static_const_bounds
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_use_wrappers;
#else
  int x_flag_chkp_use_wrappers;
#define flag_chkp_use_wrappers global_options.x_flag_chkp_use_wrappers
#endif
#ifdef GENERATOR_FILE
extern int flag_chkp_zero_input_bounds_for_main;
#else
  int x_flag_chkp_zero_input_bounds_for_main;
#define flag_chkp_zero_input_bounds_for_main global_options.x_flag_chkp_zero_input_bounds_for_main
#endif
#ifdef GENERATOR_FILE
extern int flag_cilkplus;
#else
  int x_flag_cilkplus;
#define flag_cilkplus global_options.x_flag_cilkplus
#endif
#ifdef GENERATOR_FILE
extern enum gfc_fcoarray flag_coarray;
#else
  enum gfc_fcoarray x_flag_coarray;
#define flag_coarray global_options.x_flag_coarray
#endif
#ifdef GENERATOR_FILE
extern int flag_code_hoisting;
#else
  int x_flag_code_hoisting;
#define flag_code_hoisting global_options.x_flag_code_hoisting
#endif
#ifdef GENERATOR_FILE
extern int flag_combine_stack_adjustments;
#else
  int x_flag_combine_stack_adjustments;
#define flag_combine_stack_adjustments global_options.x_flag_combine_stack_adjustments
#endif
#ifdef GENERATOR_FILE
extern int flag_no_common;
#else
  int x_flag_no_common;
#define flag_no_common global_options.x_flag_no_common
#endif
#ifdef GENERATOR_FILE
extern int flag_compare_debug;
#else
  int x_flag_compare_debug;
#define flag_compare_debug global_options.x_flag_compare_debug
#endif
#ifdef GENERATOR_FILE
extern const char *flag_compare_debug_opt;
#else
  const char *x_flag_compare_debug_opt;
#define flag_compare_debug_opt global_options.x_flag_compare_debug_opt
#endif
#ifdef GENERATOR_FILE
extern int flag_compare_elim_after_reload;
#else
  int x_flag_compare_elim_after_reload;
#define flag_compare_elim_after_reload global_options.x_flag_compare_elim_after_reload
#endif
#ifdef GENERATOR_FILE
extern int flag_concepts;
#else
  int x_flag_concepts;
#define flag_concepts global_options.x_flag_concepts
#endif
#ifdef GENERATOR_FILE
extern int flag_conserve_space;
#else
  int x_flag_conserve_space;
#define flag_conserve_space global_options.x_flag_conserve_space
#endif
#ifdef GENERATOR_FILE
extern int flag_conserve_stack;
#else
  int x_flag_conserve_stack;
#define flag_conserve_stack global_options.x_flag_conserve_stack
#endif
#ifdef GENERATOR_FILE
extern int max_constexpr_depth;
#else
  int x_max_constexpr_depth;
#define max_constexpr_depth global_options.x_max_constexpr_depth
#endif
#ifdef GENERATOR_FILE
extern int constexpr_loop_limit;
#else
  int x_constexpr_loop_limit;
#define constexpr_loop_limit global_options.x_constexpr_loop_limit
#endif
#ifdef GENERATOR_FILE
extern enum gfc_convert flag_convert;
#else
  enum gfc_convert x_flag_convert;
#define flag_convert global_options.x_flag_convert
#endif
#ifdef GENERATOR_FILE
extern int flag_cprop_registers;
#else
  int x_flag_cprop_registers;
#define flag_cprop_registers global_options.x_flag_cprop_registers
#endif
#ifdef GENERATOR_FILE
extern int flag_cray_pointer;
#else
  int x_flag_cray_pointer;
#define flag_cray_pointer global_options.x_flag_cray_pointer
#endif
#ifdef GENERATOR_FILE
extern int flag_crossjumping;
#else
  int x_flag_crossjumping;
#define flag_crossjumping global_options.x_flag_crossjumping
#endif
#ifdef GENERATOR_FILE
extern int flag_cse_follow_jumps;
#else
  int x_flag_cse_follow_jumps;
#define flag_cse_follow_jumps global_options.x_flag_cse_follow_jumps
#endif
#ifdef GENERATOR_FILE
extern int flag_cx_fortran_rules;
#else
  int x_flag_cx_fortran_rules;
#define flag_cx_fortran_rules global_options.x_flag_cx_fortran_rules
#endif
#ifdef GENERATOR_FILE
extern int flag_cx_limited_range;
#else
  int x_flag_cx_limited_range;
#define flag_cx_limited_range global_options.x_flag_cx_limited_range
#endif
#ifdef GENERATOR_FILE
extern int flag_data_sections;
#else
  int x_flag_data_sections;
#define flag_data_sections global_options.x_flag_data_sections
#endif
#ifdef GENERATOR_FILE
extern int flag_dce;
#else
  int x_flag_dce;
#define flag_dce global_options.x_flag_dce
#endif
#ifdef GENERATOR_FILE
extern int flag_debug_types_section;
#else
  int x_flag_debug_types_section;
#define flag_debug_types_section global_options.x_flag_debug_types_section
#endif
#ifdef GENERATOR_FILE
extern int flag_dec;
#else
  int x_flag_dec;
#define flag_dec global_options.x_flag_dec
#endif
#ifdef GENERATOR_FILE
extern int flag_dec_intrinsic_ints;
#else
  int x_flag_dec_intrinsic_ints;
#define flag_dec_intrinsic_ints global_options.x_flag_dec_intrinsic_ints
#endif
#ifdef GENERATOR_FILE
extern int flag_dec_math;
#else
  int x_flag_dec_math;
#define flag_dec_math global_options.x_flag_dec_math
#endif
#ifdef GENERATOR_FILE
extern int flag_dec_static;
#else
  int x_flag_dec_static;
#define flag_dec_static global_options.x_flag_dec_static
#endif
#ifdef GENERATOR_FILE
extern int flag_dec_structure;
#else
  int x_flag_dec_structure;
#define flag_dec_structure global_options.x_flag_dec_structure
#endif
#ifdef GENERATOR_FILE
extern int flag_declone_ctor_dtor;
#else
  int x_flag_declone_ctor_dtor;
#define flag_declone_ctor_dtor global_options.x_flag_declone_ctor_dtor
#endif
#ifdef GENERATOR_FILE
extern int flag_deduce_init_list;
#else
  int x_flag_deduce_init_list;
#define flag_deduce_init_list global_options.x_flag_deduce_init_list
#endif
#ifdef GENERATOR_FILE
extern int flag_default_double;
#else
  int x_flag_default_double;
#define flag_default_double global_options.x_flag_default_double
#endif
#ifdef GENERATOR_FILE
extern int flag_default_integer;
#else
  int x_flag_default_integer;
#define flag_default_integer global_options.x_flag_default_integer
#endif
#ifdef GENERATOR_FILE
extern int flag_default_real_10;
#else
  int x_flag_default_real_10;
#define flag_default_real_10 global_options.x_flag_default_real_10
#endif
#ifdef GENERATOR_FILE
extern int flag_default_real_16;
#else
  int x_flag_default_real_16;
#define flag_default_real_16 global_options.x_flag_default_real_16
#endif
#ifdef GENERATOR_FILE
extern int flag_default_real_8;
#else
  int x_flag_default_real_8;
#define flag_default_real_8 global_options.x_flag_default_real_8
#endif
#ifdef GENERATOR_FILE
extern int flag_defer_pop;
#else
  int x_flag_defer_pop;
#define flag_defer_pop global_options.x_flag_defer_pop
#endif
#ifdef GENERATOR_FILE
extern int flag_delayed_branch;
#else
  int x_flag_delayed_branch;
#define flag_delayed_branch global_options.x_flag_delayed_branch
#endif
#ifdef GENERATOR_FILE
extern int flag_delete_dead_exceptions;
#else
  int x_flag_delete_dead_exceptions;
#define flag_delete_dead_exceptions global_options.x_flag_delete_dead_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_delete_null_pointer_checks;
#else
  int x_flag_delete_null_pointer_checks;
#define flag_delete_null_pointer_checks global_options.x_flag_delete_null_pointer_checks
#endif
#ifdef GENERATOR_FILE
extern int flag_devirtualize;
#else
  int x_flag_devirtualize;
#define flag_devirtualize global_options.x_flag_devirtualize
#endif
#ifdef GENERATOR_FILE
extern int flag_ltrans_devirtualize;
#else
  int x_flag_ltrans_devirtualize;
#define flag_ltrans_devirtualize global_options.x_flag_ltrans_devirtualize
#endif
#ifdef GENERATOR_FILE
extern int flag_devirtualize_speculatively;
#else
  int x_flag_devirtualize_speculatively;
#define flag_devirtualize_speculatively global_options.x_flag_devirtualize_speculatively
#endif
#ifdef GENERATOR_FILE
extern int flag_diagnostics_show_color;
#else
  int x_flag_diagnostics_show_color;
#define flag_diagnostics_show_color global_options.x_flag_diagnostics_show_color
#endif
#ifdef GENERATOR_FILE
extern int flag_diagnostics_generate_patch;
#else
  int x_flag_diagnostics_generate_patch;
#define flag_diagnostics_generate_patch global_options.x_flag_diagnostics_generate_patch
#endif
#ifdef GENERATOR_FILE
extern int flag_diagnostics_parseable_fixits;
#else
  int x_flag_diagnostics_parseable_fixits;
#define flag_diagnostics_parseable_fixits global_options.x_flag_diagnostics_parseable_fixits
#endif
#ifdef GENERATOR_FILE
extern int flag_diagnostics_show_caret;
#else
  int x_flag_diagnostics_show_caret;
#define flag_diagnostics_show_caret global_options.x_flag_diagnostics_show_caret
#endif
#ifdef GENERATOR_FILE
extern int flag_diagnostics_show_option;
#else
  int x_flag_diagnostics_show_option;
#define flag_diagnostics_show_option global_options.x_flag_diagnostics_show_option
#endif
#ifdef GENERATOR_FILE
extern int flag_diagnostics_show_template_tree;
#else
  int x_flag_diagnostics_show_template_tree;
#define flag_diagnostics_show_template_tree global_options.x_flag_diagnostics_show_template_tree
#endif
#ifdef GENERATOR_FILE
extern int flag_dollar_ok;
#else
  int x_flag_dollar_ok;
#define flag_dollar_ok global_options.x_flag_dollar_ok
#endif
#ifdef GENERATOR_FILE
extern int flag_dse;
#else
  int x_flag_dse;
#define flag_dse global_options.x_flag_dse
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_ada_spec;
#else
  int x_flag_dump_ada_spec;
#define flag_dump_ada_spec global_options.x_flag_dump_ada_spec
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_ada_spec_slim;
#else
  int x_flag_dump_ada_spec_slim;
#define flag_dump_ada_spec_slim global_options.x_flag_dump_ada_spec_slim
#endif
#ifdef GENERATOR_FILE
extern const char *flag_dump_final_insns;
#else
  const char *x_flag_dump_final_insns;
#define flag_dump_final_insns global_options.x_flag_dump_final_insns
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_fortran_optimized;
#else
  int x_flag_dump_fortran_optimized;
#define flag_dump_fortran_optimized global_options.x_flag_dump_fortran_optimized
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_fortran_original;
#else
  int x_flag_dump_fortran_original;
#define flag_dump_fortran_original global_options.x_flag_dump_fortran_original
#endif
#ifdef GENERATOR_FILE
extern const char *flag_dump_go_spec;
#else
  const char *x_flag_dump_go_spec;
#define flag_dump_go_spec global_options.x_flag_dump_go_spec
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_locations;
#else
  int x_flag_dump_locations;
#define flag_dump_locations global_options.x_flag_dump_locations
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_noaddr;
#else
  int x_flag_dump_noaddr;
#define flag_dump_noaddr global_options.x_flag_dump_noaddr
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_passes;
#else
  int x_flag_dump_passes;
#define flag_dump_passes global_options.x_flag_dump_passes
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_unnumbered;
#else
  int x_flag_dump_unnumbered;
#define flag_dump_unnumbered global_options.x_flag_dump_unnumbered
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_unnumbered_links;
#else
  int x_flag_dump_unnumbered_links;
#define flag_dump_unnumbered_links global_options.x_flag_dump_unnumbered_links
#endif
#ifdef GENERATOR_FILE
extern int flag_dwarf2_cfi_asm;
#else
  int x_flag_dwarf2_cfi_asm;
#define flag_dwarf2_cfi_asm global_options.x_flag_dwarf2_cfi_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_early_inlining;
#else
  int x_flag_early_inlining;
#define flag_early_inlining global_options.x_flag_early_inlining
#endif
#ifdef GENERATOR_FILE
extern int flag_elide_constructors;
#else
  int x_flag_elide_constructors;
#define flag_elide_constructors global_options.x_flag_elide_constructors
#endif
#ifdef GENERATOR_FILE
extern int flag_elide_type;
#else
  int x_flag_elide_type;
#define flag_elide_type global_options.x_flag_elide_type
#endif
#ifdef GENERATOR_FILE
extern int flag_debug_only_used_symbols;
#else
  int x_flag_debug_only_used_symbols;
#define flag_debug_only_used_symbols global_options.x_flag_debug_only_used_symbols
#endif
#ifdef GENERATOR_FILE
extern int flag_eliminate_unused_debug_types;
#else
  int x_flag_eliminate_unused_debug_types;
#define flag_eliminate_unused_debug_types global_options.x_flag_eliminate_unused_debug_types
#endif
#ifdef GENERATOR_FILE
extern int flag_emit_class_debug_always;
#else
  int x_flag_emit_class_debug_always;
#define flag_emit_class_debug_always global_options.x_flag_emit_class_debug_always
#endif
#ifdef GENERATOR_FILE
extern int flag_enforce_eh_specs;
#else
  int x_flag_enforce_eh_specs;
#define flag_enforce_eh_specs global_options.x_flag_enforce_eh_specs
#endif
#ifdef GENERATOR_FILE
extern int flag_exceptions;
#else
  int x_flag_exceptions;
#define flag_exceptions global_options.x_flag_exceptions
#endif
#ifdef GENERATOR_FILE
extern enum excess_precision flag_excess_precision_cmdline;
#else
  enum excess_precision x_flag_excess_precision_cmdline;
#define flag_excess_precision_cmdline global_options.x_flag_excess_precision_cmdline
#endif
#ifdef GENERATOR_FILE
extern int flag_expensive_optimizations;
#else
  int x_flag_expensive_optimizations;
#define flag_expensive_optimizations global_options.x_flag_expensive_optimizations
#endif
#ifdef GENERATOR_FILE
extern int flag_ext_numeric_literals;
#else
  int x_flag_ext_numeric_literals;
#define flag_ext_numeric_literals global_options.x_flag_ext_numeric_literals
#endif
#ifdef GENERATOR_FILE
extern int flag_extern_tls_init;
#else
  int x_flag_extern_tls_init;
#define flag_extern_tls_init global_options.x_flag_extern_tls_init
#endif
#ifdef GENERATOR_FILE
extern int flag_external_blas;
#else
  int x_flag_external_blas;
#define flag_external_blas global_options.x_flag_external_blas
#endif
#ifdef GENERATOR_FILE
extern int flag_f2c;
#else
  int x_flag_f2c;
#define flag_f2c global_options.x_flag_f2c
#endif
#ifdef GENERATOR_FILE
extern int flag_fat_lto_objects;
#else
  int x_flag_fat_lto_objects;
#define flag_fat_lto_objects global_options.x_flag_fat_lto_objects
#endif
#ifdef GENERATOR_FILE
extern int flag_finite_math_only;
#else
  int x_flag_finite_math_only;
#define flag_finite_math_only global_options.x_flag_finite_math_only
#endif
#ifdef GENERATOR_FILE
extern int flag_fixed_line_length;
#else
  int x_flag_fixed_line_length;
#define flag_fixed_line_length global_options.x_flag_fixed_line_length
#endif
#ifdef GENERATOR_FILE
extern int flag_float_store;
#else
  int x_flag_float_store;
#define flag_float_store global_options.x_flag_float_store
#endif
#ifdef GENERATOR_FILE
extern int flag_new_for_scope;
#else
  int x_flag_new_for_scope;
#define flag_new_for_scope global_options.x_flag_new_for_scope
#endif
#ifdef GENERATOR_FILE
extern int flag_forward_propagate;
#else
  int x_flag_forward_propagate;
#define flag_forward_propagate global_options.x_flag_forward_propagate
#endif
#ifdef GENERATOR_FILE
extern enum fp_contract_mode flag_fp_contract_mode;
#else
  enum fp_contract_mode x_flag_fp_contract_mode;
#define flag_fp_contract_mode global_options.x_flag_fp_contract_mode
#endif
#ifdef GENERATOR_FILE
extern int flag_fp_int_builtin_inexact;
#else
  int x_flag_fp_int_builtin_inexact;
#define flag_fp_int_builtin_inexact global_options.x_flag_fp_int_builtin_inexact
#endif
#ifdef GENERATOR_FILE
extern int flag_free_line_length;
#else
  int x_flag_free_line_length;
#define flag_free_line_length global_options.x_flag_free_line_length
#endif
#ifdef GENERATOR_FILE
extern int flag_friend_injection;
#else
  int x_flag_friend_injection;
#define flag_friend_injection global_options.x_flag_friend_injection
#endif
#ifdef GENERATOR_FILE
extern int flag_frontend_loop_interchange;
#else
  int x_flag_frontend_loop_interchange;
#define flag_frontend_loop_interchange global_options.x_flag_frontend_loop_interchange
#endif
#ifdef GENERATOR_FILE
extern int flag_frontend_optimize;
#else
  int x_flag_frontend_optimize;
#define flag_frontend_optimize global_options.x_flag_frontend_optimize
#endif
#ifdef GENERATOR_FILE
extern int flag_no_function_cse;
#else
  int x_flag_no_function_cse;
#define flag_no_function_cse global_options.x_flag_no_function_cse
#endif
#ifdef GENERATOR_FILE
extern int flag_function_sections;
#else
  int x_flag_function_sections;
#define flag_function_sections global_options.x_flag_function_sections
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse;
#else
  int x_flag_gcse;
#define flag_gcse global_options.x_flag_gcse
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_after_reload;
#else
  int x_flag_gcse_after_reload;
#define flag_gcse_after_reload global_options.x_flag_gcse_after_reload
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_las;
#else
  int x_flag_gcse_las;
#define flag_gcse_las global_options.x_flag_gcse_las
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_lm;
#else
  int x_flag_gcse_lm;
#define flag_gcse_lm global_options.x_flag_gcse_lm
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_sm;
#else
  int x_flag_gcse_sm;
#define flag_gcse_sm global_options.x_flag_gcse_sm
#endif
#ifdef GENERATOR_FILE
extern int flag_gimple;
#else
  int x_flag_gimple;
#define flag_gimple global_options.x_flag_gimple
#endif
#ifdef GENERATOR_FILE
extern int flag_no_gnu_keywords;
#else
  int x_flag_no_gnu_keywords;
#define flag_no_gnu_keywords global_options.x_flag_no_gnu_keywords
#endif
#ifdef GENERATOR_FILE
extern int flag_next_runtime;
#else
  int x_flag_next_runtime;
#define flag_next_runtime global_options.x_flag_next_runtime
#endif
#ifdef GENERATOR_FILE
extern int flag_tm;
#else
  int x_flag_tm;
#define flag_tm global_options.x_flag_tm
#endif
#ifdef GENERATOR_FILE
extern int flag_gnu_unique;
#else
  int x_flag_gnu_unique;
#define flag_gnu_unique global_options.x_flag_gnu_unique
#endif
#ifdef GENERATOR_FILE
extern int flag_gnu89_inline;
#else
  int x_flag_gnu89_inline;
#define flag_gnu89_inline global_options.x_flag_gnu89_inline
#endif
#ifdef GENERATOR_FILE
extern int go_check_divide_overflow;
#else
  int x_go_check_divide_overflow;
#define go_check_divide_overflow global_options.x_go_check_divide_overflow
#endif
#ifdef GENERATOR_FILE
extern int go_check_divide_zero;
#else
  int x_go_check_divide_zero;
#define go_check_divide_zero global_options.x_go_check_divide_zero
#endif
#ifdef GENERATOR_FILE
extern int go_compiling_runtime;
#else
  int x_go_compiling_runtime;
#define go_compiling_runtime global_options.x_go_compiling_runtime
#endif
#ifdef GENERATOR_FILE
extern int go_debug_escape_level;
#else
  int x_go_debug_escape_level;
#define go_debug_escape_level global_options.x_go_debug_escape_level
#endif
#ifdef GENERATOR_FILE
extern const char *go_debug_escape_hash;
#else
  const char *x_go_debug_escape_hash;
#define go_debug_escape_hash global_options.x_go_debug_escape_hash
#endif
#ifdef GENERATOR_FILE
extern int flag_graphite;
#else
  int x_flag_graphite;
#define flag_graphite global_options.x_flag_graphite
#endif
#ifdef GENERATOR_FILE
extern int flag_graphite_identity;
#else
  int x_flag_graphite_identity;
#define flag_graphite_identity global_options.x_flag_graphite_identity
#endif
#ifdef GENERATOR_FILE
extern int flag_guess_branch_prob;
#else
  int x_flag_guess_branch_prob;
#define flag_guess_branch_prob global_options.x_flag_guess_branch_prob
#endif
#ifdef GENERATOR_FILE
extern int flag_hoist_adjacent_loads;
#else
  int x_flag_hoist_adjacent_loads;
#define flag_hoist_adjacent_loads global_options.x_flag_hoist_adjacent_loads
#endif
#ifdef GENERATOR_FILE
extern int flag_no_ident;
#else
  int x_flag_no_ident;
#define flag_no_ident global_options.x_flag_no_ident
#endif
#ifdef GENERATOR_FILE
extern int flag_if_conversion;
#else
  int x_flag_if_conversion;
#define flag_if_conversion global_options.x_flag_if_conversion
#endif
#ifdef GENERATOR_FILE
extern int flag_if_conversion2;
#else
  int x_flag_if_conversion2;
#define flag_if_conversion2 global_options.x_flag_if_conversion2
#endif
#ifdef GENERATOR_FILE
extern int flag_implement_inlines;
#else
  int x_flag_implement_inlines;
#define flag_implement_inlines global_options.x_flag_implement_inlines
#endif
#ifdef GENERATOR_FILE
extern int flag_implicit_inline_templates;
#else
  int x_flag_implicit_inline_templates;
#define flag_implicit_inline_templates global_options.x_flag_implicit_inline_templates
#endif
#ifdef GENERATOR_FILE
extern int flag_implicit_none;
#else
  int x_flag_implicit_none;
#define flag_implicit_none global_options.x_flag_implicit_none
#endif
#ifdef GENERATOR_FILE
extern int flag_implicit_templates;
#else
  int x_flag_implicit_templates;
#define flag_implicit_templates global_options.x_flag_implicit_templates
#endif
#ifdef GENERATOR_FILE
extern int flag_indirect_inlining;
#else
  int x_flag_indirect_inlining;
#define flag_indirect_inlining global_options.x_flag_indirect_inlining
#endif
#ifdef GENERATOR_FILE
extern int flag_inhibit_size_directive;
#else
  int x_flag_inhibit_size_directive;
#define flag_inhibit_size_directive global_options.x_flag_inhibit_size_directive
#endif
#ifdef GENERATOR_FILE
extern int flag_init_derived;
#else
  int x_flag_init_derived;
#define flag_init_derived global_options.x_flag_init_derived
#endif
#ifdef GENERATOR_FILE
extern enum gfc_init_local_real flag_init_real;
#else
  enum gfc_init_local_real x_flag_init_real;
#define flag_init_real global_options.x_flag_init_real
#endif
#ifdef GENERATOR_FILE
extern int flag_no_inline;
#else
  int x_flag_no_inline;
#define flag_no_inline global_options.x_flag_no_inline
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_atomics;
#else
  int x_flag_inline_atomics;
#define flag_inline_atomics global_options.x_flag_inline_atomics
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_functions;
#else
  int x_flag_inline_functions;
#define flag_inline_functions global_options.x_flag_inline_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_functions_called_once;
#else
  int x_flag_inline_functions_called_once;
#define flag_inline_functions_called_once global_options.x_flag_inline_functions_called_once
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_matmul_limit;
#else
  int x_flag_inline_matmul_limit;
#define flag_inline_matmul_limit global_options.x_flag_inline_matmul_limit
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_small_functions;
#else
  int x_flag_inline_small_functions;
#define flag_inline_small_functions global_options.x_flag_inline_small_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_instrument_function_entry_exit;
#else
  int x_flag_instrument_function_entry_exit;
#define flag_instrument_function_entry_exit global_options.x_flag_instrument_function_entry_exit
#endif
#ifdef GENERATOR_FILE
extern int flag_integer4_kind;
#else
  int x_flag_integer4_kind;
#define flag_integer4_kind global_options.x_flag_integer4_kind
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_bit_cp;
#else
  int x_flag_ipa_bit_cp;
#define flag_ipa_bit_cp global_options.x_flag_ipa_bit_cp
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_cp;
#else
  int x_flag_ipa_cp;
#define flag_ipa_cp global_options.x_flag_ipa_cp
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_cp_clone;
#else
  int x_flag_ipa_cp_clone;
#define flag_ipa_cp_clone global_options.x_flag_ipa_cp_clone
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_icf;
#else
  int x_flag_ipa_icf;
#define flag_ipa_icf global_options.x_flag_ipa_icf
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_icf_functions;
#else
  int x_flag_ipa_icf_functions;
#define flag_ipa_icf_functions global_options.x_flag_ipa_icf_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_icf_variables;
#else
  int x_flag_ipa_icf_variables;
#define flag_ipa_icf_variables global_options.x_flag_ipa_icf_variables
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_profile;
#else
  int x_flag_ipa_profile;
#define flag_ipa_profile global_options.x_flag_ipa_profile
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_pta;
#else
  int x_flag_ipa_pta;
#define flag_ipa_pta global_options.x_flag_ipa_pta
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_pure_const;
#else
  int x_flag_ipa_pure_const;
#define flag_ipa_pure_const global_options.x_flag_ipa_pure_const
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_ra;
#else
  int x_flag_ipa_ra;
#define flag_ipa_ra global_options.x_flag_ipa_ra
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_reference;
#else
  int x_flag_ipa_reference;
#define flag_ipa_reference global_options.x_flag_ipa_reference
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_sra;
#else
  int x_flag_ipa_sra;
#define flag_ipa_sra global_options.x_flag_ipa_sra
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_vrp;
#else
  int x_flag_ipa_vrp;
#define flag_ipa_vrp global_options.x_flag_ipa_vrp
#endif
#ifdef GENERATOR_FILE
extern enum ira_algorithm flag_ira_algorithm;
#else
  enum ira_algorithm x_flag_ira_algorithm;
#define flag_ira_algorithm global_options.x_flag_ira_algorithm
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_hoist_pressure;
#else
  int x_flag_ira_hoist_pressure;
#define flag_ira_hoist_pressure global_options.x_flag_ira_hoist_pressure
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_loop_pressure;
#else
  int x_flag_ira_loop_pressure;
#define flag_ira_loop_pressure global_options.x_flag_ira_loop_pressure
#endif
#ifdef GENERATOR_FILE
extern enum ira_region flag_ira_region;
#else
  enum ira_region x_flag_ira_region;
#define flag_ira_region global_options.x_flag_ira_region
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_share_save_slots;
#else
  int x_flag_ira_share_save_slots;
#define flag_ira_share_save_slots global_options.x_flag_ira_share_save_slots
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_share_spill_slots;
#else
  int x_flag_ira_share_spill_slots;
#define flag_ira_share_spill_slots global_options.x_flag_ira_share_spill_slots
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_verbose;
#else
  int x_flag_ira_verbose;
#define flag_ira_verbose global_options.x_flag_ira_verbose
#endif
#ifdef GENERATOR_FILE
extern int flag_isolate_erroneous_paths_attribute;
#else
  int x_flag_isolate_erroneous_paths_attribute;
#define flag_isolate_erroneous_paths_attribute global_options.x_flag_isolate_erroneous_paths_attribute
#endif
#ifdef GENERATOR_FILE
extern int flag_isolate_erroneous_paths_dereference;
#else
  int x_flag_isolate_erroneous_paths_dereference;
#define flag_isolate_erroneous_paths_dereference global_options.x_flag_isolate_erroneous_paths_dereference
#endif
#ifdef GENERATOR_FILE
extern enum ivar_visibility default_ivar_visibility;
#else
  enum ivar_visibility x_default_ivar_visibility;
#define default_ivar_visibility global_options.x_default_ivar_visibility
#endif
#ifdef GENERATOR_FILE
extern int flag_ivopts;
#else
  int x_flag_ivopts;
#define flag_ivopts global_options.x_flag_ivopts
#endif
#ifdef GENERATOR_FILE
extern int flag_jump_tables;
#else
  int x_flag_jump_tables;
#define flag_jump_tables global_options.x_flag_jump_tables
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_gc_roots_live;
#else
  int x_flag_keep_gc_roots_live;
#define flag_keep_gc_roots_live global_options.x_flag_keep_gc_roots_live
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_inline_dllexport;
#else
  int x_flag_keep_inline_dllexport;
#define flag_keep_inline_dllexport global_options.x_flag_keep_inline_dllexport
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_inline_functions;
#else
  int x_flag_keep_inline_functions;
#define flag_keep_inline_functions global_options.x_flag_keep_inline_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_static_consts;
#else
  int x_flag_keep_static_consts;
#define flag_keep_static_consts global_options.x_flag_keep_static_consts
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_static_functions;
#else
  int x_flag_keep_static_functions;
#define flag_keep_static_functions global_options.x_flag_keep_static_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_lax_vector_conversions;
#else
  int x_flag_lax_vector_conversions;
#define flag_lax_vector_conversions global_options.x_flag_lax_vector_conversions
#endif
#ifdef GENERATOR_FILE
extern int flag_leading_underscore;
#else
  int x_flag_leading_underscore;
#define flag_leading_underscore global_options.x_flag_leading_underscore
#endif
#ifdef GENERATOR_FILE
extern int flag_lifetime_dse;
#else
  int x_flag_lifetime_dse;
#define flag_lifetime_dse global_options.x_flag_lifetime_dse
#endif
#ifdef GENERATOR_FILE
extern int flag_limit_function_alignment;
#else
  int x_flag_limit_function_alignment;
#define flag_limit_function_alignment global_options.x_flag_limit_function_alignment
#endif
#ifdef GENERATOR_FILE
extern enum lto_linker_output flag_lto_linker_output;
#else
  enum lto_linker_output x_flag_lto_linker_output;
#define flag_lto_linker_output global_options.x_flag_lto_linker_output
#endif
#ifdef GENERATOR_FILE
extern int flag_live_range_shrinkage;
#else
  int x_flag_live_range_shrinkage;
#define flag_live_range_shrinkage global_options.x_flag_live_range_shrinkage
#endif
#ifdef GENERATOR_FILE
extern int flag_local_ivars;
#else
  int x_flag_local_ivars;
#define flag_local_ivars global_options.x_flag_local_ivars
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_interchange;
#else
  int x_flag_loop_interchange;
#define flag_loop_interchange global_options.x_flag_loop_interchange
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_nest_optimize;
#else
  int x_flag_loop_nest_optimize;
#define flag_loop_nest_optimize global_options.x_flag_loop_nest_optimize
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_parallelize_all;
#else
  int x_flag_loop_parallelize_all;
#define flag_loop_parallelize_all global_options.x_flag_loop_parallelize_all
#endif
#ifdef GENERATOR_FILE
extern int flag_unroll_jam;
#else
  int x_flag_unroll_jam;
#define flag_unroll_jam global_options.x_flag_unroll_jam
#endif
#ifdef GENERATOR_FILE
extern int flag_lra_remat;
#else
  int x_flag_lra_remat;
#define flag_lra_remat global_options.x_flag_lra_remat
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_compression_level;
#else
  int x_flag_lto_compression_level;
#define flag_lto_compression_level global_options.x_flag_lto_compression_level
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_odr_type_mering;
#else
  int x_flag_lto_odr_type_mering;
#define flag_lto_odr_type_mering global_options.x_flag_lto_odr_type_mering
#endif
#ifdef GENERATOR_FILE
extern enum lto_partition_model flag_lto_partition;
#else
  enum lto_partition_model x_flag_lto_partition;
#define flag_lto_partition global_options.x_flag_lto_partition
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_report;
#else
  int x_flag_lto_report;
#define flag_lto_report global_options.x_flag_lto_report
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_report_wpa;
#else
  int x_flag_lto_report_wpa;
#define flag_lto_report_wpa global_options.x_flag_lto_report_wpa
#endif
#ifdef GENERATOR_FILE
extern const char *flag_lto;
#else
  const char *x_flag_lto;
#define flag_lto global_options.x_flag_lto
#endif
#ifdef GENERATOR_FILE
extern int flag_ltrans;
#else
  int x_flag_ltrans;
#define flag_ltrans global_options.x_flag_ltrans
#endif
#ifdef GENERATOR_FILE
extern const char *ltrans_output_list;
#else
  const char *x_ltrans_output_list;
#define ltrans_output_list global_options.x_ltrans_output_list
#endif
#ifdef GENERATOR_FILE
extern int flag_errno_math;
#else
  int x_flag_errno_math;
#define flag_errno_math global_options.x_flag_errno_math
#endif
#ifdef GENERATOR_FILE
extern int flag_max_array_constructor;
#else
  int x_flag_max_array_constructor;
#define flag_max_array_constructor global_options.x_flag_max_array_constructor
#endif
#ifdef GENERATOR_FILE
extern int flag_max_errors;
#else
  int x_flag_max_errors;
#define flag_max_errors global_options.x_flag_max_errors
#endif
#ifdef GENERATOR_FILE
extern int flag_max_stack_var_size;
#else
  int x_flag_max_stack_var_size;
#define flag_max_stack_var_size global_options.x_flag_max_stack_var_size
#endif
#ifdef GENERATOR_FILE
extern int flag_max_subrecord_length;
#else
  int x_flag_max_subrecord_length;
#define flag_max_subrecord_length global_options.x_flag_max_subrecord_length
#endif
#ifdef GENERATOR_FILE
extern int mem_report;
#else
  int x_mem_report;
#define mem_report global_options.x_mem_report
#endif
#ifdef GENERATOR_FILE
extern int mem_report_wpa;
#else
  int x_mem_report_wpa;
#define mem_report_wpa global_options.x_mem_report_wpa
#endif
#ifdef GENERATOR_FILE
extern int flag_merge_constants;
#else
  int x_flag_merge_constants;
#define flag_merge_constants global_options.x_flag_merge_constants
#endif
#ifdef GENERATOR_FILE
extern int flag_merge_debug_strings;
#else
  int x_flag_merge_debug_strings;
#define flag_merge_debug_strings global_options.x_flag_merge_debug_strings
#endif
#ifdef GENERATOR_FILE
extern int flag_module_private;
#else
  int x_flag_module_private;
#define flag_module_private global_options.x_flag_module_private
#endif
#ifdef GENERATOR_FILE
extern int flag_modulo_sched;
#else
  int x_flag_modulo_sched;
#define flag_modulo_sched global_options.x_flag_modulo_sched
#endif
#ifdef GENERATOR_FILE
extern int flag_modulo_sched_allow_regmoves;
#else
  int x_flag_modulo_sched_allow_regmoves;
#define flag_modulo_sched_allow_regmoves global_options.x_flag_modulo_sched_allow_regmoves
#endif
#ifdef GENERATOR_FILE
extern int flag_move_loop_invariants;
#else
  int x_flag_move_loop_invariants;
#define flag_move_loop_invariants global_options.x_flag_move_loop_invariants
#endif
#ifdef GENERATOR_FILE
extern int flag_ms_extensions;
#else
  int x_flag_ms_extensions;
#define flag_ms_extensions global_options.x_flag_ms_extensions
#endif
#ifdef GENERATOR_FILE
extern int flag_new_inheriting_ctors;
#else
  int x_flag_new_inheriting_ctors;
#define flag_new_inheriting_ctors global_options.x_flag_new_inheriting_ctors
#endif
#ifdef GENERATOR_FILE
extern int flag_new_ttp;
#else
  int x_flag_new_ttp;
#define flag_new_ttp global_options.x_flag_new_ttp
#endif
#ifdef GENERATOR_FILE
extern int flag_nil_receivers;
#else
  int x_flag_nil_receivers;
#define flag_nil_receivers global_options.x_flag_nil_receivers
#endif
#ifdef GENERATOR_FILE
extern int flag_non_call_exceptions;
#else
  int x_flag_non_call_exceptions;
#define flag_non_call_exceptions global_options.x_flag_non_call_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_no_nonansi_builtin;
#else
  int x_flag_no_nonansi_builtin;
#define flag_no_nonansi_builtin global_options.x_flag_no_nonansi_builtin
#endif
#ifdef GENERATOR_FILE
extern int flag_nothrow_opt;
#else
  int x_flag_nothrow_opt;
#define flag_nothrow_opt global_options.x_flag_nothrow_opt
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_abi;
#else
  int x_flag_objc_abi;
#define flag_objc_abi global_options.x_flag_objc_abi
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_call_cxx_cdtors;
#else
  int x_flag_objc_call_cxx_cdtors;
#define flag_objc_call_cxx_cdtors global_options.x_flag_objc_call_cxx_cdtors
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_direct_dispatch;
#else
  int x_flag_objc_direct_dispatch;
#define flag_objc_direct_dispatch global_options.x_flag_objc_direct_dispatch
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_exceptions;
#else
  int x_flag_objc_exceptions;
#define flag_objc_exceptions global_options.x_flag_objc_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_gc;
#else
  int x_flag_objc_gc;
#define flag_objc_gc global_options.x_flag_objc_gc
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_nilcheck;
#else
  int x_flag_objc_nilcheck;
#define flag_objc_nilcheck global_options.x_flag_objc_nilcheck
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_sjlj_exceptions;
#else
  int x_flag_objc_sjlj_exceptions;
#define flag_objc_sjlj_exceptions global_options.x_flag_objc_sjlj_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_objc1_only;
#else
  int x_flag_objc1_only;
#define flag_objc1_only global_options.x_flag_objc1_only
#endif
#ifdef GENERATOR_FILE
extern enum offload_abi flag_offload_abi;
#else
  enum offload_abi x_flag_offload_abi;
#define flag_offload_abi global_options.x_flag_offload_abi
#endif
#ifdef GENERATOR_FILE
extern int flag_omit_frame_pointer;
#else
  int x_flag_omit_frame_pointer;
#define flag_omit_frame_pointer global_options.x_flag_omit_frame_pointer
#endif
#ifdef GENERATOR_FILE
extern int flag_openacc;
#else
  int x_flag_openacc;
#define flag_openacc global_options.x_flag_openacc
#endif
#ifdef GENERATOR_FILE
extern const char *flag_openacc_dims;
#else
  const char *x_flag_openacc_dims;
#define flag_openacc_dims global_options.x_flag_openacc_dims
#endif
#ifdef GENERATOR_FILE
extern int flag_openmp;
#else
  int x_flag_openmp;
#define flag_openmp global_options.x_flag_openmp
#endif
#ifdef GENERATOR_FILE
extern int flag_openmp_simd;
#else
  int x_flag_openmp_simd;
#define flag_openmp_simd global_options.x_flag_openmp_simd
#endif
#ifdef GENERATOR_FILE
extern int flag_opt_info;
#else
  int x_flag_opt_info;
#define flag_opt_info global_options.x_flag_opt_info
#endif
#ifdef GENERATOR_FILE
extern int flag_optimize_sibling_calls;
#else
  int x_flag_optimize_sibling_calls;
#define flag_optimize_sibling_calls global_options.x_flag_optimize_sibling_calls
#endif
#ifdef GENERATOR_FILE
extern int flag_optimize_strlen;
#else
  int x_flag_optimize_strlen;
#define flag_optimize_strlen global_options.x_flag_optimize_strlen
#endif
#ifdef GENERATOR_FILE
extern int flag_pack_derived;
#else
  int x_flag_pack_derived;
#define flag_pack_derived global_options.x_flag_pack_derived
#endif
#ifdef GENERATOR_FILE
extern int flag_pack_struct;
#else
  int x_flag_pack_struct;
#define flag_pack_struct global_options.x_flag_pack_struct
#endif
#ifdef GENERATOR_FILE
extern int flag_partial_inlining;
#else
  int x_flag_partial_inlining;
#define flag_partial_inlining global_options.x_flag_partial_inlining
#endif
#ifdef GENERATOR_FILE
extern int flag_pcc_struct_return;
#else
  int x_flag_pcc_struct_return;
#define flag_pcc_struct_return global_options.x_flag_pcc_struct_return
#endif
#ifdef GENERATOR_FILE
extern int flag_peel_loops;
#else
  int x_flag_peel_loops;
#define flag_peel_loops global_options.x_flag_peel_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_no_peephole;
#else
  int x_flag_no_peephole;
#define flag_no_peephole global_options.x_flag_no_peephole
#endif
#ifdef GENERATOR_FILE
extern int flag_peephole2;
#else
  int x_flag_peephole2;
#define flag_peephole2 global_options.x_flag_peephole2
#endif
#ifdef GENERATOR_FILE
extern int flag_permissive;
#else
  int x_flag_permissive;
#define flag_permissive global_options.x_flag_permissive
#endif
#ifdef GENERATOR_FILE
extern enum permitted_flt_eval_methods flag_permitted_flt_eval_methods;
#else
  enum permitted_flt_eval_methods x_flag_permitted_flt_eval_methods;
#define flag_permitted_flt_eval_methods global_options.x_flag_permitted_flt_eval_methods
#endif
#ifdef GENERATOR_FILE
extern int flag_plan9_extensions;
#else
  int x_flag_plan9_extensions;
#define flag_plan9_extensions global_options.x_flag_plan9_extensions
#endif
#ifdef GENERATOR_FILE
extern int flag_plt;
#else
  int x_flag_plt;
#define flag_plt global_options.x_flag_plt
#endif
#ifdef GENERATOR_FILE
extern int post_ipa_mem_report;
#else
  int x_post_ipa_mem_report;
#define post_ipa_mem_report global_options.x_post_ipa_mem_report
#endif
#ifdef GENERATOR_FILE
extern int pre_ipa_mem_report;
#else
  int x_pre_ipa_mem_report;
#define pre_ipa_mem_report global_options.x_pre_ipa_mem_report
#endif
#ifdef GENERATOR_FILE
extern int flag_predictive_commoning;
#else
  int x_flag_predictive_commoning;
#define flag_predictive_commoning global_options.x_flag_predictive_commoning
#endif
#ifdef GENERATOR_FILE
extern int flag_prefetch_loop_arrays;
#else
  int x_flag_prefetch_loop_arrays;
#define flag_prefetch_loop_arrays global_options.x_flag_prefetch_loop_arrays
#endif
#ifdef GENERATOR_FILE
extern int flag_pretty_templates;
#else
  int x_flag_pretty_templates;
#define flag_pretty_templates global_options.x_flag_pretty_templates
#endif
#ifdef GENERATOR_FILE
extern int flag_printf_return_value;
#else
  int x_flag_printf_return_value;
#define flag_printf_return_value global_options.x_flag_printf_return_value
#endif
#ifdef GENERATOR_FILE
extern int profile_flag;
#else
  int x_profile_flag;
#define profile_flag global_options.x_profile_flag
#endif
#ifdef GENERATOR_FILE
extern int profile_abs_path_flag;
#else
  int x_profile_abs_path_flag;
#define profile_abs_path_flag global_options.x_profile_abs_path_flag
#endif
#ifdef GENERATOR_FILE
extern int profile_arc_flag;
#else
  int x_profile_arc_flag;
#define profile_arc_flag global_options.x_profile_arc_flag
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_correction;
#else
  int x_flag_profile_correction;
#define flag_profile_correction global_options.x_flag_profile_correction
#endif
#ifdef GENERATOR_FILE
extern const char *profile_data_prefix;
#else
  const char *x_profile_data_prefix;
#define profile_data_prefix global_options.x_profile_data_prefix
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_reorder_functions;
#else
  int x_flag_profile_reorder_functions;
#define flag_profile_reorder_functions global_options.x_flag_profile_reorder_functions
#endif
#ifdef GENERATOR_FILE
extern int profile_report;
#else
  int x_profile_report;
#define profile_report global_options.x_profile_report
#endif
#ifdef GENERATOR_FILE
extern enum profile_update flag_profile_update;
#else
  enum profile_update x_flag_profile_update;
#define flag_profile_update global_options.x_flag_profile_update
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_use;
#else
  int x_flag_profile_use;
#define flag_profile_use global_options.x_flag_profile_use
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_values;
#else
  int x_flag_profile_values;
#define flag_profile_values global_options.x_flag_profile_values
#endif
#ifdef GENERATOR_FILE
extern int flag_protect_parens;
#else
  int x_flag_protect_parens;
#define flag_protect_parens global_options.x_flag_protect_parens
#endif
#ifdef GENERATOR_FILE
extern int flag_range_check;
#else
  int x_flag_range_check;
#define flag_range_check global_options.x_flag_range_check
#endif
#ifdef GENERATOR_FILE
extern int flag_real4_kind;
#else
  int x_flag_real4_kind;
#define flag_real4_kind global_options.x_flag_real4_kind
#endif
#ifdef GENERATOR_FILE
extern int flag_real8_kind;
#else
  int x_flag_real8_kind;
#define flag_real8_kind global_options.x_flag_real8_kind
#endif
#ifdef GENERATOR_FILE
extern int flag_realloc_lhs;
#else
  int x_flag_realloc_lhs;
#define flag_realloc_lhs global_options.x_flag_realloc_lhs
#endif
#ifdef GENERATOR_FILE
extern int flag_reciprocal_math;
#else
  int x_flag_reciprocal_math;
#define flag_reciprocal_math global_options.x_flag_reciprocal_math
#endif
#ifdef GENERATOR_FILE
extern int flag_record_gcc_switches;
#else
  int x_flag_record_gcc_switches;
#define flag_record_gcc_switches global_options.x_flag_record_gcc_switches
#endif
#ifdef GENERATOR_FILE
extern int flag_record_marker;
#else
  int x_flag_record_marker;
#define flag_record_marker global_options.x_flag_record_marker
#endif
#ifdef GENERATOR_FILE
extern int flag_recursive;
#else
  int x_flag_recursive;
#define flag_recursive global_options.x_flag_recursive
#endif
#ifdef GENERATOR_FILE
extern int flag_ree;
#else
  int x_flag_ree;
#define flag_ree global_options.x_flag_ree
#endif
#ifdef GENERATOR_FILE
extern int flag_rename_registers;
#else
  int x_flag_rename_registers;
#define flag_rename_registers global_options.x_flag_rename_registers
#endif
#ifdef GENERATOR_FILE
extern int flag_reorder_blocks;
#else
  int x_flag_reorder_blocks;
#define flag_reorder_blocks global_options.x_flag_reorder_blocks
#endif
#ifdef GENERATOR_FILE
extern enum reorder_blocks_algorithm flag_reorder_blocks_algorithm;
#else
  enum reorder_blocks_algorithm x_flag_reorder_blocks_algorithm;
#define flag_reorder_blocks_algorithm global_options.x_flag_reorder_blocks_algorithm
#endif
#ifdef GENERATOR_FILE
extern int flag_reorder_blocks_and_partition;
#else
  int x_flag_reorder_blocks_and_partition;
#define flag_reorder_blocks_and_partition global_options.x_flag_reorder_blocks_and_partition
#endif
#ifdef GENERATOR_FILE
extern int flag_reorder_functions;
#else
  int x_flag_reorder_functions;
#define flag_reorder_functions global_options.x_flag_reorder_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_repack_arrays;
#else
  int x_flag_repack_arrays;
#define flag_repack_arrays global_options.x_flag_repack_arrays
#endif
#ifdef GENERATOR_FILE
extern int flag_replace_objc_classes;
#else
  int x_flag_replace_objc_classes;
#define flag_replace_objc_classes global_options.x_flag_replace_objc_classes
#endif
#ifdef GENERATOR_FILE
extern int flag_report_bug;
#else
  int x_flag_report_bug;
#define flag_report_bug global_options.x_flag_report_bug
#endif
#ifdef GENERATOR_FILE
extern int go_require_return_statement;
#else
  int x_go_require_return_statement;
#define go_require_return_statement global_options.x_go_require_return_statement
#endif
#ifdef GENERATOR_FILE
extern int flag_rerun_cse_after_loop;
#else
  int x_flag_rerun_cse_after_loop;
#define flag_rerun_cse_after_loop global_options.x_flag_rerun_cse_after_loop
#endif
#ifdef GENERATOR_FILE
extern int flag_resched_modulo_sched;
#else
  int x_flag_resched_modulo_sched;
#define flag_resched_modulo_sched global_options.x_flag_resched_modulo_sched
#endif
#ifdef GENERATOR_FILE
extern int flag_rounding_math;
#else
  int x_flag_rounding_math;
#define flag_rounding_math global_options.x_flag_rounding_math
#endif
#ifdef GENERATOR_FILE
extern int flag_rtti;
#else
  int x_flag_rtti;
#define flag_rtti global_options.x_flag_rtti
#endif
#ifdef GENERATOR_FILE
extern int flag_sanitize_address_use_after_scope;
#else
  int x_flag_sanitize_address_use_after_scope;
#define flag_sanitize_address_use_after_scope global_options.x_flag_sanitize_address_use_after_scope
#endif
#ifdef GENERATOR_FILE
extern int flag_sanitize_undefined_trap_on_error;
#else
  int x_flag_sanitize_undefined_trap_on_error;
#define flag_sanitize_undefined_trap_on_error global_options.x_flag_sanitize_undefined_trap_on_error
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_critical_path_heuristic;
#else
  int x_flag_sched_critical_path_heuristic;
#define flag_sched_critical_path_heuristic global_options.x_flag_sched_critical_path_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_dep_count_heuristic;
#else
  int x_flag_sched_dep_count_heuristic;
#define flag_sched_dep_count_heuristic global_options.x_flag_sched_dep_count_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_group_heuristic;
#else
  int x_flag_sched_group_heuristic;
#define flag_sched_group_heuristic global_options.x_flag_sched_group_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_interblock;
#else
  int x_flag_schedule_interblock;
#define flag_schedule_interblock global_options.x_flag_schedule_interblock
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_last_insn_heuristic;
#else
  int x_flag_sched_last_insn_heuristic;
#define flag_sched_last_insn_heuristic global_options.x_flag_sched_last_insn_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_pressure;
#else
  int x_flag_sched_pressure;
#define flag_sched_pressure global_options.x_flag_sched_pressure
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_rank_heuristic;
#else
  int x_flag_sched_rank_heuristic;
#define flag_sched_rank_heuristic global_options.x_flag_sched_rank_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_speculative;
#else
  int x_flag_schedule_speculative;
#define flag_schedule_speculative global_options.x_flag_schedule_speculative
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_spec_insn_heuristic;
#else
  int x_flag_sched_spec_insn_heuristic;
#define flag_sched_spec_insn_heuristic global_options.x_flag_sched_spec_insn_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_speculative_load;
#else
  int x_flag_schedule_speculative_load;
#define flag_schedule_speculative_load global_options.x_flag_schedule_speculative_load
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_speculative_load_dangerous;
#else
  int x_flag_schedule_speculative_load_dangerous;
#define flag_schedule_speculative_load_dangerous global_options.x_flag_schedule_speculative_load_dangerous
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_stalled_insns;
#else
  int x_flag_sched_stalled_insns;
#define flag_sched_stalled_insns global_options.x_flag_sched_stalled_insns
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_stalled_insns_dep;
#else
  int x_flag_sched_stalled_insns_dep;
#define flag_sched_stalled_insns_dep global_options.x_flag_sched_stalled_insns_dep
#endif
#ifdef GENERATOR_FILE
extern int sched_verbose_param;
#else
  int x_sched_verbose_param;
#define sched_verbose_param global_options.x_sched_verbose_param
#endif
#ifdef GENERATOR_FILE
extern int flag_sched2_use_superblocks;
#else
  int x_flag_sched2_use_superblocks;
#define flag_sched2_use_superblocks global_options.x_flag_sched2_use_superblocks
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_fusion;
#else
  int x_flag_schedule_fusion;
#define flag_schedule_fusion global_options.x_flag_schedule_fusion
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_insns;
#else
  int x_flag_schedule_insns;
#define flag_schedule_insns global_options.x_flag_schedule_insns
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_insns_after_reload;
#else
  int x_flag_schedule_insns_after_reload;
#define flag_schedule_insns_after_reload global_options.x_flag_schedule_insns_after_reload
#endif
#ifdef GENERATOR_FILE
extern int flag_second_underscore;
#else
  int x_flag_second_underscore;
#define flag_second_underscore global_options.x_flag_second_underscore
#endif
#ifdef GENERATOR_FILE
extern int flag_section_anchors;
#else
  int x_flag_section_anchors;
#define flag_section_anchors global_options.x_flag_section_anchors
#endif
#ifdef GENERATOR_FILE
extern int flag_sel_sched_pipelining;
#else
  int x_flag_sel_sched_pipelining;
#define flag_sel_sched_pipelining global_options.x_flag_sel_sched_pipelining
#endif
#ifdef GENERATOR_FILE
extern int flag_sel_sched_pipelining_outer_loops;
#else
  int x_flag_sel_sched_pipelining_outer_loops;
#define flag_sel_sched_pipelining_outer_loops global_options.x_flag_sel_sched_pipelining_outer_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_sel_sched_reschedule_pipelined;
#else
  int x_flag_sel_sched_reschedule_pipelined;
#define flag_sel_sched_reschedule_pipelined global_options.x_flag_sel_sched_reschedule_pipelined
#endif
#ifdef GENERATOR_FILE
extern int flag_selective_scheduling;
#else
  int x_flag_selective_scheduling;
#define flag_selective_scheduling global_options.x_flag_selective_scheduling
#endif
#ifdef GENERATOR_FILE
extern int flag_selective_scheduling2;
#else
  int x_flag_selective_scheduling2;
#define flag_selective_scheduling2 global_options.x_flag_selective_scheduling2
#endif
#ifdef GENERATOR_FILE
extern const char *flag_self_test;
#else
  const char *x_flag_self_test;
#define flag_self_test global_options.x_flag_self_test
#endif
#ifdef GENERATOR_FILE
extern int flag_semantic_interposition;
#else
  int x_flag_semantic_interposition;
#define flag_semantic_interposition global_options.x_flag_semantic_interposition
#endif
#ifdef GENERATOR_FILE
extern int flag_short_enums;
#else
  int x_flag_short_enums;
#define flag_short_enums global_options.x_flag_short_enums
#endif
#ifdef GENERATOR_FILE
extern int flag_short_wchar;
#else
  int x_flag_short_wchar;
#define flag_short_wchar global_options.x_flag_short_wchar
#endif
#ifdef GENERATOR_FILE
extern int flag_show_column;
#else
  int x_flag_show_column;
#define flag_show_column global_options.x_flag_show_column
#endif
#ifdef GENERATOR_FILE
extern int flag_shrink_wrap;
#else
  int x_flag_shrink_wrap;
#define flag_shrink_wrap global_options.x_flag_shrink_wrap
#endif
#ifdef GENERATOR_FILE
extern int flag_shrink_wrap_separate;
#else
  int x_flag_shrink_wrap_separate;
#define flag_shrink_wrap_separate global_options.x_flag_shrink_wrap_separate
#endif
#ifdef GENERATOR_FILE
extern int flag_sign_zero;
#else
  int x_flag_sign_zero;
#define flag_sign_zero global_options.x_flag_sign_zero
#endif
#ifdef GENERATOR_FILE
extern int flag_signaling_nans;
#else
  int x_flag_signaling_nans;
#define flag_signaling_nans global_options.x_flag_signaling_nans
#endif
#ifdef GENERATOR_FILE
extern int flag_signed_bitfields;
#else
  int x_flag_signed_bitfields;
#define flag_signed_bitfields global_options.x_flag_signed_bitfields
#endif
#ifdef GENERATOR_FILE
extern int flag_signed_char;
#else
  int x_flag_signed_char;
#define flag_signed_char global_options.x_flag_signed_char
#endif
#ifdef GENERATOR_FILE
extern int flag_signed_zeros;
#else
  int x_flag_signed_zeros;
#define flag_signed_zeros global_options.x_flag_signed_zeros
#endif
#ifdef GENERATOR_FILE
extern enum vect_cost_model flag_simd_cost_model;
#else
  enum vect_cost_model x_flag_simd_cost_model;
#define flag_simd_cost_model global_options.x_flag_simd_cost_model
#endif
#ifdef GENERATOR_FILE
extern int flag_single_precision_constant;
#else
  int x_flag_single_precision_constant;
#define flag_single_precision_constant global_options.x_flag_single_precision_constant
#endif
#ifdef GENERATOR_FILE
extern int flag_sized_deallocation;
#else
  int x_flag_sized_deallocation;
#define flag_sized_deallocation global_options.x_flag_sized_deallocation
#endif
#ifdef GENERATOR_FILE
extern int flag_split_ivs_in_unroller;
#else
  int x_flag_split_ivs_in_unroller;
#define flag_split_ivs_in_unroller global_options.x_flag_split_ivs_in_unroller
#endif
#ifdef GENERATOR_FILE
extern int flag_split_loops;
#else
  int x_flag_split_loops;
#define flag_split_loops global_options.x_flag_split_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_split_paths;
#else
  int x_flag_split_paths;
#define flag_split_paths global_options.x_flag_split_paths
#endif
#ifdef GENERATOR_FILE
extern int flag_split_stack;
#else
  int x_flag_split_stack;
#define flag_split_stack global_options.x_flag_split_stack
#endif
#ifdef GENERATOR_FILE
extern int flag_split_wide_types;
#else
  int x_flag_split_wide_types;
#define flag_split_wide_types global_options.x_flag_split_wide_types
#endif
#ifdef GENERATOR_FILE
extern int flag_ssa_backprop;
#else
  int x_flag_ssa_backprop;
#define flag_ssa_backprop global_options.x_flag_ssa_backprop
#endif
#ifdef GENERATOR_FILE
extern int flag_ssa_phiopt;
#else
  int x_flag_ssa_phiopt;
#define flag_ssa_phiopt global_options.x_flag_ssa_phiopt
#endif
#ifdef GENERATOR_FILE
extern enum scalar_storage_order_kind default_sso;
#else
  enum scalar_storage_order_kind x_default_sso;
#define default_sso global_options.x_default_sso
#endif
#ifdef GENERATOR_FILE
extern int flag_stack_arrays;
#else
  int x_flag_stack_arrays;
#define flag_stack_arrays global_options.x_flag_stack_arrays
#endif
#ifdef GENERATOR_FILE
extern int flag_stack_clash_protection;
#else
  int x_flag_stack_clash_protection;
#define flag_stack_clash_protection global_options.x_flag_stack_clash_protection
#endif
#ifdef GENERATOR_FILE
extern int flag_stack_protect;
#else
  int x_flag_stack_protect;
#define flag_stack_protect global_options.x_flag_stack_protect
#endif
#ifdef GENERATOR_FILE
extern enum stack_reuse_level flag_stack_reuse;
#else
  enum stack_reuse_level x_flag_stack_reuse;
#define flag_stack_reuse global_options.x_flag_stack_reuse
#endif
#ifdef GENERATOR_FILE
extern int flag_stack_usage;
#else
  int x_flag_stack_usage;
#define flag_stack_usage global_options.x_flag_stack_usage
#endif
#ifdef GENERATOR_FILE
extern int flag_detailed_statistics;
#else
  int x_flag_detailed_statistics;
#define flag_detailed_statistics global_options.x_flag_detailed_statistics
#endif
#ifdef GENERATOR_FILE
extern int flag_stdarg_opt;
#else
  int x_flag_stdarg_opt;
#define flag_stdarg_opt global_options.x_flag_stdarg_opt
#endif
#ifdef GENERATOR_FILE
extern int flag_store_merging;
#else
  int x_flag_store_merging;
#define flag_store_merging global_options.x_flag_store_merging
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_aliasing;
#else
  int x_flag_strict_aliasing;
#define flag_strict_aliasing global_options.x_flag_strict_aliasing
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_enums;
#else
  int x_flag_strict_enums;
#define flag_strict_enums global_options.x_flag_strict_enums
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_volatile_bitfields;
#else
  int x_flag_strict_volatile_bitfields;
#define flag_strict_volatile_bitfields global_options.x_flag_strict_volatile_bitfields
#endif
#ifdef GENERATOR_FILE
extern int flag_strong_eval_order;
#else
  int x_flag_strong_eval_order;
#define flag_strong_eval_order global_options.x_flag_strong_eval_order
#endif
#ifdef GENERATOR_FILE
extern int flag_sync_libcalls;
#else
  int x_flag_sync_libcalls;
#define flag_sync_libcalls global_options.x_flag_sync_libcalls
#endif
#ifdef GENERATOR_FILE
extern int flag_syntax_only;
#else
  int x_flag_syntax_only;
#define flag_syntax_only global_options.x_flag_syntax_only
#endif
#ifdef GENERATOR_FILE
extern int template_backtrace_limit;
#else
  int x_template_backtrace_limit;
#define template_backtrace_limit global_options.x_template_backtrace_limit
#endif
#ifdef GENERATOR_FILE
extern int flag_test_coverage;
#else
  int x_flag_test_coverage;
#define flag_test_coverage global_options.x_flag_test_coverage
#endif
#ifdef GENERATOR_FILE
extern int flag_test_forall_temp;
#else
  int x_flag_test_forall_temp;
#define flag_test_forall_temp global_options.x_flag_test_forall_temp
#endif
#ifdef GENERATOR_FILE
extern int flag_thread_jumps;
#else
  int x_flag_thread_jumps;
#define flag_thread_jumps global_options.x_flag_thread_jumps
#endif
#ifdef GENERATOR_FILE
extern int flag_threadsafe_statics;
#else
  int x_flag_threadsafe_statics;
#define flag_threadsafe_statics global_options.x_flag_threadsafe_statics
#endif
#ifdef GENERATOR_FILE
extern int time_report;
#else
  int x_time_report;
#define time_report global_options.x_time_report
#endif
#ifdef GENERATOR_FILE
extern int time_report_details;
#else
  int x_time_report_details;
#define time_report_details global_options.x_time_report_details
#endif
#ifdef GENERATOR_FILE
extern enum tls_model flag_tls_default;
#else
  enum tls_model x_flag_tls_default;
#define flag_tls_default global_options.x_flag_tls_default
#endif
#ifdef GENERATOR_FILE
extern int flag_toplevel_reorder;
#else
  int x_flag_toplevel_reorder;
#define flag_toplevel_reorder global_options.x_flag_toplevel_reorder
#endif
#ifdef GENERATOR_FILE
extern int flag_tracer;
#else
  int x_flag_tracer;
#define flag_tracer global_options.x_flag_tracer
#endif
#ifdef GENERATOR_FILE
extern int flag_trampolines;
#else
  int x_flag_trampolines;
#define flag_trampolines global_options.x_flag_trampolines
#endif
#ifdef GENERATOR_FILE
extern int flag_trapping_math;
#else
  int x_flag_trapping_math;
#define flag_trapping_math global_options.x_flag_trapping_math
#endif
#ifdef GENERATOR_FILE
extern int flag_trapv;
#else
  int x_flag_trapv;
#define flag_trapv global_options.x_flag_trapv
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_bit_ccp;
#else
  int x_flag_tree_bit_ccp;
#define flag_tree_bit_ccp global_options.x_flag_tree_bit_ccp
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_builtin_call_dce;
#else
  int x_flag_tree_builtin_call_dce;
#define flag_tree_builtin_call_dce global_options.x_flag_tree_builtin_call_dce
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_ccp;
#else
  int x_flag_tree_ccp;
#define flag_tree_ccp global_options.x_flag_tree_ccp
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_ch;
#else
  int x_flag_tree_ch;
#define flag_tree_ch global_options.x_flag_tree_ch
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_coalesce_vars;
#else
  int x_flag_tree_coalesce_vars;
#define flag_tree_coalesce_vars global_options.x_flag_tree_coalesce_vars
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_copy_prop;
#else
  int x_flag_tree_copy_prop;
#define flag_tree_copy_prop global_options.x_flag_tree_copy_prop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_cselim;
#else
  int x_flag_tree_cselim;
#define flag_tree_cselim global_options.x_flag_tree_cselim
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_dce;
#else
  int x_flag_tree_dce;
#define flag_tree_dce global_options.x_flag_tree_dce
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_dom;
#else
  int x_flag_tree_dom;
#define flag_tree_dom global_options.x_flag_tree_dom
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_dse;
#else
  int x_flag_tree_dse;
#define flag_tree_dse global_options.x_flag_tree_dse
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_forwprop;
#else
  int x_flag_tree_forwprop;
#define flag_tree_forwprop global_options.x_flag_tree_forwprop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_fre;
#else
  int x_flag_tree_fre;
#define flag_tree_fre global_options.x_flag_tree_fre
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_distribute_patterns;
#else
  int x_flag_tree_loop_distribute_patterns;
#define flag_tree_loop_distribute_patterns global_options.x_flag_tree_loop_distribute_patterns
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_distribution;
#else
  int x_flag_tree_loop_distribution;
#define flag_tree_loop_distribution global_options.x_flag_tree_loop_distribution
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_if_convert;
#else
  int x_flag_tree_loop_if_convert;
#define flag_tree_loop_if_convert global_options.x_flag_tree_loop_if_convert
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_im;
#else
  int x_flag_tree_loop_im;
#define flag_tree_loop_im global_options.x_flag_tree_loop_im
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_ivcanon;
#else
  int x_flag_tree_loop_ivcanon;
#define flag_tree_loop_ivcanon global_options.x_flag_tree_loop_ivcanon
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_optimize;
#else
  int x_flag_tree_loop_optimize;
#define flag_tree_loop_optimize global_options.x_flag_tree_loop_optimize
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_vectorize;
#else
  int x_flag_tree_loop_vectorize;
#define flag_tree_loop_vectorize global_options.x_flag_tree_loop_vectorize
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_live_range_split;
#else
  int x_flag_tree_live_range_split;
#define flag_tree_live_range_split global_options.x_flag_tree_live_range_split
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_parallelize_loops;
#else
  int x_flag_tree_parallelize_loops;
#define flag_tree_parallelize_loops global_options.x_flag_tree_parallelize_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_partial_pre;
#else
  int x_flag_tree_partial_pre;
#define flag_tree_partial_pre global_options.x_flag_tree_partial_pre
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_phiprop;
#else
  int x_flag_tree_phiprop;
#define flag_tree_phiprop global_options.x_flag_tree_phiprop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_pre;
#else
  int x_flag_tree_pre;
#define flag_tree_pre global_options.x_flag_tree_pre
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_pta;
#else
  int x_flag_tree_pta;
#define flag_tree_pta global_options.x_flag_tree_pta
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_reassoc;
#else
  int x_flag_tree_reassoc;
#define flag_tree_reassoc global_options.x_flag_tree_reassoc
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_scev_cprop;
#else
  int x_flag_tree_scev_cprop;
#define flag_tree_scev_cprop global_options.x_flag_tree_scev_cprop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_sink;
#else
  int x_flag_tree_sink;
#define flag_tree_sink global_options.x_flag_tree_sink
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_slp_vectorize;
#else
  int x_flag_tree_slp_vectorize;
#define flag_tree_slp_vectorize global_options.x_flag_tree_slp_vectorize
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_slsr;
#else
  int x_flag_tree_slsr;
#define flag_tree_slsr global_options.x_flag_tree_slsr
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_sra;
#else
  int x_flag_tree_sra;
#define flag_tree_sra global_options.x_flag_tree_sra
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_switch_conversion;
#else
  int x_flag_tree_switch_conversion;
#define flag_tree_switch_conversion global_options.x_flag_tree_switch_conversion
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_tail_merge;
#else
  int x_flag_tree_tail_merge;
#define flag_tree_tail_merge global_options.x_flag_tree_tail_merge
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_ter;
#else
  int x_flag_tree_ter;
#define flag_tree_ter global_options.x_flag_tree_ter
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_vrp;
#else
  int x_flag_tree_vrp;
#define flag_tree_vrp global_options.x_flag_tree_vrp
#endif
#ifdef GENERATOR_FILE
extern int flag_unconstrained_commons;
#else
  int x_flag_unconstrained_commons;
#define flag_unconstrained_commons global_options.x_flag_unconstrained_commons
#endif
#ifdef GENERATOR_FILE
extern int flag_underscoring;
#else
  int x_flag_underscoring;
#define flag_underscoring global_options.x_flag_underscoring
#endif
#ifdef GENERATOR_FILE
extern int flag_unit_at_a_time;
#else
  int x_flag_unit_at_a_time;
#define flag_unit_at_a_time global_options.x_flag_unit_at_a_time
#endif
#ifdef GENERATOR_FILE
extern int flag_unroll_all_loops;
#else
  int x_flag_unroll_all_loops;
#define flag_unroll_all_loops global_options.x_flag_unroll_all_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_unroll_loops;
#else
  int x_flag_unroll_loops;
#define flag_unroll_loops global_options.x_flag_unroll_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_unsafe_math_optimizations;
#else
  int x_flag_unsafe_math_optimizations;
#define flag_unsafe_math_optimizations global_options.x_flag_unsafe_math_optimizations
#endif
#ifdef GENERATOR_FILE
extern int flag_unswitch_loops;
#else
  int x_flag_unswitch_loops;
#define flag_unswitch_loops global_options.x_flag_unswitch_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_unwind_tables;
#else
  int x_flag_unwind_tables;
#define flag_unwind_tables global_options.x_flag_unwind_tables
#endif
#ifdef GENERATOR_FILE
extern int flag_use_cxa_atexit;
#else
  int x_flag_use_cxa_atexit;
#define flag_use_cxa_atexit global_options.x_flag_use_cxa_atexit
#endif
#ifdef GENERATOR_FILE
extern int flag_use_cxa_get_exception_ptr;
#else
  int x_flag_use_cxa_get_exception_ptr;
#define flag_use_cxa_get_exception_ptr global_options.x_flag_use_cxa_get_exception_ptr
#endif
#ifdef GENERATOR_FILE
extern int flag_use_linker_plugin;
#else
  int x_flag_use_linker_plugin;
#define flag_use_linker_plugin global_options.x_flag_use_linker_plugin
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking;
#else
  int x_flag_var_tracking;
#define flag_var_tracking global_options.x_flag_var_tracking
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking_assignments;
#else
  int x_flag_var_tracking_assignments;
#define flag_var_tracking_assignments global_options.x_flag_var_tracking_assignments
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking_assignments_toggle;
#else
  int x_flag_var_tracking_assignments_toggle;
#define flag_var_tracking_assignments_toggle global_options.x_flag_var_tracking_assignments_toggle
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking_uninit;
#else
  int x_flag_var_tracking_uninit;
#define flag_var_tracking_uninit global_options.x_flag_var_tracking_uninit
#endif
#ifdef GENERATOR_FILE
extern int flag_variable_expansion_in_unroller;
#else
  int x_flag_variable_expansion_in_unroller;
#define flag_variable_expansion_in_unroller global_options.x_flag_variable_expansion_in_unroller
#endif
#ifdef GENERATOR_FILE
extern enum vect_cost_model flag_vect_cost_model;
#else
  enum vect_cost_model x_flag_vect_cost_model;
#define flag_vect_cost_model global_options.x_flag_vect_cost_model
#endif
#ifdef GENERATOR_FILE
extern int flag_verbose_asm;
#else
  int x_flag_verbose_asm;
#define flag_verbose_asm global_options.x_flag_verbose_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_visibility_ms_compat;
#else
  int x_flag_visibility_ms_compat;
#define flag_visibility_ms_compat global_options.x_flag_visibility_ms_compat
#endif
#ifdef GENERATOR_FILE
extern enum symbol_visibility default_visibility;
#else
  enum symbol_visibility x_default_visibility;
#define default_visibility global_options.x_default_visibility
#endif
#ifdef GENERATOR_FILE
extern int flag_value_profile_transformations;
#else
  int x_flag_value_profile_transformations;
#define flag_value_profile_transformations global_options.x_flag_value_profile_transformations
#endif
#ifdef GENERATOR_FILE
extern enum vtv_priority flag_vtable_verify;
#else
  enum vtv_priority x_flag_vtable_verify;
#define flag_vtable_verify global_options.x_flag_vtable_verify
#endif
#ifdef GENERATOR_FILE
extern int flag_vtv_counts;
#else
  int x_flag_vtv_counts;
#define flag_vtv_counts global_options.x_flag_vtv_counts
#endif
#ifdef GENERATOR_FILE
extern int flag_vtv_debug;
#else
  int x_flag_vtv_debug;
#define flag_vtv_debug global_options.x_flag_vtv_debug
#endif
#ifdef GENERATOR_FILE
extern int flag_weak;
#else
  int x_flag_weak;
#define flag_weak global_options.x_flag_weak
#endif
#ifdef GENERATOR_FILE
extern int flag_web;
#else
  int x_flag_web;
#define flag_web global_options.x_flag_web
#endif
#ifdef GENERATOR_FILE
extern int flag_whole_program;
#else
  int x_flag_whole_program;
#define flag_whole_program global_options.x_flag_whole_program
#endif
#ifdef GENERATOR_FILE
extern int flag_working_directory;
#else
  int x_flag_working_directory;
#define flag_working_directory global_options.x_flag_working_directory
#endif
#ifdef GENERATOR_FILE
extern const char *flag_wpa;
#else
  const char *x_flag_wpa;
#define flag_wpa global_options.x_flag_wpa
#endif
#ifdef GENERATOR_FILE
extern int flag_wrapv;
#else
  int x_flag_wrapv;
#define flag_wrapv global_options.x_flag_wrapv
#endif
#ifdef GENERATOR_FILE
extern int flag_wrapv_pointer;
#else
  int x_flag_wrapv_pointer;
#define flag_wrapv_pointer global_options.x_flag_wrapv_pointer
#endif
#ifdef GENERATOR_FILE
extern int flag_zero_initialized_in_bss;
#else
  int x_flag_zero_initialized_in_bss;
#define flag_zero_initialized_in_bss global_options.x_flag_zero_initialized_in_bss
#endif
#ifdef GENERATOR_FILE
extern int flag_zero_link;
#else
  int x_flag_zero_link;
#define flag_zero_link global_options.x_flag_zero_link
#endif
#ifdef GENERATOR_FILE
extern int dwarf2out_as_loc_support;
#else
  int x_dwarf2out_as_loc_support;
#define dwarf2out_as_loc_support global_options.x_dwarf2out_as_loc_support
#endif
#ifdef GENERATOR_FILE
extern int dwarf2out_as_locview_support;
#else
  int x_dwarf2out_as_locview_support;
#define dwarf2out_as_locview_support global_options.x_dwarf2out_as_locview_support
#endif
#ifdef GENERATOR_FILE
extern int debug_column_info;
#else
  int x_debug_column_info;
#define debug_column_info global_options.x_debug_column_info
#endif
#ifdef GENERATOR_FILE
extern int dwarf_version;
#else
  int x_dwarf_version;
#define dwarf_version global_options.x_dwarf_version
#endif
#ifdef GENERATOR_FILE
extern int flag_gen_declaration;
#else
  int x_flag_gen_declaration;
#define flag_gen_declaration global_options.x_flag_gen_declaration
#endif
#ifdef GENERATOR_FILE
extern int debug_generate_pub_sections;
#else
  int x_debug_generate_pub_sections;
#define debug_generate_pub_sections global_options.x_debug_generate_pub_sections
#endif
#ifdef GENERATOR_FILE
extern int debug_inline_points;
#else
  int x_debug_inline_points;
#define debug_inline_points global_options.x_debug_inline_points
#endif
#ifdef GENERATOR_FILE
extern int debug_internal_reset_location_views;
#else
  int x_debug_internal_reset_location_views;
#define debug_internal_reset_location_views global_options.x_debug_internal_reset_location_views
#endif
#ifdef GENERATOR_FILE
extern int dwarf_record_gcc_switches;
#else
  int x_dwarf_record_gcc_switches;
#define dwarf_record_gcc_switches global_options.x_dwarf_record_gcc_switches
#endif
#ifdef GENERATOR_FILE
extern int dwarf_split_debug_info;
#else
  int x_dwarf_split_debug_info;
#define dwarf_split_debug_info global_options.x_dwarf_split_debug_info
#endif
#ifdef GENERATOR_FILE
extern int debug_nonbind_markers_p;
#else
  int x_debug_nonbind_markers_p;
#define debug_nonbind_markers_p global_options.x_debug_nonbind_markers_p
#endif
#ifdef GENERATOR_FILE
extern int dwarf_strict;
#else
  int x_dwarf_strict;
#define dwarf_strict global_options.x_dwarf_strict
#endif
#ifdef GENERATOR_FILE
extern int flag_gtoggle;
#else
  int x_flag_gtoggle;
#define flag_gtoggle global_options.x_flag_gtoggle
#endif
#ifdef GENERATOR_FILE
extern int debug_variable_location_views;
#else
  int x_debug_variable_location_views;
#define debug_variable_location_views global_options.x_debug_variable_location_views
#endif
#ifdef GENERATOR_FILE
extern const char *imultiarch;
#else
  const char *x_imultiarch;
#define imultiarch global_options.x_imultiarch
#endif
#ifdef GENERATOR_FILE
extern const char *plugindir_string;
#else
  const char *x_plugindir_string;
#define plugindir_string global_options.x_plugindir_string
#endif
#ifdef GENERATOR_FILE
extern int mips_abi;
#else
  int x_mips_abi;
#define mips_abi global_options.x_mips_abi
#endif
#ifdef GENERATOR_FILE
extern int mips_abs;
#else
  int x_mips_abs;
#define mips_abs global_options.x_mips_abs
#endif
#ifdef GENERATOR_FILE
extern int flag_android;
#else
  int x_flag_android;
#define flag_android global_options.x_flag_android
#endif
#ifdef GENERATOR_FILE
extern int mips_arch_option;
#else
  int x_mips_arch_option;
#define mips_arch_option global_options.x_mips_arch_option
#endif
#ifdef GENERATOR_FILE
extern int linux_libc;
#else
  int x_linux_libc;
#define linux_libc global_options.x_linux_libc
#endif
#ifdef GENERATOR_FILE
extern int mips_branch_cost;
#else
  int x_mips_branch_cost;
#define mips_branch_cost global_options.x_mips_branch_cost
#endif
#ifdef GENERATOR_FILE
extern enum mips_code_readable_setting mips_code_readable;
#else
  enum mips_code_readable_setting x_mips_code_readable;
#define mips_code_readable global_options.x_mips_code_readable
#endif
#ifdef GENERATOR_FILE
extern enum mips_cb_setting mips_cb;
#else
  enum mips_cb_setting x_mips_cb;
#define mips_cb global_options.x_mips_cb
#endif
#ifdef GENERATOR_FILE
extern int TARGET_DEBUG_MODE;
#else
  int x_TARGET_DEBUG_MODE;
#define TARGET_DEBUG_MODE global_options.x_TARGET_DEBUG_MODE
#endif
#ifdef GENERATOR_FILE
extern int TARGET_DEBUG_D_MODE;
#else
  int x_TARGET_DEBUG_D_MODE;
#define TARGET_DEBUG_D_MODE global_options.x_TARGET_DEBUG_D_MODE
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MDMX;
#else
  int x_TARGET_MDMX;
#define TARGET_MDMX global_options.x_TARGET_MDMX
#endif
#ifdef GENERATOR_FILE
extern int TARGET_DSP;
#else
  int x_TARGET_DSP;
#define TARGET_DSP global_options.x_TARGET_DSP
#endif
#ifdef GENERATOR_FILE
extern int TARGET_DSPR2;
#else
  int x_TARGET_DSPR2;
#define TARGET_DSPR2 global_options.x_TARGET_DSPR2
#endif
#ifdef GENERATOR_FILE
extern int TARGET_EMBEDDED_DATA;
#else
  int x_TARGET_EMBEDDED_DATA;
#define TARGET_EMBEDDED_DATA global_options.x_TARGET_EMBEDDED_DATA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_EVA;
#else
  int x_TARGET_EVA;
#define TARGET_EVA global_options.x_TARGET_EVA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_EXTERN_SDATA;
#else
  int x_TARGET_EXTERN_SDATA;
#define TARGET_EXTERN_SDATA global_options.x_TARGET_EXTERN_SDATA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FIX_24K;
#else
  int x_TARGET_FIX_24K;
#define TARGET_FIX_24K global_options.x_TARGET_FIX_24K
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FIX_RM7000;
#else
  int x_TARGET_FIX_RM7000;
#define TARGET_FIX_RM7000 global_options.x_TARGET_FIX_RM7000
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FIX_SB1;
#else
  int x_TARGET_FIX_SB1;
#define TARGET_FIX_SB1 global_options.x_TARGET_FIX_SB1
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FIX_VR4120;
#else
  int x_TARGET_FIX_VR4120;
#define TARGET_FIX_VR4120 global_options.x_TARGET_FIX_VR4120
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FIX_VR4130;
#else
  int x_TARGET_FIX_VR4130;
#define TARGET_FIX_VR4130 global_options.x_TARGET_FIX_VR4130
#endif
#ifdef GENERATOR_FILE
extern int TARGET_4300_MUL_FIX;
#else
  int x_TARGET_4300_MUL_FIX;
#define TARGET_4300_MUL_FIX global_options.x_TARGET_4300_MUL_FIX
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FLIP_MIPS16;
#else
  int x_TARGET_FLIP_MIPS16;
#define TARGET_FLIP_MIPS16 global_options.x_TARGET_FLIP_MIPS16
#endif
#ifdef GENERATOR_FILE
extern const char *mips_cache_flush_func;
#else
  const char *x_mips_cache_flush_func;
#define mips_cache_flush_func global_options.x_mips_cache_flush_func
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FP_EXCEPTIONS;
#else
  int x_TARGET_FP_EXCEPTIONS;
#define TARGET_FP_EXCEPTIONS global_options.x_TARGET_FP_EXCEPTIONS
#endif
#ifdef GENERATOR_FILE
extern int flag_frame_header_optimization;
#else
  int x_flag_frame_header_optimization;
#define flag_frame_header_optimization global_options.x_flag_frame_header_optimization
#endif
#ifdef GENERATOR_FILE
extern int TARGET_GPOPT;
#else
  int x_TARGET_GPOPT;
#define TARGET_GPOPT global_options.x_TARGET_GPOPT
#endif
#ifdef GENERATOR_FILE
extern int TARGET_INTERLINK_COMPRESSED;
#else
  int x_TARGET_INTERLINK_COMPRESSED;
#define TARGET_INTERLINK_COMPRESSED global_options.x_TARGET_INTERLINK_COMPRESSED
#endif
#ifdef GENERATOR_FILE
extern int mips_isa_option;
#else
  int x_mips_isa_option;
#define mips_isa_option global_options.x_mips_isa_option
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MIPS3D;
#else
  int x_TARGET_MIPS3D;
#define TARGET_MIPS3D global_options.x_TARGET_MIPS3D
#endif
#ifdef GENERATOR_FILE
extern int TARGET_LOAD_STORE_PAIRS;
#else
  int x_TARGET_LOAD_STORE_PAIRS;
#define TARGET_LOAD_STORE_PAIRS global_options.x_TARGET_LOAD_STORE_PAIRS
#endif
#ifdef GENERATOR_FILE
extern int TARGET_LOCAL_SDATA;
#else
  int x_TARGET_LOCAL_SDATA;
#define TARGET_LOCAL_SDATA global_options.x_TARGET_LOCAL_SDATA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_LONG_CALLS;
#else
  int x_TARGET_LONG_CALLS;
#define TARGET_LONG_CALLS global_options.x_TARGET_LONG_CALLS
#endif
#ifdef GENERATOR_FILE
extern int mips_lra_flag;
#else
  int x_mips_lra_flag;
#define mips_lra_flag global_options.x_mips_lra_flag
#endif
#ifdef GENERATOR_FILE
extern int mips_lxc1_sxc1;
#else
  int x_mips_lxc1_sxc1;
#define mips_lxc1_sxc1 global_options.x_mips_lxc1_sxc1
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MAD;
#else
  int x_TARGET_MAD;
#define TARGET_MAD global_options.x_TARGET_MAD
#endif
#ifdef GENERATOR_FILE
extern int mips_madd4;
#else
  int x_mips_madd4;
#define mips_madd4 global_options.x_mips_madd4
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MCOUNT_RA_ADDRESS;
#else
  int x_TARGET_MCOUNT_RA_ADDRESS;
#define TARGET_MCOUNT_RA_ADDRESS global_options.x_TARGET_MCOUNT_RA_ADDRESS
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MCU;
#else
  int x_TARGET_MCU;
#define TARGET_MCU global_options.x_TARGET_MCU
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MSA;
#else
  int x_TARGET_MSA;
#define TARGET_MSA global_options.x_TARGET_MSA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MT;
#else
  int x_TARGET_MT;
#define TARGET_MT global_options.x_TARGET_MT
#endif
#ifdef GENERATOR_FILE
extern int mips_nan;
#else
  int x_mips_nan;
#define mips_nan global_options.x_mips_nan
#endif
#ifdef GENERATOR_FILE
extern int TARGET_NO_FLOAT;
#else
  int x_TARGET_NO_FLOAT;
#define TARGET_NO_FLOAT global_options.x_TARGET_NO_FLOAT
#endif
#ifdef GENERATOR_FILE
extern int TARGET_PLT;
#else
  int x_TARGET_PLT;
#define TARGET_PLT global_options.x_TARGET_PLT
#endif
#ifdef GENERATOR_FILE
extern enum mips_r10k_cache_barrier_setting mips_r10k_cache_barrier;
#else
  enum mips_r10k_cache_barrier_setting x_mips_r10k_cache_barrier;
#define mips_r10k_cache_barrier global_options.x_mips_r10k_cache_barrier
#endif
#ifdef GENERATOR_FILE
extern int TARGET_SHARED;
#else
  int x_TARGET_SHARED;
#define TARGET_SHARED global_options.x_TARGET_SHARED
#endif
#ifdef GENERATOR_FILE
extern int TARGET_SYM32;
#else
  int x_TARGET_SYM32;
#define TARGET_SYM32 global_options.x_TARGET_SYM32
#endif
#ifdef GENERATOR_FILE
extern int mips_tune_option;
#else
  int x_mips_tune_option;
#define mips_tune_option global_options.x_mips_tune_option
#endif
#ifdef GENERATOR_FILE
extern int TARGET_UNINIT_CONST_IN_RODATA;
#else
  int x_TARGET_UNINIT_CONST_IN_RODATA;
#define TARGET_UNINIT_CONST_IN_RODATA global_options.x_TARGET_UNINIT_CONST_IN_RODATA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_VIRT;
#else
  int x_TARGET_VIRT;
#define TARGET_VIRT global_options.x_TARGET_VIRT
#endif
#ifdef GENERATOR_FILE
extern int TARGET_XGOT;
#else
  int x_TARGET_XGOT;
#define TARGET_XGOT global_options.x_TARGET_XGOT
#endif
#ifdef GENERATOR_FILE
extern int TARGET_XPA;
#else
  int x_TARGET_XPA;
#define TARGET_XPA global_options.x_TARGET_XPA
#endif
#ifdef GENERATOR_FILE
extern const char *asm_file_name;
#else
  const char *x_asm_file_name;
#define asm_file_name global_options.x_asm_file_name
#endif
#ifdef GENERATOR_FILE
extern int pass_exit_codes;
#else
  int x_pass_exit_codes;
#define pass_exit_codes global_options.x_pass_exit_codes
#endif
#ifdef GENERATOR_FILE
extern int flag_pedantic_errors;
#else
  int x_flag_pedantic_errors;
#define flag_pedantic_errors global_options.x_flag_pedantic_errors
#endif
#ifdef GENERATOR_FILE
extern int use_pipes;
#else
  int x_use_pipes;
#define use_pipes global_options.x_use_pipes
#endif
#ifdef GENERATOR_FILE
extern const char *print_file_name;
#else
  const char *x_print_file_name;
#define print_file_name global_options.x_print_file_name
#endif
#ifdef GENERATOR_FILE
extern int print_multi_directory;
#else
  int x_print_multi_directory;
#define print_multi_directory global_options.x_print_multi_directory
#endif
#ifdef GENERATOR_FILE
extern int print_multi_lib;
#else
  int x_print_multi_lib;
#define print_multi_lib global_options.x_print_multi_lib
#endif
#ifdef GENERATOR_FILE
extern int print_multi_os_directory;
#else
  int x_print_multi_os_directory;
#define print_multi_os_directory global_options.x_print_multi_os_directory
#endif
#ifdef GENERATOR_FILE
extern int print_multiarch;
#else
  int x_print_multiarch;
#define print_multiarch global_options.x_print_multiarch
#endif
#ifdef GENERATOR_FILE
extern const char *print_prog_name;
#else
  const char *x_print_prog_name;
#define print_prog_name global_options.x_print_prog_name
#endif
#ifdef GENERATOR_FILE
extern int print_search_dirs;
#else
  int x_print_search_dirs;
#define print_search_dirs global_options.x_print_search_dirs
#endif
#ifdef GENERATOR_FILE
extern int print_sysroot;
#else
  int x_print_sysroot;
#define print_sysroot global_options.x_print_sysroot
#endif
#ifdef GENERATOR_FILE
extern int print_sysroot_headers_suffix;
#else
  int x_print_sysroot_headers_suffix;
#define print_sysroot_headers_suffix global_options.x_print_sysroot_headers_suffix
#endif
#ifdef GENERATOR_FILE
extern int quiet_flag;
#else
  int x_quiet_flag;
#define quiet_flag global_options.x_quiet_flag
#endif
#ifdef GENERATOR_FILE
extern int report_times;
#else
  int x_report_times;
#define report_times global_options.x_report_times
#endif
#ifdef GENERATOR_FILE
extern int flag_undef;
#else
  int x_flag_undef;
#define flag_undef global_options.x_flag_undef
#endif
#ifdef GENERATOR_FILE
extern int verbose_flag;
#else
  int x_verbose_flag;
#define verbose_flag global_options.x_verbose_flag
#endif
#ifdef GENERATOR_FILE
extern int version_flag;
#else
  int x_version_flag;
#define version_flag global_options.x_version_flag
#endif
#ifdef GENERATOR_FILE
extern int inhibit_warnings;
#else
  int x_inhibit_warnings;
#define inhibit_warnings global_options.x_inhibit_warnings
#endif
#ifdef GENERATOR_FILE
extern const char *wrapper_string;
#else
  const char *x_wrapper_string;
#define wrapper_string global_options.x_wrapper_string
#endif
#ifndef GENERATOR_FILE
  int x_VAR_mno_flush_func;
#define x_VAR_mno_flush_func do_not_use
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_associative_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_cx_limited_range;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_excess_precision_cmdline;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_finite_math_only;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_errno_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_reciprocal_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_rounding_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_signaling_nans;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_signed_zeros;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_trapping_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_unsafe_math_optimizations;
#endif
#ifndef GENERATOR_FILE
};
extern struct gcc_options global_options;
extern const struct gcc_options global_options_init;
extern struct gcc_options global_options_set;
#define target_flags_explicit global_options_set.x_target_flags
#endif
#endif

#if !defined(IN_LIBGCC2) && !defined(IN_TARGET_LIBS) && !defined(IN_RTS)

/* Structure to save/restore optimization and target specific options.  */
struct GTY(()) cl_optimization
{
  int x_align_functions;
  int x_align_jumps;
  int x_align_labels;
  int x_align_loops;
  int x_flag_sched_stalled_insns;
  int x_flag_sched_stalled_insns_dep;
  int x_flag_tree_parallelize_loops;
  enum fp_contract_mode x_flag_fp_contract_mode;
  enum ira_algorithm x_flag_ira_algorithm;
  enum ira_region x_flag_ira_region;
  enum reorder_blocks_algorithm x_flag_reorder_blocks_algorithm;
  enum vect_cost_model x_flag_simd_cost_model;
  enum stack_reuse_level x_flag_stack_reuse;
  enum vect_cost_model x_flag_vect_cost_model;
  unsigned char x_optimize;
  unsigned char x_optimize_size;
  unsigned char x_optimize_debug;
  unsigned char x_optimize_fast;
  signed char x_flag_aggressive_loop_optimizations;
  signed char x_flag_associative_math;
  signed char x_flag_asynchronous_unwind_tables;
  signed char x_flag_auto_inc_dec;
  signed char x_flag_branch_on_count_reg;
  signed char x_flag_branch_probabilities;
  signed char x_flag_branch_target_load_optimize;
  signed char x_flag_branch_target_load_optimize2;
  signed char x_flag_btr_bb_exclusive;
  signed char x_flag_caller_saves;
  signed char x_flag_code_hoisting;
  signed char x_flag_combine_stack_adjustments;
  signed char x_flag_compare_elim_after_reload;
  signed char x_flag_conserve_stack;
  signed char x_flag_cprop_registers;
  signed char x_flag_crossjumping;
  signed char x_flag_cse_follow_jumps;
  signed char x_flag_cx_fortran_rules;
  signed char x_flag_cx_limited_range;
  signed char x_flag_dce;
  signed char x_flag_defer_pop;
  signed char x_flag_delayed_branch;
  signed char x_flag_delete_dead_exceptions;
  signed char x_flag_delete_null_pointer_checks;
  signed char x_flag_devirtualize;
  signed char x_flag_devirtualize_speculatively;
  signed char x_flag_dse;
  signed char x_flag_early_inlining;
  signed char x_flag_exceptions;
  signed char x_flag_expensive_optimizations;
  signed char x_flag_finite_math_only;
  signed char x_flag_float_store;
  signed char x_flag_forward_propagate;
  signed char x_flag_fp_int_builtin_inexact;
  signed char x_flag_no_function_cse;
  signed char x_flag_gcse;
  signed char x_flag_gcse_after_reload;
  signed char x_flag_gcse_las;
  signed char x_flag_gcse_lm;
  signed char x_flag_gcse_sm;
  signed char x_flag_graphite;
  signed char x_flag_graphite_identity;
  signed char x_flag_guess_branch_prob;
  signed char x_flag_hoist_adjacent_loads;
  signed char x_flag_if_conversion;
  signed char x_flag_if_conversion2;
  signed char x_flag_indirect_inlining;
  signed char x_flag_no_inline;
  signed char x_flag_inline_atomics;
  signed char x_flag_inline_functions;
  signed char x_flag_inline_functions_called_once;
  signed char x_flag_inline_small_functions;
  signed char x_flag_ipa_bit_cp;
  signed char x_flag_ipa_cp;
  signed char x_flag_ipa_cp_clone;
  signed char x_flag_ipa_icf;
  signed char x_flag_ipa_icf_functions;
  signed char x_flag_ipa_icf_variables;
  signed char x_flag_ipa_profile;
  signed char x_flag_ipa_pta;
  signed char x_flag_ipa_pure_const;
  signed char x_flag_ipa_ra;
  signed char x_flag_ipa_reference;
  signed char x_flag_ipa_sra;
  signed char x_flag_ipa_vrp;
  signed char x_flag_ira_hoist_pressure;
  signed char x_flag_ira_loop_pressure;
  signed char x_flag_ira_share_save_slots;
  signed char x_flag_ira_share_spill_slots;
  signed char x_flag_isolate_erroneous_paths_attribute;
  signed char x_flag_isolate_erroneous_paths_dereference;
  signed char x_flag_ivopts;
  signed char x_flag_jump_tables;
  signed char x_flag_keep_gc_roots_live;
  signed char x_flag_lifetime_dse;
  signed char x_flag_limit_function_alignment;
  signed char x_flag_live_range_shrinkage;
  signed char x_flag_loop_interchange;
  signed char x_flag_loop_nest_optimize;
  signed char x_flag_loop_parallelize_all;
  signed char x_flag_unroll_jam;
  signed char x_flag_lra_remat;
  signed char x_flag_errno_math;
  signed char x_flag_modulo_sched;
  signed char x_flag_modulo_sched_allow_regmoves;
  signed char x_flag_move_loop_invariants;
  signed char x_flag_non_call_exceptions;
  signed char x_flag_nothrow_opt;
  signed char x_flag_omit_frame_pointer;
  signed char x_flag_opt_info;
  signed char x_flag_optimize_sibling_calls;
  signed char x_flag_optimize_strlen;
  signed char x_flag_pack_struct;
  signed char x_flag_partial_inlining;
  signed char x_flag_peel_loops;
  signed char x_flag_no_peephole;
  signed char x_flag_peephole2;
  signed char x_flag_plt;
  signed char x_flag_predictive_commoning;
  signed char x_flag_prefetch_loop_arrays;
  signed char x_flag_printf_return_value;
  signed char x_flag_reciprocal_math;
  signed char x_flag_pcc_struct_return;
  signed char x_flag_rename_registers;
  signed char x_flag_reorder_blocks;
  signed char x_flag_reorder_blocks_and_partition;
  signed char x_flag_reorder_functions;
  signed char x_flag_rerun_cse_after_loop;
  signed char x_flag_resched_modulo_sched;
  signed char x_flag_rounding_math;
  signed char x_flag_rtti;
  signed char x_flag_sched_critical_path_heuristic;
  signed char x_flag_sched_dep_count_heuristic;
  signed char x_flag_sched_group_heuristic;
  signed char x_flag_schedule_interblock;
  signed char x_flag_sched_last_insn_heuristic;
  signed char x_flag_sched_pressure;
  signed char x_flag_sched_rank_heuristic;
  signed char x_flag_schedule_speculative;
  signed char x_flag_sched_spec_insn_heuristic;
  signed char x_flag_schedule_speculative_load;
  signed char x_flag_schedule_speculative_load_dangerous;
  signed char x_flag_sched2_use_superblocks;
  signed char x_flag_schedule_fusion;
  signed char x_flag_schedule_insns;
  signed char x_flag_schedule_insns_after_reload;
  signed char x_flag_section_anchors;
  signed char x_flag_sel_sched_pipelining;
  signed char x_flag_sel_sched_pipelining_outer_loops;
  signed char x_flag_sel_sched_reschedule_pipelined;
  signed char x_flag_selective_scheduling;
  signed char x_flag_selective_scheduling2;
  signed char x_flag_short_enums;
  signed char x_flag_short_wchar;
  signed char x_flag_shrink_wrap;
  signed char x_flag_shrink_wrap_separate;
  signed char x_flag_signaling_nans;
  signed char x_flag_signed_zeros;
  signed char x_flag_single_precision_constant;
  signed char x_flag_split_ivs_in_unroller;
  signed char x_flag_split_loops;
  signed char x_flag_split_paths;
  signed char x_flag_split_wide_types;
  signed char x_flag_ssa_backprop;
  signed char x_flag_ssa_phiopt;
  signed char x_flag_stack_clash_protection;
  signed char x_flag_stack_protect;
  signed char x_flag_stdarg_opt;
  signed char x_flag_store_merging;
  signed char x_flag_strict_aliasing;
  signed char x_flag_strict_enums;
  signed char x_flag_strict_volatile_bitfields;
  signed char x_flag_thread_jumps;
  signed char x_flag_threadsafe_statics;
  signed char x_flag_tracer;
  signed char x_flag_trapping_math;
  signed char x_flag_trapv;
  signed char x_flag_tree_bit_ccp;
  signed char x_flag_tree_builtin_call_dce;
  signed char x_flag_tree_ccp;
  signed char x_flag_tree_ch;
  signed char x_flag_tree_coalesce_vars;
  signed char x_flag_tree_copy_prop;
  signed char x_flag_tree_cselim;
  signed char x_flag_tree_dce;
  signed char x_flag_tree_dom;
  signed char x_flag_tree_dse;
  signed char x_flag_tree_forwprop;
  signed char x_flag_tree_fre;
  signed char x_flag_tree_loop_distribute_patterns;
  signed char x_flag_tree_loop_distribution;
  signed char x_flag_tree_loop_if_convert;
  signed char x_flag_tree_loop_im;
  signed char x_flag_tree_loop_ivcanon;
  signed char x_flag_tree_loop_optimize;
  signed char x_flag_tree_loop_vectorize;
  signed char x_flag_tree_live_range_split;
  signed char x_flag_tree_partial_pre;
  signed char x_flag_tree_phiprop;
  signed char x_flag_tree_pre;
  signed char x_flag_tree_pta;
  signed char x_flag_tree_reassoc;
  signed char x_flag_tree_scev_cprop;
  signed char x_flag_tree_sink;
  signed char x_flag_tree_slp_vectorize;
  signed char x_flag_tree_slsr;
  signed char x_flag_tree_sra;
  signed char x_flag_tree_switch_conversion;
  signed char x_flag_tree_tail_merge;
  signed char x_flag_tree_ter;
  signed char x_flag_tree_vrp;
  signed char x_flag_unconstrained_commons;
  signed char x_flag_unroll_all_loops;
  signed char x_flag_unroll_loops;
  signed char x_flag_unsafe_math_optimizations;
  signed char x_flag_unswitch_loops;
  signed char x_flag_unwind_tables;
  signed char x_flag_var_tracking;
  signed char x_flag_var_tracking_assignments;
  signed char x_flag_var_tracking_assignments_toggle;
  signed char x_flag_var_tracking_uninit;
  signed char x_flag_variable_expansion_in_unroller;
  signed char x_flag_value_profile_transformations;
  signed char x_flag_web;
  signed char x_flag_wrapv;
  signed char x_flag_wrapv_pointer;
  signed char x_flag_frame_header_optimization;
};

/* Structure to save/restore selected target specific options.  */
struct GTY(()) cl_target_option
{
  signed char x_mips_lra_flag;
};


/* Save optimization variables into a structure.  */
extern void cl_optimization_save (struct cl_optimization *, struct gcc_options *);

/* Restore optimization variables from a structure.  */
extern void cl_optimization_restore (struct gcc_options *, struct cl_optimization *);

/* Print optimization variables from a structure.  */
extern void cl_optimization_print (FILE *, int, struct cl_optimization *);

/* Print different optimization variables from structures provided as arguments.  */
extern void cl_optimization_print_diff (FILE *, int, cl_optimization *ptr1, cl_optimization *ptr2);

/* Save selected option variables into a structure.  */
extern void cl_target_option_save (struct cl_target_option *, struct gcc_options *);

/* Restore selected option variables from a structure.  */
extern void cl_target_option_restore (struct gcc_options *, struct cl_target_option *);

/* Print target option variables from a structure.  */
extern void cl_target_option_print (FILE *, int, struct cl_target_option *);

/* Print different target option variables from structures provided as arguments.  */
extern void cl_target_option_print_diff (FILE *, int, cl_target_option *ptr1, cl_target_option *ptr2);

/* Compare two target option variables from a structure.  */
extern bool cl_target_option_eq (const struct cl_target_option *, const struct cl_target_option *);

/* Hash option variables from a structure.  */
extern hashval_t cl_target_option_hash (const struct cl_target_option *);

/* Hash optimization from a structure.  */
extern hashval_t cl_optimization_hash (const struct cl_optimization *);

/* Generator files may not have access to location_t, and don't need these.  */
#if defined(UNKNOWN_LOCATION)
bool                                                                  
common_handle_option_auto (struct gcc_options *opts,                  
                           struct gcc_options *opts_set,              
                           const struct cl_decoded_option *decoded,   
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
Ada_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
AdaSCIL_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
AdaWhy_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
BRIG_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
C_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
CXX_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
Fortran_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
Go_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
LTO_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
ObjC_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
bool                                                                  
ObjCXX_handle_option_auto (struct gcc_options *opts,              
                           struct gcc_options *opts_set,              
                           size_t scode, const char *arg, int value,  
                           unsigned int lang_mask, int kind,          
                           location_t loc,                            
                           const struct cl_option_handlers *handlers, 
                           diagnostic_context *dc);                   
void cpp_handle_option_auto (const struct gcc_options * opts, size_t scode,
                             struct cpp_options * cpp_opts);
void init_global_opts_from_cpp(struct gcc_options * opts,      
                               const struct cpp_options * cpp_opts);
#endif
#endif

#define MASK_ABICALLS (1U << 0)
#define OPTION_MASK_ANDROID (1U << 0)
#define MASK_BRANCHLIKELY (1U << 1)
#define MASK_CHECK_ZERO_DIV (1U << 2)
#define MASK_DIVIDE_BREAKS (1U << 3)
#define MASK_SINGLE_FLOAT (1U << 4)
#define MASK_BIG_ENDIAN (1U << 5)
#define MASK_EXPLICIT_RELOCS (1U << 6)
#define MASK_FIX_R10000 (1U << 7)
#define MASK_FIX_R4000 (1U << 8)
#define MASK_FIX_R4400 (1U << 9)
#define MASK_FLOAT64 (1U << 10)
#define MASK_FLOATXX (1U << 11)
#define MASK_64BIT (1U << 12)
#define MASK_SOFT_FLOAT_ABI (1U << 13)
#define MASK_IMADD (1U << 14)
#define MASK_MIPS16 (1U << 15)
#define MASK_LLSC (1U << 16)
#define MASK_LONG64 (1U << 17)
#define MASK_MEMCPY (1U << 18)
#define MASK_MICROMIPS (1U << 19)
#define MASK_ODD_SPREG (1U << 20)
#define MASK_PAIRED_SINGLE_FLOAT (1U << 21)
#define MASK_RELAX_PIC_CALLS (1U << 22)
#define MASK_SMARTMIPS (1U << 23)
#define MASK_SPLIT_ADDRESSES (1U << 24)
#define MASK_SYNCI (1U << 25)
#define MASK_VR4130_ALIGN (1U << 26)

#define TARGET_ABICALLS ((target_flags & MASK_ABICALLS) != 0)
#define TARGET_ABICALLS_P(target_flags) (((target_flags) & MASK_ABICALLS) != 0)
#define TARGET_ANDROID ((flag_android & OPTION_MASK_ANDROID) != 0)
#define TARGET_ANDROID_P(flag_android) (((flag_android) & OPTION_MASK_ANDROID) != 0)
#define TARGET_BRANCHLIKELY ((target_flags & MASK_BRANCHLIKELY) != 0)
#define TARGET_BRANCHLIKELY_P(target_flags) (((target_flags) & MASK_BRANCHLIKELY) != 0)
#define TARGET_CHECK_ZERO_DIV ((target_flags & MASK_CHECK_ZERO_DIV) != 0)
#define TARGET_CHECK_ZERO_DIV_P(target_flags) (((target_flags) & MASK_CHECK_ZERO_DIV) != 0)
#define TARGET_DIVIDE_BREAKS ((target_flags & MASK_DIVIDE_BREAKS) != 0)
#define TARGET_DIVIDE_BREAKS_P(target_flags) (((target_flags) & MASK_DIVIDE_BREAKS) != 0)
#define TARGET_SINGLE_FLOAT ((target_flags & MASK_SINGLE_FLOAT) != 0)
#define TARGET_SINGLE_FLOAT_P(target_flags) (((target_flags) & MASK_SINGLE_FLOAT) != 0)
#define TARGET_BIG_ENDIAN ((target_flags & MASK_BIG_ENDIAN) != 0)
#define TARGET_BIG_ENDIAN_P(target_flags) (((target_flags) & MASK_BIG_ENDIAN) != 0)
#define TARGET_EXPLICIT_RELOCS ((target_flags & MASK_EXPLICIT_RELOCS) != 0)
#define TARGET_EXPLICIT_RELOCS_P(target_flags) (((target_flags) & MASK_EXPLICIT_RELOCS) != 0)
#define TARGET_FIX_R10000 ((target_flags & MASK_FIX_R10000) != 0)
#define TARGET_FIX_R10000_P(target_flags) (((target_flags) & MASK_FIX_R10000) != 0)
#define TARGET_FIX_R4000 ((target_flags & MASK_FIX_R4000) != 0)
#define TARGET_FIX_R4000_P(target_flags) (((target_flags) & MASK_FIX_R4000) != 0)
#define TARGET_FIX_R4400 ((target_flags & MASK_FIX_R4400) != 0)
#define TARGET_FIX_R4400_P(target_flags) (((target_flags) & MASK_FIX_R4400) != 0)
#define TARGET_FLOAT64 ((target_flags & MASK_FLOAT64) != 0)
#define TARGET_FLOAT64_P(target_flags) (((target_flags) & MASK_FLOAT64) != 0)
#define TARGET_FLOATXX ((target_flags & MASK_FLOATXX) != 0)
#define TARGET_FLOATXX_P(target_flags) (((target_flags) & MASK_FLOATXX) != 0)
#define TARGET_64BIT ((target_flags & MASK_64BIT) != 0)
#define TARGET_64BIT_P(target_flags) (((target_flags) & MASK_64BIT) != 0)
#define TARGET_SOFT_FLOAT_ABI ((target_flags & MASK_SOFT_FLOAT_ABI) != 0)
#define TARGET_SOFT_FLOAT_ABI_P(target_flags) (((target_flags) & MASK_SOFT_FLOAT_ABI) != 0)
#define TARGET_IMADD ((target_flags & MASK_IMADD) != 0)
#define TARGET_IMADD_P(target_flags) (((target_flags) & MASK_IMADD) != 0)
#define TARGET_MIPS16 ((target_flags & MASK_MIPS16) != 0)
#define TARGET_MIPS16_P(target_flags) (((target_flags) & MASK_MIPS16) != 0)
#define TARGET_LLSC ((target_flags & MASK_LLSC) != 0)
#define TARGET_LLSC_P(target_flags) (((target_flags) & MASK_LLSC) != 0)
#define TARGET_LONG64 ((target_flags & MASK_LONG64) != 0)
#define TARGET_LONG64_P(target_flags) (((target_flags) & MASK_LONG64) != 0)
#define TARGET_MEMCPY ((target_flags & MASK_MEMCPY) != 0)
#define TARGET_MEMCPY_P(target_flags) (((target_flags) & MASK_MEMCPY) != 0)
#define TARGET_MICROMIPS ((target_flags & MASK_MICROMIPS) != 0)
#define TARGET_MICROMIPS_P(target_flags) (((target_flags) & MASK_MICROMIPS) != 0)
#define TARGET_ODD_SPREG ((target_flags & MASK_ODD_SPREG) != 0)
#define TARGET_ODD_SPREG_P(target_flags) (((target_flags) & MASK_ODD_SPREG) != 0)
#define TARGET_PAIRED_SINGLE_FLOAT ((target_flags & MASK_PAIRED_SINGLE_FLOAT) != 0)
#define TARGET_PAIRED_SINGLE_FLOAT_P(target_flags) (((target_flags) & MASK_PAIRED_SINGLE_FLOAT) != 0)
#define TARGET_RELAX_PIC_CALLS ((target_flags & MASK_RELAX_PIC_CALLS) != 0)
#define TARGET_RELAX_PIC_CALLS_P(target_flags) (((target_flags) & MASK_RELAX_PIC_CALLS) != 0)
#define TARGET_SMARTMIPS ((target_flags & MASK_SMARTMIPS) != 0)
#define TARGET_SMARTMIPS_P(target_flags) (((target_flags) & MASK_SMARTMIPS) != 0)
#define TARGET_SPLIT_ADDRESSES ((target_flags & MASK_SPLIT_ADDRESSES) != 0)
#define TARGET_SPLIT_ADDRESSES_P(target_flags) (((target_flags) & MASK_SPLIT_ADDRESSES) != 0)
#define TARGET_SYNCI ((target_flags & MASK_SYNCI) != 0)
#define TARGET_SYNCI_P(target_flags) (((target_flags) & MASK_SYNCI) != 0)
#define TARGET_VR4130_ALIGN ((target_flags & MASK_VR4130_ALIGN) != 0)
#define TARGET_VR4130_ALIGN_P(target_flags) (((target_flags) & MASK_VR4130_ALIGN) != 0)

#define TARGET_DIVIDE_TRAPS ((target_flags & MASK_DIVIDE_BREAKS) == 0)
#define TARGET_DOUBLE_FLOAT ((target_flags & MASK_SINGLE_FLOAT) == 0)
#define TARGET_LITTLE_ENDIAN ((target_flags & MASK_BIG_ENDIAN) == 0)
#define TARGET_HARD_FLOAT_ABI ((target_flags & MASK_SOFT_FLOAT_ABI) == 0)
#define TARGET_LONG32 ((target_flags & MASK_LONG64) == 0)

#define CL_Ada        (1U << 0)
#define CL_AdaSCIL    (1U << 1)
#define CL_AdaWhy     (1U << 2)
#define CL_BRIG       (1U << 3)
#define CL_C          (1U << 4)
#define CL_CXX        (1U << 5)
#define CL_Fortran    (1U << 6)
#define CL_Go         (1U << 7)
#define CL_LTO        (1U << 8)
#define CL_ObjC       (1U << 9)
#define CL_ObjCXX     (1U << 10)
#define CL_LANG_ALL   ((1U << 11) - 1)

enum opt_code
{
  OPT____ = 0,                               /* -### */
  /* OPT__all_warnings = 1, */               /* --all-warnings */
  /* OPT__ansi = 2, */                       /* --ansi */
  /* OPT__assemble = 3, */                   /* --assemble */
  /* OPT__assert = 4, */                     /* --assert */
  /* OPT__assert_ = 5, */                    /* --assert= */
  /* OPT__comments = 6, */                   /* --comments */
  /* OPT__comments_in_macros = 7, */         /* --comments-in-macros */
  /* OPT__compile = 8, */                    /* --compile */
  /* OPT__coverage = 9, */                   /* --coverage */
  /* OPT__debug = 10, */                     /* --debug */
  /* OPT__define_macro = 11, */              /* --define-macro */
  /* OPT__define_macro_ = 12, */             /* --define-macro= */
  /* OPT__dependencies = 13, */              /* --dependencies */
  /* OPT__dump = 14, */                      /* --dump */
  /* OPT__dump_ = 15, */                     /* --dump= */
  /* OPT__dumpbase = 16, */                  /* --dumpbase */
  /* OPT__dumpdir = 17, */                   /* --dumpdir */
  /* OPT__entry = 18, */                     /* --entry */
  /* OPT__entry_ = 19, */                    /* --entry= */
  /* OPT__extra_warnings = 20, */            /* --extra-warnings */
  /* OPT__for_assembler = 21, */             /* --for-assembler */
  /* OPT__for_assembler_ = 22, */            /* --for-assembler= */
  /* OPT__for_linker = 23, */                /* --for-linker */
  /* OPT__for_linker_ = 24, */               /* --for-linker= */
  /* OPT__force_link = 25, */                /* --force-link */
  /* OPT__force_link_ = 26, */               /* --force-link= */
  OPT__help = 27,                            /* --help */
  OPT__help_ = 28,                           /* --help= */
  /* OPT__imacros = 29, */                   /* --imacros */
  /* OPT__imacros_ = 30, */                  /* --imacros= */
  /* OPT__include = 31, */                   /* --include */
  /* OPT__include_barrier = 32, */           /* --include-barrier */
  /* OPT__include_directory = 33, */         /* --include-directory */
  /* OPT__include_directory_after = 34, */   /* --include-directory-after */
  /* OPT__include_directory_after_ = 35, */  /* --include-directory-after= */
  /* OPT__include_directory_ = 36, */        /* --include-directory= */
  /* OPT__include_prefix = 37, */            /* --include-prefix */
  /* OPT__include_prefix_ = 38, */           /* --include-prefix= */
  /* OPT__include_with_prefix = 39, */       /* --include-with-prefix */
  /* OPT__include_with_prefix_after = 40, */ /* --include-with-prefix-after */
  /* OPT__include_with_prefix_after_ = 41, *//* --include-with-prefix-after= */
  /* OPT__include_with_prefix_before = 42, *//* --include-with-prefix-before */
  /* OPT__include_with_prefix_before_ = 43, *//* --include-with-prefix-before= */
  /* OPT__include_with_prefix_ = 44, */      /* --include-with-prefix= */
  /* OPT__include_ = 45, */                  /* --include= */
  /* OPT__language = 46, */                  /* --language */
  /* OPT__language_ = 47, */                 /* --language= */
  /* OPT__library_directory = 48, */         /* --library-directory */
  /* OPT__library_directory_ = 49, */        /* --library-directory= */
  /* OPT__no_canonical_prefixes = 50, */     /* --no-canonical-prefixes */
  /* OPT__no_integrated_cpp = 51, */         /* --no-integrated-cpp */
  /* OPT__no_line_commands = 52, */          /* --no-line-commands */
  /* OPT__no_standard_includes = 53, */      /* --no-standard-includes */
  /* OPT__no_standard_libraries = 54, */     /* --no-standard-libraries */
  OPT__no_sysroot_suffix = 55,               /* --no-sysroot-suffix */
  /* OPT__no_warnings = 56, */               /* --no-warnings */
  /* OPT__optimize = 57, */                  /* --optimize */
  /* OPT__output = 58, */                    /* --output */
  OPT__output_pch_ = 59,                     /* --output-pch= */
  /* OPT__output_ = 60, */                   /* --output= */
  OPT__param = 61,                           /* --param */
  /* OPT__param_ = 62, */                    /* --param= */
  /* OPT__pass_exit_codes = 63, */           /* --pass-exit-codes */
  /* OPT__pedantic = 64, */                  /* --pedantic */
  /* OPT__pedantic_errors = 65, */           /* --pedantic-errors */
  /* OPT__pie = 66, */                       /* --pie */
  /* OPT__pipe = 67, */                      /* --pipe */
  /* OPT__prefix = 68, */                    /* --prefix */
  /* OPT__prefix_ = 69, */                   /* --prefix= */
  /* OPT__preprocess = 70, */                /* --preprocess */
  /* OPT__print_file_name = 71, */           /* --print-file-name */
  /* OPT__print_file_name_ = 72, */          /* --print-file-name= */
  /* OPT__print_libgcc_file_name = 73, */    /* --print-libgcc-file-name */
  /* OPT__print_missing_file_dependencies = 74, *//* --print-missing-file-dependencies */
  /* OPT__print_multi_directory = 75, */     /* --print-multi-directory */
  /* OPT__print_multi_lib = 76, */           /* --print-multi-lib */
  /* OPT__print_multi_os_directory = 77, */  /* --print-multi-os-directory */
  /* OPT__print_multiarch = 78, */           /* --print-multiarch */
  /* OPT__print_prog_name = 79, */           /* --print-prog-name */
  /* OPT__print_prog_name_ = 80, */          /* --print-prog-name= */
  /* OPT__print_search_dirs = 81, */         /* --print-search-dirs */
  /* OPT__print_sysroot = 82, */             /* --print-sysroot */
  /* OPT__print_sysroot_headers_suffix = 83, *//* --print-sysroot-headers-suffix */
  /* OPT__profile = 84, */                   /* --profile */
  /* OPT__save_temps = 85, */                /* --save-temps */
  /* OPT__shared = 86, */                    /* --shared */
  /* OPT__specs = 87, */                     /* --specs */
  /* OPT__specs_ = 88, */                    /* --specs= */
  /* OPT__static = 89, */                    /* --static */
  /* OPT__static_pie = 90, */                /* --static-pie */
  /* OPT__symbolic = 91, */                  /* --symbolic */
  /* OPT__sysroot = 92, */                   /* --sysroot */
  OPT__sysroot_ = 93,                        /* --sysroot= */
  OPT__target_help = 94,                     /* --target-help */
  /* OPT__time = 95, */                      /* --time */
  /* OPT__trace_includes = 96, */            /* --trace-includes */
  /* OPT__traditional = 97, */               /* --traditional */
  /* OPT__traditional_cpp = 98, */           /* --traditional-cpp */
  /* OPT__trigraphs = 99, */                 /* --trigraphs */
  /* OPT__undefine_macro = 100, */           /* --undefine-macro */
  /* OPT__undefine_macro_ = 101, */          /* --undefine-macro= */
  /* OPT__user_dependencies = 102, */        /* --user-dependencies */
  /* OPT__verbose = 103, */                  /* --verbose */
  OPT__version = 104,                        /* --version */
  /* OPT__write_dependencies = 105, */       /* --write-dependencies */
  /* OPT__write_user_dependencies = 106, */  /* --write-user-dependencies */
  OPT_A = 107,                               /* -A */
  OPT_B = 108,                               /* -B */
  OPT_C = 109,                               /* -C */
  OPT_CC = 110,                              /* -CC */
  OPT_D = 111,                               /* -D */
  OPT_E = 112,                               /* -E */
  OPT_EB = 113,                              /* -EB */
  OPT_EL = 114,                              /* -EL */
  OPT_F = 115,                               /* -F */
  OPT_G = 116,                               /* -G */
  OPT_H = 117,                               /* -H */
  OPT_I = 118,                               /* -I */
  OPT_J = 119,                               /* -J */
  OPT_L = 120,                               /* -L */
  OPT_M = 121,                               /* -M */
  OPT_MD = 122,                              /* -MD */
  OPT_MF = 123,                              /* -MF */
  OPT_MG = 124,                              /* -MG */
  OPT_MM = 125,                              /* -MM */
  OPT_MMD = 126,                             /* -MMD */
  OPT_MP = 127,                              /* -MP */
  OPT_MQ = 128,                              /* -MQ */
  OPT_MT = 129,                              /* -MT */
  OPT_N = 130,                               /* -N */
  OPT_O = 131,                               /* -O */
  OPT_Ofast = 132,                           /* -Ofast */
  OPT_Og = 133,                              /* -Og */
  OPT_Os = 134,                              /* -Os */
  OPT_P = 135,                               /* -P */
  OPT_Q = 136,                               /* -Q */
  OPT_Qn = 137,                              /* -Qn */
  OPT_Qy = 138,                              /* -Qy */
  OPT_R = 139,                               /* -R */
  OPT_S = 140,                               /* -S */
  OPT_T = 141,                               /* -T */
  OPT_Tbss = 142,                            /* -Tbss */
  OPT_Tbss_ = 143,                           /* -Tbss= */
  OPT_Tdata = 144,                           /* -Tdata */
  OPT_Tdata_ = 145,                          /* -Tdata= */
  OPT_Ttext = 146,                           /* -Ttext */
  OPT_Ttext_ = 147,                          /* -Ttext= */
  OPT_U = 148,                               /* -U */
  /* OPT_W = 149, */                         /* -W */
  OPT_Wa_ = 150,                             /* -Wa, */
  OPT_Wabi = 151,                            /* -Wabi */
  OPT_Wabi_tag = 152,                        /* -Wabi-tag */
  OPT_Wabi_ = 153,                           /* -Wabi= */
  OPT_Waddress = 154,                        /* -Waddress */
  OPT_Waggregate_return = 155,               /* -Waggregate-return */
  OPT_Waggressive_loop_optimizations = 156,  /* -Waggressive-loop-optimizations */
  OPT_Waliasing = 157,                       /* -Waliasing */
  OPT_Walign_commons = 158,                  /* -Walign-commons */
  /* OPT_Waligned_new = 159, */              /* -Waligned-new */
  OPT_Waligned_new_ = 160,                   /* -Waligned-new= */
  OPT_Wall = 161,                            /* -Wall */
  OPT_Walloc_size_larger_than_ = 162,        /* -Walloc-size-larger-than= */
  OPT_Walloc_zero = 163,                     /* -Walloc-zero */
  OPT_Walloca = 164,                         /* -Walloca */
  OPT_Walloca_larger_than_ = 165,            /* -Walloca-larger-than= */
  OPT_Wampersand = 166,                      /* -Wampersand */
  OPT_Wargument_mismatch = 167,              /* -Wargument-mismatch */
  OPT_Warray_bounds = 168,                   /* -Warray-bounds */
  OPT_Warray_bounds_ = 169,                  /* -Warray-bounds= */
  OPT_Warray_temporaries = 170,              /* -Warray-temporaries */
  OPT_Wassign_intercept = 171,               /* -Wassign-intercept */
  OPT_Wattribute_alias = 172,                /* -Wattribute-alias */
  OPT_Wattributes = 173,                     /* -Wattributes */
  OPT_Wbad_function_cast = 174,              /* -Wbad-function-cast */
  OPT_Wbool_compare = 175,                   /* -Wbool-compare */
  OPT_Wbool_operation = 176,                 /* -Wbool-operation */
  OPT_Wbuiltin_declaration_mismatch = 177,   /* -Wbuiltin-declaration-mismatch */
  OPT_Wbuiltin_macro_redefined = 178,        /* -Wbuiltin-macro-redefined */
  OPT_Wc___compat = 179,                     /* -Wc++-compat */
  /* OPT_Wc__0x_compat = 180, */             /* -Wc++0x-compat */
  OPT_Wc__11_compat = 181,                   /* -Wc++11-compat */
  OPT_Wc__14_compat = 182,                   /* -Wc++14-compat */
  OPT_Wc__17_compat = 183,                   /* -Wc++17-compat */
  /* OPT_Wc__1z_compat = 184, */             /* -Wc++1z-compat */
  OPT_Wc_binding_type = 185,                 /* -Wc-binding-type */
  OPT_Wc90_c99_compat = 186,                 /* -Wc90-c99-compat */
  OPT_Wc99_c11_compat = 187,                 /* -Wc99-c11-compat */
  OPT_Wcast_align = 188,                     /* -Wcast-align */
  OPT_Wcast_align_strict = 189,              /* -Wcast-align=strict */
  OPT_Wcast_function_type = 190,             /* -Wcast-function-type */
  OPT_Wcast_qual = 191,                      /* -Wcast-qual */
  /* OPT_Wcatch_value = 192, */              /* -Wcatch-value */
  OPT_Wcatch_value_ = 193,                   /* -Wcatch-value= */
  OPT_Wchar_subscripts = 194,                /* -Wchar-subscripts */
  OPT_Wcharacter_truncation = 195,           /* -Wcharacter-truncation */
  OPT_Wchkp = 196,                           /* -Wchkp */
  OPT_Wclass_memaccess = 197,                /* -Wclass-memaccess */
  OPT_Wclobbered = 198,                      /* -Wclobbered */
  OPT_Wcomment = 199,                        /* -Wcomment */
  /* OPT_Wcomments = 200, */                 /* -Wcomments */
  OPT_Wcompare_reals = 201,                  /* -Wcompare-reals */
  OPT_Wconditionally_supported = 202,        /* -Wconditionally-supported */
  OPT_Wconversion = 203,                     /* -Wconversion */
  OPT_Wconversion_extra = 204,               /* -Wconversion-extra */
  OPT_Wconversion_null = 205,                /* -Wconversion-null */
  OPT_Wcoverage_mismatch = 206,              /* -Wcoverage-mismatch */
  OPT_Wcpp = 207,                            /* -Wcpp */
  OPT_Wctor_dtor_privacy = 208,              /* -Wctor-dtor-privacy */
  OPT_Wdangling_else = 209,                  /* -Wdangling-else */
  OPT_Wdate_time = 210,                      /* -Wdate-time */
  OPT_Wdeclaration_after_statement = 211,    /* -Wdeclaration-after-statement */
  OPT_Wdelete_incomplete = 212,              /* -Wdelete-incomplete */
  OPT_Wdelete_non_virtual_dtor = 213,        /* -Wdelete-non-virtual-dtor */
  OPT_Wdeprecated = 214,                     /* -Wdeprecated */
  OPT_Wdeprecated_declarations = 215,        /* -Wdeprecated-declarations */
  OPT_Wdesignated_init = 216,                /* -Wdesignated-init */
  OPT_Wdisabled_optimization = 217,          /* -Wdisabled-optimization */
  OPT_Wdiscarded_array_qualifiers = 218,     /* -Wdiscarded-array-qualifiers */
  OPT_Wdiscarded_qualifiers = 219,           /* -Wdiscarded-qualifiers */
  OPT_Wdiv_by_zero = 220,                    /* -Wdiv-by-zero */
  OPT_Wdo_subscript = 221,                   /* -Wdo-subscript */
  OPT_Wdouble_promotion = 222,               /* -Wdouble-promotion */
  OPT_Wduplicate_decl_specifier = 223,       /* -Wduplicate-decl-specifier */
  OPT_Wduplicated_branches = 224,            /* -Wduplicated-branches */
  OPT_Wduplicated_cond = 225,                /* -Wduplicated-cond */
  OPT_Weffc__ = 226,                         /* -Weffc++ */
  OPT_Wempty_body = 227,                     /* -Wempty-body */
  OPT_Wendif_labels = 228,                   /* -Wendif-labels */
  OPT_Wenum_compare = 229,                   /* -Wenum-compare */
  OPT_Werror = 230,                          /* -Werror */
  /* OPT_Werror_implicit_function_declaration = 231, *//* -Werror-implicit-function-declaration */
  OPT_Werror_ = 232,                         /* -Werror= */
  OPT_Wexpansion_to_defined = 233,           /* -Wexpansion-to-defined */
  OPT_Wextra = 234,                          /* -Wextra */
  OPT_Wextra_semi = 235,                     /* -Wextra-semi */
  OPT_Wfatal_errors = 236,                   /* -Wfatal-errors */
  OPT_Wfloat_conversion = 237,               /* -Wfloat-conversion */
  OPT_Wfloat_equal = 238,                    /* -Wfloat-equal */
  /* OPT_Wformat = 239, */                   /* -Wformat */
  OPT_Wformat_contains_nul = 240,            /* -Wformat-contains-nul */
  OPT_Wformat_extra_args = 241,              /* -Wformat-extra-args */
  OPT_Wformat_nonliteral = 242,              /* -Wformat-nonliteral */
  /* OPT_Wformat_overflow = 243, */          /* -Wformat-overflow */
  OPT_Wformat_overflow_ = 244,               /* -Wformat-overflow= */
  OPT_Wformat_security = 245,                /* -Wformat-security */
  OPT_Wformat_signedness = 246,              /* -Wformat-signedness */
  /* OPT_Wformat_truncation = 247, */        /* -Wformat-truncation */
  OPT_Wformat_truncation_ = 248,             /* -Wformat-truncation= */
  OPT_Wformat_y2k = 249,                     /* -Wformat-y2k */
  OPT_Wformat_zero_length = 250,             /* -Wformat-zero-length */
  OPT_Wformat_ = 251,                        /* -Wformat= */
  OPT_Wframe_address = 252,                  /* -Wframe-address */
  OPT_Wframe_larger_than_ = 253,             /* -Wframe-larger-than= */
  OPT_Wfree_nonheap_object = 254,            /* -Wfree-nonheap-object */
  OPT_Wfrontend_loop_interchange = 255,      /* -Wfrontend-loop-interchange */
  OPT_Wfunction_elimination = 256,           /* -Wfunction-elimination */
  OPT_Whsa = 257,                            /* -Whsa */
  OPT_Wif_not_aligned = 258,                 /* -Wif-not-aligned */
  OPT_Wignored_attributes = 259,             /* -Wignored-attributes */
  OPT_Wignored_qualifiers = 260,             /* -Wignored-qualifiers */
  OPT_Wimplicit = 261,                       /* -Wimplicit */
  /* OPT_Wimplicit_fallthrough = 262, */     /* -Wimplicit-fallthrough */
  OPT_Wimplicit_fallthrough_ = 263,          /* -Wimplicit-fallthrough= */
  OPT_Wimplicit_function_declaration = 264,  /* -Wimplicit-function-declaration */
  OPT_Wimplicit_int = 265,                   /* -Wimplicit-int */
  OPT_Wimplicit_interface = 266,             /* -Wimplicit-interface */
  OPT_Wimplicit_procedure = 267,             /* -Wimplicit-procedure */
  /* OPT_Wimport = 268, */                   /* -Wimport */
  OPT_Wincompatible_pointer_types = 269,     /* -Wincompatible-pointer-types */
  OPT_Winherited_variadic_ctor = 270,        /* -Winherited-variadic-ctor */
  OPT_Winit_self = 271,                      /* -Winit-self */
  OPT_Winline = 272,                         /* -Winline */
  OPT_Wint_conversion = 273,                 /* -Wint-conversion */
  OPT_Wint_in_bool_context = 274,            /* -Wint-in-bool-context */
  OPT_Wint_to_pointer_cast = 275,            /* -Wint-to-pointer-cast */
  OPT_Winteger_division = 276,               /* -Winteger-division */
  OPT_Wintrinsic_shadow = 277,               /* -Wintrinsic-shadow */
  OPT_Wintrinsics_std = 278,                 /* -Wintrinsics-std */
  OPT_Winvalid_memory_model = 279,           /* -Winvalid-memory-model */
  OPT_Winvalid_offsetof = 280,               /* -Winvalid-offsetof */
  OPT_Winvalid_pch = 281,                    /* -Winvalid-pch */
  OPT_Wjump_misses_init = 282,               /* -Wjump-misses-init */
  OPT_Wl_ = 283,                             /* -Wl, */
  /* OPT_Wlarger_than_ = 284, */             /* -Wlarger-than- */
  OPT_Wlarger_than_ = 285,                   /* -Wlarger-than= */
  OPT_Wline_truncation = 286,                /* -Wline-truncation */
  OPT_Wliteral_suffix = 287,                 /* -Wliteral-suffix */
  OPT_Wlogical_not_parentheses = 288,        /* -Wlogical-not-parentheses */
  OPT_Wlogical_op = 289,                     /* -Wlogical-op */
  OPT_Wlong_long = 290,                      /* -Wlong-long */
  OPT_Wlto_type_mismatch = 291,              /* -Wlto-type-mismatch */
  OPT_Wmain = 292,                           /* -Wmain */
  OPT_Wmaybe_uninitialized = 293,            /* -Wmaybe-uninitialized */
  OPT_Wmemset_elt_size = 294,                /* -Wmemset-elt-size */
  OPT_Wmemset_transposed_args = 295,         /* -Wmemset-transposed-args */
  OPT_Wmisleading_indentation = 296,         /* -Wmisleading-indentation */
  OPT_Wmissing_attributes = 297,             /* -Wmissing-attributes */
  OPT_Wmissing_braces = 298,                 /* -Wmissing-braces */
  OPT_Wmissing_declarations = 299,           /* -Wmissing-declarations */
  OPT_Wmissing_field_initializers = 300,     /* -Wmissing-field-initializers */
  /* OPT_Wmissing_format_attribute = 301, */ /* -Wmissing-format-attribute */
  OPT_Wmissing_include_dirs = 302,           /* -Wmissing-include-dirs */
  /* OPT_Wmissing_noreturn = 303, */         /* -Wmissing-noreturn */
  OPT_Wmissing_parameter_type = 304,         /* -Wmissing-parameter-type */
  OPT_Wmissing_prototypes = 305,             /* -Wmissing-prototypes */
  /* OPT_Wmudflap = 306, */                  /* -Wmudflap */
  OPT_Wmultichar = 307,                      /* -Wmultichar */
  OPT_Wmultiple_inheritance = 308,           /* -Wmultiple-inheritance */
  OPT_Wmultistatement_macros = 309,          /* -Wmultistatement-macros */
  OPT_Wnamespaces = 310,                     /* -Wnamespaces */
  OPT_Wnarrowing = 311,                      /* -Wnarrowing */
  OPT_Wnested_externs = 312,                 /* -Wnested-externs */
  OPT_Wnoexcept = 313,                       /* -Wnoexcept */
  OPT_Wnoexcept_type = 314,                  /* -Wnoexcept-type */
  OPT_Wnon_template_friend = 315,            /* -Wnon-template-friend */
  OPT_Wnon_virtual_dtor = 316,               /* -Wnon-virtual-dtor */
  OPT_Wnonnull = 317,                        /* -Wnonnull */
  OPT_Wnonnull_compare = 318,                /* -Wnonnull-compare */
  /* OPT_Wnormalized = 319, */               /* -Wnormalized */
  OPT_Wnormalized_ = 320,                    /* -Wnormalized= */
  OPT_Wnull_dereference = 321,               /* -Wnull-dereference */
  OPT_Wodr = 322,                            /* -Wodr */
  OPT_Wold_style_cast = 323,                 /* -Wold-style-cast */
  OPT_Wold_style_declaration = 324,          /* -Wold-style-declaration */
  OPT_Wold_style_definition = 325,           /* -Wold-style-definition */
  OPT_Wopenmp_simd = 326,                    /* -Wopenmp-simd */
  OPT_Woverflow = 327,                       /* -Woverflow */
  OPT_Woverlength_strings = 328,             /* -Woverlength-strings */
  OPT_Woverloaded_virtual = 329,             /* -Woverloaded-virtual */
  OPT_Woverride_init = 330,                  /* -Woverride-init */
  OPT_Woverride_init_side_effects = 331,     /* -Woverride-init-side-effects */
  OPT_Wp_ = 332,                             /* -Wp, */
  OPT_Wpacked = 333,                         /* -Wpacked */
  OPT_Wpacked_bitfield_compat = 334,         /* -Wpacked-bitfield-compat */
  OPT_Wpacked_not_aligned = 335,             /* -Wpacked-not-aligned */
  OPT_Wpadded = 336,                         /* -Wpadded */
  OPT_Wparentheses = 337,                    /* -Wparentheses */
  OPT_Wpedantic = 338,                       /* -Wpedantic */
  /* OPT_Wplacement_new = 339, */            /* -Wplacement-new */
  OPT_Wplacement_new_ = 340,                 /* -Wplacement-new= */
  OPT_Wpmf_conversions = 341,                /* -Wpmf-conversions */
  OPT_Wpointer_arith = 342,                  /* -Wpointer-arith */
  OPT_Wpointer_compare = 343,                /* -Wpointer-compare */
  OPT_Wpointer_sign = 344,                   /* -Wpointer-sign */
  OPT_Wpointer_to_int_cast = 345,            /* -Wpointer-to-int-cast */
  OPT_Wpragmas = 346,                        /* -Wpragmas */
  OPT_Wproperty_assign_default = 347,        /* -Wproperty-assign-default */
  OPT_Wprotocol = 348,                       /* -Wprotocol */
  OPT_Wpsabi = 349,                          /* -Wpsabi */
  OPT_Wreal_q_constant = 350,                /* -Wreal-q-constant */
  OPT_Wrealloc_lhs = 351,                    /* -Wrealloc-lhs */
  OPT_Wrealloc_lhs_all = 352,                /* -Wrealloc-lhs-all */
  OPT_Wredundant_decls = 353,                /* -Wredundant-decls */
  OPT_Wregister = 354,                       /* -Wregister */
  OPT_Wreorder = 355,                        /* -Wreorder */
  OPT_Wrestrict = 356,                       /* -Wrestrict */
  OPT_Wreturn_local_addr = 357,              /* -Wreturn-local-addr */
  OPT_Wreturn_type = 358,                    /* -Wreturn-type */
  OPT_Wscalar_storage_order = 359,           /* -Wscalar-storage-order */
  OPT_Wselector = 360,                       /* -Wselector */
  OPT_Wsequence_point = 361,                 /* -Wsequence-point */
  OPT_Wshadow = 362,                         /* -Wshadow */
  /* OPT_Wshadow_compatible_local = 363, */  /* -Wshadow-compatible-local */
  OPT_Wshadow_ivar = 364,                    /* -Wshadow-ivar */
  /* OPT_Wshadow_local = 365, */             /* -Wshadow-local */
  OPT_Wshadow_compatible_local = 366,        /* -Wshadow=compatible-local */
  /* OPT_Wshadow_global = 367, */            /* -Wshadow=global */
  OPT_Wshadow_local = 368,                   /* -Wshadow=local */
  OPT_Wshift_count_negative = 369,           /* -Wshift-count-negative */
  OPT_Wshift_count_overflow = 370,           /* -Wshift-count-overflow */
  OPT_Wshift_negative_value = 371,           /* -Wshift-negative-value */
  /* OPT_Wshift_overflow = 372, */           /* -Wshift-overflow */
  OPT_Wshift_overflow_ = 373,                /* -Wshift-overflow= */
  OPT_Wsign_compare = 374,                   /* -Wsign-compare */
  OPT_Wsign_conversion = 375,                /* -Wsign-conversion */
  OPT_Wsign_promo = 376,                     /* -Wsign-promo */
  OPT_Wsized_deallocation = 377,             /* -Wsized-deallocation */
  OPT_Wsizeof_array_argument = 378,          /* -Wsizeof-array-argument */
  OPT_Wsizeof_pointer_div = 379,             /* -Wsizeof-pointer-div */
  OPT_Wsizeof_pointer_memaccess = 380,       /* -Wsizeof-pointer-memaccess */
  OPT_Wstack_protector = 381,                /* -Wstack-protector */
  OPT_Wstack_usage_ = 382,                   /* -Wstack-usage= */
  OPT_Wstrict_aliasing = 383,                /* -Wstrict-aliasing */
  OPT_Wstrict_aliasing_ = 384,               /* -Wstrict-aliasing= */
  OPT_Wstrict_null_sentinel = 385,           /* -Wstrict-null-sentinel */
  OPT_Wstrict_overflow = 386,                /* -Wstrict-overflow */
  OPT_Wstrict_overflow_ = 387,               /* -Wstrict-overflow= */
  OPT_Wstrict_prototypes = 388,              /* -Wstrict-prototypes */
  OPT_Wstrict_selector_match = 389,          /* -Wstrict-selector-match */
  /* OPT_Wstringop_overflow = 390, */        /* -Wstringop-overflow */
  OPT_Wstringop_overflow_ = 391,             /* -Wstringop-overflow= */
  OPT_Wstringop_truncation = 392,            /* -Wstringop-truncation */
  OPT_Wsubobject_linkage = 393,              /* -Wsubobject-linkage */
  OPT_Wsuggest_attribute_cold = 394,         /* -Wsuggest-attribute=cold */
  OPT_Wsuggest_attribute_const = 395,        /* -Wsuggest-attribute=const */
  OPT_Wsuggest_attribute_format = 396,       /* -Wsuggest-attribute=format */
  OPT_Wsuggest_attribute_malloc = 397,       /* -Wsuggest-attribute=malloc */
  OPT_Wsuggest_attribute_noreturn = 398,     /* -Wsuggest-attribute=noreturn */
  OPT_Wsuggest_attribute_pure = 399,         /* -Wsuggest-attribute=pure */
  OPT_Wsuggest_final_methods = 400,          /* -Wsuggest-final-methods */
  OPT_Wsuggest_final_types = 401,            /* -Wsuggest-final-types */
  OPT_Wsuggest_override = 402,               /* -Wsuggest-override */
  OPT_Wsurprising = 403,                     /* -Wsurprising */
  OPT_Wswitch = 404,                         /* -Wswitch */
  OPT_Wswitch_bool = 405,                    /* -Wswitch-bool */
  OPT_Wswitch_default = 406,                 /* -Wswitch-default */
  OPT_Wswitch_enum = 407,                    /* -Wswitch-enum */
  OPT_Wswitch_unreachable = 408,             /* -Wswitch-unreachable */
  OPT_Wsync_nand = 409,                      /* -Wsync-nand */
  OPT_Wsynth = 410,                          /* -Wsynth */
  OPT_Wsystem_headers = 411,                 /* -Wsystem-headers */
  OPT_Wtabs = 412,                           /* -Wtabs */
  OPT_Wtarget_lifetime = 413,                /* -Wtarget-lifetime */
  OPT_Wtautological_compare = 414,           /* -Wtautological-compare */
  OPT_Wtemplates = 415,                      /* -Wtemplates */
  OPT_Wterminate = 416,                      /* -Wterminate */
  OPT_Wtraditional = 417,                    /* -Wtraditional */
  OPT_Wtraditional_conversion = 418,         /* -Wtraditional-conversion */
  OPT_Wtrampolines = 419,                    /* -Wtrampolines */
  OPT_Wtrigraphs = 420,                      /* -Wtrigraphs */
  OPT_Wtype_limits = 421,                    /* -Wtype-limits */
  OPT_Wundeclared_selector = 422,            /* -Wundeclared-selector */
  OPT_Wundef = 423,                          /* -Wundef */
  OPT_Wundefined_do_loop = 424,              /* -Wundefined-do-loop */
  OPT_Wunderflow = 425,                      /* -Wunderflow */
  OPT_Wuninitialized = 426,                  /* -Wuninitialized */
  OPT_Wunknown_pragmas = 427,                /* -Wunknown-pragmas */
  /* OPT_Wunreachable_code = 428, */         /* -Wunreachable-code */
  /* OPT_Wunsafe_loop_optimizations = 429, *//* -Wunsafe-loop-optimizations */
  OPT_Wunsuffixed_float_constants = 430,     /* -Wunsuffixed-float-constants */
  OPT_Wunused = 431,                         /* -Wunused */
  OPT_Wunused_but_set_parameter = 432,       /* -Wunused-but-set-parameter */
  OPT_Wunused_but_set_variable = 433,        /* -Wunused-but-set-variable */
  /* OPT_Wunused_const_variable = 434, */    /* -Wunused-const-variable */
  OPT_Wunused_const_variable_ = 435,         /* -Wunused-const-variable= */
  OPT_Wunused_dummy_argument = 436,          /* -Wunused-dummy-argument */
  OPT_Wunused_function = 437,                /* -Wunused-function */
  OPT_Wunused_label = 438,                   /* -Wunused-label */
  OPT_Wunused_local_typedefs = 439,          /* -Wunused-local-typedefs */
  OPT_Wunused_macros = 440,                  /* -Wunused-macros */
  OPT_Wunused_parameter = 441,               /* -Wunused-parameter */
  OPT_Wunused_result = 442,                  /* -Wunused-result */
  OPT_Wunused_value = 443,                   /* -Wunused-value */
  OPT_Wunused_variable = 444,                /* -Wunused-variable */
  OPT_Wuse_without_only = 445,               /* -Wuse-without-only */
  OPT_Wuseless_cast = 446,                   /* -Wuseless-cast */
  OPT_Wvarargs = 447,                        /* -Wvarargs */
  OPT_Wvariadic_macros = 448,                /* -Wvariadic-macros */
  OPT_Wvector_operation_performance = 449,   /* -Wvector-operation-performance */
  OPT_Wvirtual_inheritance = 450,            /* -Wvirtual-inheritance */
  OPT_Wvirtual_move_assign = 451,            /* -Wvirtual-move-assign */
  OPT_Wvla = 452,                            /* -Wvla */
  OPT_Wvla_larger_than_ = 453,               /* -Wvla-larger-than= */
  OPT_Wvolatile_register_var = 454,          /* -Wvolatile-register-var */
  OPT_Wwrite_strings = 455,                  /* -Wwrite-strings */
  OPT_Wzero_as_null_pointer_constant = 456,  /* -Wzero-as-null-pointer-constant */
  OPT_Wzerotrip = 457,                       /* -Wzerotrip */
  OPT_Xassembler = 458,                      /* -Xassembler */
  OPT_Xlinker = 459,                         /* -Xlinker */
  OPT_Xpreprocessor = 460,                   /* -Xpreprocessor */
  OPT_Z = 461,                               /* -Z */
  OPT_ansi = 462,                            /* -ansi */
  OPT_aux_info = 463,                        /* -aux-info */
  /* OPT_aux_info_ = 464, */                 /* -aux-info= */
  OPT_auxbase = 465,                         /* -auxbase */
  OPT_auxbase_strip = 466,                   /* -auxbase-strip */
  OPT_c = 467,                               /* -c */
  OPT_coverage = 468,                        /* -coverage */
  OPT_cpp = 469,                             /* -cpp */
  OPT_cpp_ = 470,                            /* -cpp= */
  OPT_d = 471,                               /* -d */
  OPT_dumpbase = 472,                        /* -dumpbase */
  OPT_dumpdir = 473,                         /* -dumpdir */
  OPT_dumpfullversion = 474,                 /* -dumpfullversion */
  OPT_dumpmachine = 475,                     /* -dumpmachine */
  OPT_dumpspecs = 476,                       /* -dumpspecs */
  OPT_dumpversion = 477,                     /* -dumpversion */
  OPT_e = 478,                               /* -e */
  OPT_export_dynamic = 479,                  /* -export-dynamic */
  OPT_fPIC = 480,                            /* -fPIC */
  OPT_fPIE = 481,                            /* -fPIE */
  OPT_fRTS_ = 482,                           /* -fRTS= */
  OPT_fabi_compat_version_ = 483,            /* -fabi-compat-version= */
  OPT_fabi_version_ = 484,                   /* -fabi-version= */
  OPT_faccess_control = 485,                 /* -faccess-control */
  OPT_fada_spec_parent_ = 486,               /* -fada-spec-parent= */
  OPT_faggressive_function_elimination = 487,/* -faggressive-function-elimination */
  OPT_faggressive_loop_optimizations = 488,  /* -faggressive-loop-optimizations */
  OPT_falign_commons = 489,                  /* -falign-commons */
  OPT_falign_functions = 490,                /* -falign-functions */
  OPT_falign_functions_ = 491,               /* -falign-functions= */
  OPT_falign_jumps = 492,                    /* -falign-jumps */
  OPT_falign_jumps_ = 493,                   /* -falign-jumps= */
  OPT_falign_labels = 494,                   /* -falign-labels */
  OPT_falign_labels_ = 495,                  /* -falign-labels= */
  OPT_falign_loops = 496,                    /* -falign-loops */
  OPT_falign_loops_ = 497,                   /* -falign-loops= */
  /* OPT_faligned_new = 498, */              /* -faligned-new */
  OPT_faligned_new_ = 499,                   /* -faligned-new= */
  OPT_fall_intrinsics = 500,                 /* -fall-intrinsics */
  /* OPT_fall_virtual = 501, */              /* -fall-virtual */
  OPT_fallow_leading_underscore = 502,       /* -fallow-leading-underscore */
  OPT_fallow_parameterless_variadic_functions = 503,/* -fallow-parameterless-variadic-functions */
  /* OPT_falt_external_templates = 504, */   /* -falt-external-templates */
  /* OPT_fargument_alias = 505, */           /* -fargument-alias */
  /* OPT_fargument_noalias = 506, */         /* -fargument-noalias */
  /* OPT_fargument_noalias_anything = 507, *//* -fargument-noalias-anything */
  /* OPT_fargument_noalias_global = 508, */  /* -fargument-noalias-global */
  OPT_fasan_shadow_offset_ = 509,            /* -fasan-shadow-offset= */
  OPT_fasm = 510,                            /* -fasm */
  OPT_fassociative_math = 511,               /* -fassociative-math */
  OPT_fasynchronous_unwind_tables = 512,     /* -fasynchronous-unwind-tables */
  OPT_fauto_inc_dec = 513,                   /* -fauto-inc-dec */
  OPT_fauto_profile = 514,                   /* -fauto-profile */
  OPT_fauto_profile_ = 515,                  /* -fauto-profile= */
  OPT_fautomatic = 516,                      /* -fautomatic */
  OPT_fbackslash = 517,                      /* -fbackslash */
  OPT_fbacktrace = 518,                      /* -fbacktrace */
  OPT_fblas_matmul_limit_ = 519,             /* -fblas-matmul-limit= */
  OPT_fbounds_check = 520,                   /* -fbounds-check */
  OPT_fbranch_count_reg = 521,               /* -fbranch-count-reg */
  OPT_fbranch_probabilities = 522,           /* -fbranch-probabilities */
  OPT_fbranch_target_load_optimize = 523,    /* -fbranch-target-load-optimize */
  OPT_fbranch_target_load_optimize2 = 524,   /* -fbranch-target-load-optimize2 */
  OPT_fbtr_bb_exclusive = 525,               /* -fbtr-bb-exclusive */
  OPT_fbuilding_libgcc = 526,                /* -fbuilding-libgcc */
  OPT_fbuiltin = 527,                        /* -fbuiltin */
  OPT_fbuiltin_ = 528,                       /* -fbuiltin- */
  OPT_fbuiltin_printf = 529,                 /* -fbuiltin-printf */
  OPT_fc_prototypes = 530,                   /* -fc-prototypes */
  OPT_fcall_saved_ = 531,                    /* -fcall-saved- */
  OPT_fcall_used_ = 532,                     /* -fcall-used- */
  OPT_fcaller_saves = 533,                   /* -fcaller-saves */
  OPT_fcanonical_system_headers = 534,       /* -fcanonical-system-headers */
  /* OPT_fcf_protection = 535, */            /* -fcf-protection */
  OPT_fcf_protection_ = 536,                 /* -fcf-protection= */
  OPT_fcheck_array_temporaries = 537,        /* -fcheck-array-temporaries */
  OPT_fcheck_data_deps = 538,                /* -fcheck-data-deps */
  OPT_fcheck_new = 539,                      /* -fcheck-new */
  OPT_fcheck_pointer_bounds = 540,           /* -fcheck-pointer-bounds */
  OPT_fcheck_ = 541,                         /* -fcheck= */
  OPT_fchecking = 542,                       /* -fchecking */
  OPT_fchecking_ = 543,                      /* -fchecking= */
  OPT_fchkp_check_incomplete_type = 544,     /* -fchkp-check-incomplete-type */
  OPT_fchkp_check_read = 545,                /* -fchkp-check-read */
  OPT_fchkp_check_write = 546,               /* -fchkp-check-write */
  OPT_fchkp_first_field_has_own_bounds = 547,/* -fchkp-first-field-has-own-bounds */
  OPT_fchkp_flexible_struct_trailing_arrays = 548,/* -fchkp-flexible-struct-trailing-arrays */
  OPT_fchkp_instrument_calls = 549,          /* -fchkp-instrument-calls */
  OPT_fchkp_instrument_marked_only = 550,    /* -fchkp-instrument-marked-only */
  OPT_fchkp_narrow_bounds = 551,             /* -fchkp-narrow-bounds */
  OPT_fchkp_narrow_to_innermost_array = 552, /* -fchkp-narrow-to-innermost-array */
  OPT_fchkp_optimize = 553,                  /* -fchkp-optimize */
  OPT_fchkp_store_bounds = 554,              /* -fchkp-store-bounds */
  OPT_fchkp_treat_zero_dynamic_size_as_infinite = 555,/* -fchkp-treat-zero-dynamic-size-as-infinite */
  OPT_fchkp_use_fast_string_functions = 556, /* -fchkp-use-fast-string-functions */
  OPT_fchkp_use_nochk_string_functions = 557,/* -fchkp-use-nochk-string-functions */
  OPT_fchkp_use_static_bounds = 558,         /* -fchkp-use-static-bounds */
  OPT_fchkp_use_static_const_bounds = 559,   /* -fchkp-use-static-const-bounds */
  OPT_fchkp_use_wrappers = 560,              /* -fchkp-use-wrappers */
  OPT_fchkp_zero_input_bounds_for_main = 561,/* -fchkp-zero-input-bounds-for-main */
  OPT_fcilkplus = 562,                       /* -fcilkplus */
  OPT_fcoarray_ = 563,                       /* -fcoarray= */
  OPT_fcode_hoisting = 564,                  /* -fcode-hoisting */
  OPT_fcombine_stack_adjustments = 565,      /* -fcombine-stack-adjustments */
  OPT_fcommon = 566,                         /* -fcommon */
  OPT_fcompare_debug = 567,                  /* -fcompare-debug */
  OPT_fcompare_debug_second = 568,           /* -fcompare-debug-second */
  OPT_fcompare_debug_ = 569,                 /* -fcompare-debug= */
  OPT_fcompare_elim = 570,                   /* -fcompare-elim */
  OPT_fconcepts = 571,                       /* -fconcepts */
  OPT_fcond_mismatch = 572,                  /* -fcond-mismatch */
  OPT_fconserve_space = 573,                 /* -fconserve-space */
  OPT_fconserve_stack = 574,                 /* -fconserve-stack */
  OPT_fconstant_string_class_ = 575,         /* -fconstant-string-class= */
  OPT_fconstexpr_depth_ = 576,               /* -fconstexpr-depth= */
  OPT_fconstexpr_loop_limit_ = 577,          /* -fconstexpr-loop-limit= */
  OPT_fconvert_ = 578,                       /* -fconvert= */
  OPT_fcprop_registers = 579,                /* -fcprop-registers */
  OPT_fcray_pointer = 580,                   /* -fcray-pointer */
  OPT_fcrossjumping = 581,                   /* -fcrossjumping */
  OPT_fcse_follow_jumps = 582,               /* -fcse-follow-jumps */
  /* OPT_fcse_skip_blocks = 583, */          /* -fcse-skip-blocks */
  OPT_fcx_fortran_rules = 584,               /* -fcx-fortran-rules */
  OPT_fcx_limited_range = 585,               /* -fcx-limited-range */
  OPT_fd_lines_as_code = 586,                /* -fd-lines-as-code */
  OPT_fd_lines_as_comments = 587,            /* -fd-lines-as-comments */
  OPT_fdata_sections = 588,                  /* -fdata-sections */
  OPT_fdbg_cnt_list = 589,                   /* -fdbg-cnt-list */
  OPT_fdbg_cnt_ = 590,                       /* -fdbg-cnt= */
  OPT_fdce = 591,                            /* -fdce */
  OPT_fdebug_cpp = 592,                      /* -fdebug-cpp */
  OPT_fdebug_prefix_map_ = 593,              /* -fdebug-prefix-map= */
  OPT_fdebug_types_section = 594,            /* -fdebug-types-section */
  OPT_fdec = 595,                            /* -fdec */
  OPT_fdec_intrinsic_ints = 596,             /* -fdec-intrinsic-ints */
  OPT_fdec_math = 597,                       /* -fdec-math */
  OPT_fdec_static = 598,                     /* -fdec-static */
  OPT_fdec_structure = 599,                  /* -fdec-structure */
  OPT_fdeclone_ctor_dtor = 600,              /* -fdeclone-ctor-dtor */
  OPT_fdeduce_init_list = 601,               /* -fdeduce-init-list */
  OPT_fdefault_double_8 = 602,               /* -fdefault-double-8 */
  /* OPT_fdefault_inline = 603, */           /* -fdefault-inline */
  OPT_fdefault_integer_8 = 604,              /* -fdefault-integer-8 */
  OPT_fdefault_real_10 = 605,                /* -fdefault-real-10 */
  OPT_fdefault_real_16 = 606,                /* -fdefault-real-16 */
  OPT_fdefault_real_8 = 607,                 /* -fdefault-real-8 */
  OPT_fdefer_pop = 608,                      /* -fdefer-pop */
  OPT_fdelayed_branch = 609,                 /* -fdelayed-branch */
  OPT_fdelete_dead_exceptions = 610,         /* -fdelete-dead-exceptions */
  OPT_fdelete_null_pointer_checks = 611,     /* -fdelete-null-pointer-checks */
  OPT_fdevirtualize = 612,                   /* -fdevirtualize */
  OPT_fdevirtualize_at_ltrans = 613,         /* -fdevirtualize-at-ltrans */
  OPT_fdevirtualize_speculatively = 614,     /* -fdevirtualize-speculatively */
  /* OPT_fdiagnostics_color = 615, */        /* -fdiagnostics-color */
  OPT_fdiagnostics_color_ = 616,             /* -fdiagnostics-color= */
  OPT_fdiagnostics_generate_patch = 617,     /* -fdiagnostics-generate-patch */
  OPT_fdiagnostics_parseable_fixits = 618,   /* -fdiagnostics-parseable-fixits */
  OPT_fdiagnostics_show_caret = 619,         /* -fdiagnostics-show-caret */
  OPT_fdiagnostics_show_location_ = 620,     /* -fdiagnostics-show-location= */
  OPT_fdiagnostics_show_option = 621,        /* -fdiagnostics-show-option */
  OPT_fdiagnostics_show_template_tree = 622, /* -fdiagnostics-show-template-tree */
  OPT_fdirectives_only = 623,                /* -fdirectives-only */
  OPT_fdisable_ = 624,                       /* -fdisable- */
  OPT_fdollar_ok = 625,                      /* -fdollar-ok */
  OPT_fdollars_in_identifiers = 626,         /* -fdollars-in-identifiers */
  OPT_fdse = 627,                            /* -fdse */
  OPT_fdump_ = 628,                          /* -fdump- */
  OPT_fdump_ada_spec = 629,                  /* -fdump-ada-spec */
  OPT_fdump_ada_spec_slim = 630,             /* -fdump-ada-spec-slim */
  /* OPT_fdump_core = 631, */                /* -fdump-core */
  OPT_fdump_final_insns = 632,               /* -fdump-final-insns */
  OPT_fdump_final_insns_ = 633,              /* -fdump-final-insns= */
  OPT_fdump_fortran_optimized = 634,         /* -fdump-fortran-optimized */
  OPT_fdump_fortran_original = 635,          /* -fdump-fortran-original */
  OPT_fdump_go_spec_ = 636,                  /* -fdump-go-spec= */
  OPT_fdump_internal_locations = 637,        /* -fdump-internal-locations */
  OPT_fdump_noaddr = 638,                    /* -fdump-noaddr */
  /* OPT_fdump_parse_tree = 639, */          /* -fdump-parse-tree */
  OPT_fdump_passes = 640,                    /* -fdump-passes */
  OPT_fdump_unnumbered = 641,                /* -fdump-unnumbered */
  OPT_fdump_unnumbered_links = 642,          /* -fdump-unnumbered-links */
  OPT_fdwarf2_cfi_asm = 643,                 /* -fdwarf2-cfi-asm */
  OPT_fearly_inlining = 644,                 /* -fearly-inlining */
  OPT_felide_constructors = 645,             /* -felide-constructors */
  OPT_felide_type = 646,                     /* -felide-type */
  /* OPT_feliminate_dwarf2_dups = 647, */    /* -feliminate-dwarf2-dups */
  OPT_feliminate_unused_debug_symbols = 648, /* -feliminate-unused-debug-symbols */
  OPT_feliminate_unused_debug_types = 649,   /* -feliminate-unused-debug-types */
  OPT_femit_class_debug_always = 650,        /* -femit-class-debug-always */
  OPT_femit_struct_debug_baseonly = 651,     /* -femit-struct-debug-baseonly */
  OPT_femit_struct_debug_detailed_ = 652,    /* -femit-struct-debug-detailed= */
  OPT_femit_struct_debug_reduced = 653,      /* -femit-struct-debug-reduced */
  OPT_fenable_ = 654,                        /* -fenable- */
  OPT_fenforce_eh_specs = 655,               /* -fenforce-eh-specs */
  /* OPT_fenum_int_equiv = 656, */           /* -fenum-int-equiv */
  OPT_fexceptions = 657,                     /* -fexceptions */
  OPT_fexcess_precision_ = 658,              /* -fexcess-precision= */
  OPT_fexec_charset_ = 659,                  /* -fexec-charset= */
  OPT_fexpensive_optimizations = 660,        /* -fexpensive-optimizations */
  OPT_fext_numeric_literals = 661,           /* -fext-numeric-literals */
  OPT_fextended_identifiers = 662,           /* -fextended-identifiers */
  OPT_fextern_tls_init = 663,                /* -fextern-tls-init */
  OPT_fexternal_blas = 664,                  /* -fexternal-blas */
  /* OPT_fexternal_templates = 665, */       /* -fexternal-templates */
  OPT_ff2c = 666,                            /* -ff2c */
  OPT_ffast_math = 667,                      /* -ffast-math */
  OPT_ffat_lto_objects = 668,                /* -ffat-lto-objects */
  OPT_ffile_prefix_map_ = 669,               /* -ffile-prefix-map= */
  OPT_ffinite_math_only = 670,               /* -ffinite-math-only */
  OPT_ffixed_ = 671,                         /* -ffixed- */
  OPT_ffixed_form = 672,                     /* -ffixed-form */
  OPT_ffixed_line_length_ = 673,             /* -ffixed-line-length- */
  OPT_ffixed_line_length_none = 674,         /* -ffixed-line-length-none */
  OPT_ffloat_store = 675,                    /* -ffloat-store */
  OPT_ffor_scope = 676,                      /* -ffor-scope */
  /* OPT_fforce_addr = 677, */               /* -fforce-addr */
  OPT_fforward_propagate = 678,              /* -fforward-propagate */
  OPT_ffp_contract_ = 679,                   /* -ffp-contract= */
  OPT_ffp_int_builtin_inexact = 680,         /* -ffp-int-builtin-inexact */
  OPT_ffpe_summary_ = 681,                   /* -ffpe-summary= */
  OPT_ffpe_trap_ = 682,                      /* -ffpe-trap= */
  OPT_ffree_form = 683,                      /* -ffree-form */
  OPT_ffree_line_length_ = 684,              /* -ffree-line-length- */
  OPT_ffree_line_length_none = 685,          /* -ffree-line-length-none */
  OPT_ffreestanding = 686,                   /* -ffreestanding */
  OPT_ffriend_injection = 687,               /* -ffriend-injection */
  OPT_ffrontend_loop_interchange = 688,      /* -ffrontend-loop-interchange */
  OPT_ffrontend_optimize = 689,              /* -ffrontend-optimize */
  OPT_ffunction_cse = 690,                   /* -ffunction-cse */
  OPT_ffunction_sections = 691,              /* -ffunction-sections */
  OPT_fgcse = 692,                           /* -fgcse */
  OPT_fgcse_after_reload = 693,              /* -fgcse-after-reload */
  OPT_fgcse_las = 694,                       /* -fgcse-las */
  OPT_fgcse_lm = 695,                        /* -fgcse-lm */
  OPT_fgcse_sm = 696,                        /* -fgcse-sm */
  OPT_fgimple = 697,                         /* -fgimple */
  OPT_fgnat_encodings_ = 698,                /* -fgnat-encodings= */
  OPT_fgnu_keywords = 699,                   /* -fgnu-keywords */
  OPT_fgnu_runtime = 700,                    /* -fgnu-runtime */
  OPT_fgnu_tm = 701,                         /* -fgnu-tm */
  OPT_fgnu_unique = 702,                     /* -fgnu-unique */
  OPT_fgnu89_inline = 703,                   /* -fgnu89-inline */
  OPT_fgo_c_header_ = 704,                   /* -fgo-c-header= */
  OPT_fgo_check_divide_overflow = 705,       /* -fgo-check-divide-overflow */
  OPT_fgo_check_divide_zero = 706,           /* -fgo-check-divide-zero */
  OPT_fgo_compiling_runtime = 707,           /* -fgo-compiling-runtime */
  OPT_fgo_debug_escape = 708,                /* -fgo-debug-escape */
  OPT_fgo_debug_escape_hash_ = 709,          /* -fgo-debug-escape-hash= */
  OPT_fgo_dump_ = 710,                       /* -fgo-dump- */
  OPT_fgo_optimize_ = 711,                   /* -fgo-optimize- */
  OPT_fgo_pkgpath_ = 712,                    /* -fgo-pkgpath= */
  OPT_fgo_prefix_ = 713,                     /* -fgo-prefix= */
  OPT_fgo_relative_import_path_ = 714,       /* -fgo-relative-import-path= */
  OPT_fgraphite = 715,                       /* -fgraphite */
  OPT_fgraphite_identity = 716,              /* -fgraphite-identity */
  OPT_fguess_branch_probability = 717,       /* -fguess-branch-probability */
  /* OPT_fguiding_decls = 718, */            /* -fguiding-decls */
  /* OPT_fhandle_exceptions = 719, */        /* -fhandle-exceptions */
  /* OPT_fhelp = 720, */                     /* -fhelp */
  /* OPT_fhelp_ = 721, */                    /* -fhelp= */
  OPT_fhoist_adjacent_loads = 722,           /* -fhoist-adjacent-loads */
  /* OPT_fhonor_std = 723, */                /* -fhonor-std */
  OPT_fhosted = 724,                         /* -fhosted */
  /* OPT_fhuge_objects = 725, */             /* -fhuge-objects */
  OPT_fident = 726,                          /* -fident */
  OPT_fif_conversion = 727,                  /* -fif-conversion */
  OPT_fif_conversion2 = 728,                 /* -fif-conversion2 */
  OPT_fimplement_inlines = 729,              /* -fimplement-inlines */
  OPT_fimplicit_inline_templates = 730,      /* -fimplicit-inline-templates */
  OPT_fimplicit_none = 731,                  /* -fimplicit-none */
  OPT_fimplicit_templates = 732,             /* -fimplicit-templates */
  OPT_findirect_inlining = 733,              /* -findirect-inlining */
  OPT_finhibit_size_directive = 734,         /* -finhibit-size-directive */
  OPT_finit_character_ = 735,                /* -finit-character= */
  OPT_finit_derived = 736,                   /* -finit-derived */
  OPT_finit_integer_ = 737,                  /* -finit-integer= */
  OPT_finit_local_zero = 738,                /* -finit-local-zero */
  OPT_finit_logical_ = 739,                  /* -finit-logical= */
  OPT_finit_real_ = 740,                     /* -finit-real= */
  OPT_finline = 741,                         /* -finline */
  OPT_finline_atomics = 742,                 /* -finline-atomics */
  OPT_finline_functions = 743,               /* -finline-functions */
  OPT_finline_functions_called_once = 744,   /* -finline-functions-called-once */
  /* OPT_finline_limit_ = 745, */            /* -finline-limit- */
  OPT_finline_limit_ = 746,                  /* -finline-limit= */
  OPT_finline_matmul_limit_ = 747,           /* -finline-matmul-limit= */
  OPT_finline_small_functions = 748,         /* -finline-small-functions */
  OPT_finput_charset_ = 749,                 /* -finput-charset= */
  OPT_finstrument_functions = 750,           /* -finstrument-functions */
  OPT_finstrument_functions_exclude_file_list_ = 751,/* -finstrument-functions-exclude-file-list= */
  OPT_finstrument_functions_exclude_function_list_ = 752,/* -finstrument-functions-exclude-function-list= */
  OPT_finteger_4_integer_8 = 753,            /* -finteger-4-integer-8 */
  OPT_fintrinsic_modules_path = 754,         /* -fintrinsic-modules-path */
  OPT_fintrinsic_modules_path_ = 755,        /* -fintrinsic-modules-path= */
  OPT_fipa_bit_cp = 756,                     /* -fipa-bit-cp */
  OPT_fipa_cp = 757,                         /* -fipa-cp */
  /* OPT_fipa_cp_alignment = 758, */         /* -fipa-cp-alignment */
  OPT_fipa_cp_clone = 759,                   /* -fipa-cp-clone */
  OPT_fipa_icf = 760,                        /* -fipa-icf */
  OPT_fipa_icf_functions = 761,              /* -fipa-icf-functions */
  OPT_fipa_icf_variables = 762,              /* -fipa-icf-variables */
  /* OPT_fipa_matrix_reorg = 763, */         /* -fipa-matrix-reorg */
  OPT_fipa_profile = 764,                    /* -fipa-profile */
  OPT_fipa_pta = 765,                        /* -fipa-pta */
  OPT_fipa_pure_const = 766,                 /* -fipa-pure-const */
  OPT_fipa_ra = 767,                         /* -fipa-ra */
  OPT_fipa_reference = 768,                  /* -fipa-reference */
  OPT_fipa_sra = 769,                        /* -fipa-sra */
  /* OPT_fipa_struct_reorg = 770, */         /* -fipa-struct-reorg */
  OPT_fipa_vrp = 771,                        /* -fipa-vrp */
  OPT_fira_algorithm_ = 772,                 /* -fira-algorithm= */
  OPT_fira_hoist_pressure = 773,             /* -fira-hoist-pressure */
  OPT_fira_loop_pressure = 774,              /* -fira-loop-pressure */
  OPT_fira_region_ = 775,                    /* -fira-region= */
  OPT_fira_share_save_slots = 776,           /* -fira-share-save-slots */
  OPT_fira_share_spill_slots = 777,          /* -fira-share-spill-slots */
  OPT_fira_verbose_ = 778,                   /* -fira-verbose= */
  OPT_fisolate_erroneous_paths_attribute = 779,/* -fisolate-erroneous-paths-attribute */
  OPT_fisolate_erroneous_paths_dereference = 780,/* -fisolate-erroneous-paths-dereference */
  OPT_fivar_visibility_ = 781,               /* -fivar-visibility= */
  OPT_fivopts = 782,                         /* -fivopts */
  OPT_fjump_tables = 783,                    /* -fjump-tables */
  OPT_fkeep_gc_roots_live = 784,             /* -fkeep-gc-roots-live */
  OPT_fkeep_inline_dllexport = 785,          /* -fkeep-inline-dllexport */
  OPT_fkeep_inline_functions = 786,          /* -fkeep-inline-functions */
  OPT_fkeep_static_consts = 787,             /* -fkeep-static-consts */
  OPT_fkeep_static_functions = 788,          /* -fkeep-static-functions */
  /* OPT_flabels_ok = 789, */                /* -flabels-ok */
  OPT_flax_vector_conversions = 790,         /* -flax-vector-conversions */
  OPT_fleading_underscore = 791,             /* -fleading-underscore */
  OPT_flifetime_dse = 792,                   /* -flifetime-dse */
  OPT_flifetime_dse_ = 793,                  /* -flifetime-dse= */
  OPT_flimit_function_alignment = 794,       /* -flimit-function-alignment */
  OPT_flinker_output_ = 795,                 /* -flinker-output= */
  OPT_flive_range_shrinkage = 796,           /* -flive-range-shrinkage */
  OPT_flocal_ivars = 797,                    /* -flocal-ivars */
  /* OPT_floop_block = 798, */               /* -floop-block */
  /* OPT_floop_flatten = 799, */             /* -floop-flatten */
  OPT_floop_interchange = 800,               /* -floop-interchange */
  OPT_floop_nest_optimize = 801,             /* -floop-nest-optimize */
  /* OPT_floop_optimize = 802, */            /* -floop-optimize */
  OPT_floop_parallelize_all = 803,           /* -floop-parallelize-all */
  /* OPT_floop_strip_mine = 804, */          /* -floop-strip-mine */
  OPT_floop_unroll_and_jam = 805,            /* -floop-unroll-and-jam */
  OPT_flra_remat = 806,                      /* -flra-remat */
  OPT_flto = 807,                            /* -flto */
  OPT_flto_compression_level_ = 808,         /* -flto-compression-level= */
  OPT_flto_odr_type_merging = 809,           /* -flto-odr-type-merging */
  OPT_flto_partition_ = 810,                 /* -flto-partition= */
  OPT_flto_report = 811,                     /* -flto-report */
  OPT_flto_report_wpa = 812,                 /* -flto-report-wpa */
  OPT_flto_ = 813,                           /* -flto= */
  OPT_fltrans = 814,                         /* -fltrans */
  OPT_fltrans_output_list_ = 815,            /* -fltrans-output-list= */
  OPT_fmacro_prefix_map_ = 816,              /* -fmacro-prefix-map= */
  OPT_fmath_errno = 817,                     /* -fmath-errno */
  OPT_fmax_array_constructor_ = 818,         /* -fmax-array-constructor= */
  OPT_fmax_errors_ = 819,                    /* -fmax-errors= */
  OPT_fmax_identifier_length_ = 820,         /* -fmax-identifier-length= */
  OPT_fmax_stack_var_size_ = 821,            /* -fmax-stack-var-size= */
  OPT_fmax_subrecord_length_ = 822,          /* -fmax-subrecord-length= */
  OPT_fmem_report = 823,                     /* -fmem-report */
  OPT_fmem_report_wpa = 824,                 /* -fmem-report-wpa */
  OPT_fmerge_all_constants = 825,            /* -fmerge-all-constants */
  OPT_fmerge_constants = 826,                /* -fmerge-constants */
  OPT_fmerge_debug_strings = 827,            /* -fmerge-debug-strings */
  OPT_fmessage_length_ = 828,                /* -fmessage-length= */
  OPT_fmodule_private = 829,                 /* -fmodule-private */
  OPT_fmodulo_sched = 830,                   /* -fmodulo-sched */
  OPT_fmodulo_sched_allow_regmoves = 831,    /* -fmodulo-sched-allow-regmoves */
  OPT_fmove_loop_invariants = 832,           /* -fmove-loop-invariants */
  OPT_fms_extensions = 833,                  /* -fms-extensions */
  /* OPT_fmudflap = 834, */                  /* -fmudflap */
  /* OPT_fmudflapir = 835, */                /* -fmudflapir */
  /* OPT_fmudflapth = 836, */                /* -fmudflapth */
  /* OPT_fname_mangling_version_ = 837, */   /* -fname-mangling-version- */
  /* OPT_fnew_abi = 838, */                  /* -fnew-abi */
  OPT_fnew_inheriting_ctors = 839,           /* -fnew-inheriting-ctors */
  OPT_fnew_ttp_matching = 840,               /* -fnew-ttp-matching */
  OPT_fnext_runtime = 841,                   /* -fnext-runtime */
  OPT_fnil_receivers = 842,                  /* -fnil-receivers */
  OPT_fnon_call_exceptions = 843,            /* -fnon-call-exceptions */
  OPT_fnonansi_builtins = 844,               /* -fnonansi-builtins */
  /* OPT_fnonnull_objects = 845, */          /* -fnonnull-objects */
  OPT_fnothrow_opt = 846,                    /* -fnothrow-opt */
  OPT_fobjc_abi_version_ = 847,              /* -fobjc-abi-version= */
  OPT_fobjc_call_cxx_cdtors = 848,           /* -fobjc-call-cxx-cdtors */
  OPT_fobjc_direct_dispatch = 849,           /* -fobjc-direct-dispatch */
  OPT_fobjc_exceptions = 850,                /* -fobjc-exceptions */
  OPT_fobjc_gc = 851,                        /* -fobjc-gc */
  OPT_fobjc_nilcheck = 852,                  /* -fobjc-nilcheck */
  OPT_fobjc_sjlj_exceptions = 853,           /* -fobjc-sjlj-exceptions */
  OPT_fobjc_std_objc1 = 854,                 /* -fobjc-std=objc1 */
  OPT_foffload_abi_ = 855,                   /* -foffload-abi= */
  OPT_foffload_ = 856,                       /* -foffload= */
  OPT_fomit_frame_pointer = 857,             /* -fomit-frame-pointer */
  OPT_fopenacc = 858,                        /* -fopenacc */
  OPT_fopenacc_dim_ = 859,                   /* -fopenacc-dim= */
  OPT_fopenmp = 860,                         /* -fopenmp */
  OPT_fopenmp_simd = 861,                    /* -fopenmp-simd */
  OPT_foperator_names = 862,                 /* -foperator-names */
  OPT_fopt_info = 863,                       /* -fopt-info */
  OPT_fopt_info_ = 864,                      /* -fopt-info- */
  /* OPT_foptimize_register_move = 865, */   /* -foptimize-register-move */
  OPT_foptimize_sibling_calls = 866,         /* -foptimize-sibling-calls */
  OPT_foptimize_strlen = 867,                /* -foptimize-strlen */
  /* OPT_foptional_diags = 868, */           /* -foptional-diags */
  OPT_fpack_derived = 869,                   /* -fpack-derived */
  OPT_fpack_struct = 870,                    /* -fpack-struct */
  OPT_fpack_struct_ = 871,                   /* -fpack-struct= */
  OPT_fpartial_inlining = 872,               /* -fpartial-inlining */
  OPT_fpatchable_function_entry_ = 873,      /* -fpatchable-function-entry= */
  OPT_fpcc_struct_return = 874,              /* -fpcc-struct-return */
  OPT_fpch_deps = 875,                       /* -fpch-deps */
  OPT_fpch_preprocess = 876,                 /* -fpch-preprocess */
  OPT_fpeel_loops = 877,                     /* -fpeel-loops */
  OPT_fpeephole = 878,                       /* -fpeephole */
  OPT_fpeephole2 = 879,                      /* -fpeephole2 */
  OPT_fpermissive = 880,                     /* -fpermissive */
  OPT_fpermitted_flt_eval_methods_ = 881,    /* -fpermitted-flt-eval-methods= */
  OPT_fpic = 882,                            /* -fpic */
  OPT_fpie = 883,                            /* -fpie */
  OPT_fplan9_extensions = 884,               /* -fplan9-extensions */
  OPT_fplt = 885,                            /* -fplt */
  OPT_fplugin_arg_ = 886,                    /* -fplugin-arg- */
  OPT_fplugin_ = 887,                        /* -fplugin= */
  OPT_fpost_ipa_mem_report = 888,            /* -fpost-ipa-mem-report */
  OPT_fpre_ipa_mem_report = 889,             /* -fpre-ipa-mem-report */
  OPT_fpredictive_commoning = 890,           /* -fpredictive-commoning */
  OPT_fprefetch_loop_arrays = 891,           /* -fprefetch-loop-arrays */
  OPT_fpreprocessed = 892,                   /* -fpreprocessed */
  OPT_fpretty_templates = 893,               /* -fpretty-templates */
  OPT_fprintf_return_value = 894,            /* -fprintf-return-value */
  OPT_fprofile = 895,                        /* -fprofile */
  OPT_fprofile_abs_path = 896,               /* -fprofile-abs-path */
  OPT_fprofile_arcs = 897,                   /* -fprofile-arcs */
  OPT_fprofile_correction = 898,             /* -fprofile-correction */
  OPT_fprofile_dir_ = 899,                   /* -fprofile-dir= */
  OPT_fprofile_generate = 900,               /* -fprofile-generate */
  OPT_fprofile_generate_ = 901,              /* -fprofile-generate= */
  OPT_fprofile_reorder_functions = 902,      /* -fprofile-reorder-functions */
  OPT_fprofile_report = 903,                 /* -fprofile-report */
  OPT_fprofile_update_ = 904,                /* -fprofile-update= */
  OPT_fprofile_use = 905,                    /* -fprofile-use */
  OPT_fprofile_use_ = 906,                   /* -fprofile-use= */
  OPT_fprofile_values = 907,                 /* -fprofile-values */
  OPT_fprotect_parens = 908,                 /* -fprotect-parens */
  OPT_frandom_seed = 909,                    /* -frandom-seed */
  OPT_frandom_seed_ = 910,                   /* -frandom-seed= */
  OPT_frange_check = 911,                    /* -frange-check */
  OPT_freal_4_real_10 = 912,                 /* -freal-4-real-10 */
  OPT_freal_4_real_16 = 913,                 /* -freal-4-real-16 */
  OPT_freal_4_real_8 = 914,                  /* -freal-4-real-8 */
  OPT_freal_8_real_10 = 915,                 /* -freal-8-real-10 */
  OPT_freal_8_real_16 = 916,                 /* -freal-8-real-16 */
  OPT_freal_8_real_4 = 917,                  /* -freal-8-real-4 */
  OPT_frealloc_lhs = 918,                    /* -frealloc-lhs */
  OPT_freciprocal_math = 919,                /* -freciprocal-math */
  OPT_frecord_gcc_switches = 920,            /* -frecord-gcc-switches */
  OPT_frecord_marker_4 = 921,                /* -frecord-marker=4 */
  OPT_frecord_marker_8 = 922,                /* -frecord-marker=8 */
  OPT_frecursive = 923,                      /* -frecursive */
  OPT_free = 924,                            /* -free */
  OPT_freg_struct_return = 925,              /* -freg-struct-return */
  /* OPT_fregmove = 926, */                  /* -fregmove */
  OPT_frename_registers = 927,               /* -frename-registers */
  OPT_freorder_blocks = 928,                 /* -freorder-blocks */
  OPT_freorder_blocks_algorithm_ = 929,      /* -freorder-blocks-algorithm= */
  OPT_freorder_blocks_and_partition = 930,   /* -freorder-blocks-and-partition */
  OPT_freorder_functions = 931,              /* -freorder-functions */
  OPT_frepack_arrays = 932,                  /* -frepack-arrays */
  OPT_freplace_objc_classes = 933,           /* -freplace-objc-classes */
  OPT_frepo = 934,                           /* -frepo */
  OPT_freport_bug = 935,                     /* -freport-bug */
  OPT_frequire_return_statement = 936,       /* -frequire-return-statement */
  OPT_frerun_cse_after_loop = 937,           /* -frerun-cse-after-loop */
  /* OPT_frerun_loop_opt = 938, */           /* -frerun-loop-opt */
  OPT_freschedule_modulo_scheduled_loops = 939,/* -freschedule-modulo-scheduled-loops */
  OPT_fresolution_ = 940,                    /* -fresolution= */
  OPT_frounding_math = 941,                  /* -frounding-math */
  OPT_frtti = 942,                           /* -frtti */
  OPT_fsanitize_address_use_after_scope = 943,/* -fsanitize-address-use-after-scope */
  OPT_fsanitize_coverage_ = 944,             /* -fsanitize-coverage= */
  OPT_fsanitize_recover = 945,               /* -fsanitize-recover */
  OPT_fsanitize_recover_ = 946,              /* -fsanitize-recover= */
  OPT_fsanitize_sections_ = 947,             /* -fsanitize-sections= */
  OPT_fsanitize_undefined_trap_on_error = 948,/* -fsanitize-undefined-trap-on-error */
  OPT_fsanitize_ = 949,                      /* -fsanitize= */
  OPT_fsched_critical_path_heuristic = 950,  /* -fsched-critical-path-heuristic */
  OPT_fsched_dep_count_heuristic = 951,      /* -fsched-dep-count-heuristic */
  OPT_fsched_group_heuristic = 952,          /* -fsched-group-heuristic */
  OPT_fsched_interblock = 953,               /* -fsched-interblock */
  OPT_fsched_last_insn_heuristic = 954,      /* -fsched-last-insn-heuristic */
  OPT_fsched_pressure = 955,                 /* -fsched-pressure */
  OPT_fsched_rank_heuristic = 956,           /* -fsched-rank-heuristic */
  OPT_fsched_spec = 957,                     /* -fsched-spec */
  OPT_fsched_spec_insn_heuristic = 958,      /* -fsched-spec-insn-heuristic */
  OPT_fsched_spec_load = 959,                /* -fsched-spec-load */
  OPT_fsched_spec_load_dangerous = 960,      /* -fsched-spec-load-dangerous */
  OPT_fsched_stalled_insns = 961,            /* -fsched-stalled-insns */
  OPT_fsched_stalled_insns_dep = 962,        /* -fsched-stalled-insns-dep */
  OPT_fsched_stalled_insns_dep_ = 963,       /* -fsched-stalled-insns-dep= */
  OPT_fsched_stalled_insns_ = 964,           /* -fsched-stalled-insns= */
  OPT_fsched_verbose_ = 965,                 /* -fsched-verbose= */
  OPT_fsched2_use_superblocks = 966,         /* -fsched2-use-superblocks */
  /* OPT_fsched2_use_traces = 967, */        /* -fsched2-use-traces */
  OPT_fschedule_fusion = 968,                /* -fschedule-fusion */
  OPT_fschedule_insns = 969,                 /* -fschedule-insns */
  OPT_fschedule_insns2 = 970,                /* -fschedule-insns2 */
  OPT_fsecond_underscore = 971,              /* -fsecond-underscore */
  OPT_fsection_anchors = 972,                /* -fsection-anchors */
  /* OPT_fsee = 973, */                      /* -fsee */
  OPT_fsel_sched_pipelining = 974,           /* -fsel-sched-pipelining */
  OPT_fsel_sched_pipelining_outer_loops = 975,/* -fsel-sched-pipelining-outer-loops */
  OPT_fsel_sched_reschedule_pipelined = 976, /* -fsel-sched-reschedule-pipelined */
  OPT_fselective_scheduling = 977,           /* -fselective-scheduling */
  OPT_fselective_scheduling2 = 978,          /* -fselective-scheduling2 */
  OPT_fself_test_ = 979,                     /* -fself-test= */
  OPT_fsemantic_interposition = 980,         /* -fsemantic-interposition */
  OPT_fshort_enums = 981,                    /* -fshort-enums */
  OPT_fshort_wchar = 982,                    /* -fshort-wchar */
  OPT_fshow_column = 983,                    /* -fshow-column */
  OPT_fshrink_wrap = 984,                    /* -fshrink-wrap */
  OPT_fshrink_wrap_separate = 985,           /* -fshrink-wrap-separate */
  OPT_fsign_zero = 986,                      /* -fsign-zero */
  OPT_fsignaling_nans = 987,                 /* -fsignaling-nans */
  OPT_fsigned_bitfields = 988,               /* -fsigned-bitfields */
  OPT_fsigned_char = 989,                    /* -fsigned-char */
  OPT_fsigned_zeros = 990,                   /* -fsigned-zeros */
  OPT_fsimd_cost_model_ = 991,               /* -fsimd-cost-model= */
  OPT_fsingle_precision_constant = 992,      /* -fsingle-precision-constant */
  OPT_fsized_deallocation = 993,             /* -fsized-deallocation */
  OPT_fsplit_ivs_in_unroller = 994,          /* -fsplit-ivs-in-unroller */
  OPT_fsplit_loops = 995,                    /* -fsplit-loops */
  OPT_fsplit_paths = 996,                    /* -fsplit-paths */
  OPT_fsplit_stack = 997,                    /* -fsplit-stack */
  OPT_fsplit_wide_types = 998,               /* -fsplit-wide-types */
  /* OPT_fsquangle = 999, */                 /* -fsquangle */
  OPT_fssa_backprop = 1000,                  /* -fssa-backprop */
  OPT_fssa_phiopt = 1001,                    /* -fssa-phiopt */
  OPT_fsso_struct_ = 1002,                   /* -fsso-struct= */
  OPT_fstack_arrays = 1003,                  /* -fstack-arrays */
  /* OPT_fstack_check = 1004, */             /* -fstack-check */
  OPT_fstack_check_ = 1005,                  /* -fstack-check= */
  OPT_fstack_clash_protection = 1006,        /* -fstack-clash-protection */
  OPT_fstack_limit = 1007,                   /* -fstack-limit */
  OPT_fstack_limit_register_ = 1008,         /* -fstack-limit-register= */
  OPT_fstack_limit_symbol_ = 1009,           /* -fstack-limit-symbol= */
  OPT_fstack_protector = 1010,               /* -fstack-protector */
  OPT_fstack_protector_all = 1011,           /* -fstack-protector-all */
  OPT_fstack_protector_explicit = 1012,      /* -fstack-protector-explicit */
  OPT_fstack_protector_strong = 1013,        /* -fstack-protector-strong */
  OPT_fstack_reuse_ = 1014,                  /* -fstack-reuse= */
  OPT_fstack_usage = 1015,                   /* -fstack-usage */
  OPT_fstats = 1016,                         /* -fstats */
  OPT_fstdarg_opt = 1017,                    /* -fstdarg-opt */
  OPT_fstore_merging = 1018,                 /* -fstore-merging */
  /* OPT_fstrength_reduce = 1019, */         /* -fstrength-reduce */
  OPT_fstrict_aliasing = 1020,               /* -fstrict-aliasing */
  OPT_fstrict_enums = 1021,                  /* -fstrict-enums */
  OPT_fstrict_overflow = 1022,               /* -fstrict-overflow */
  /* OPT_fstrict_prototype = 1023, */        /* -fstrict-prototype */
  OPT_fstrict_volatile_bitfields = 1024,     /* -fstrict-volatile-bitfields */
  /* OPT_fstrong_eval_order = 1025, */       /* -fstrong-eval-order */
  OPT_fstrong_eval_order_ = 1026,            /* -fstrong-eval-order= */
  OPT_fsync_libcalls = 1027,                 /* -fsync-libcalls */
  OPT_fsyntax_only = 1028,                   /* -fsyntax-only */
  OPT_ftabstop_ = 1029,                      /* -ftabstop= */
  /* OPT_ftarget_help = 1030, */             /* -ftarget-help */
  OPT_ftemplate_backtrace_limit_ = 1031,     /* -ftemplate-backtrace-limit= */
  /* OPT_ftemplate_depth_ = 1032, */         /* -ftemplate-depth- */
  OPT_ftemplate_depth_ = 1033,               /* -ftemplate-depth= */
  OPT_ftest_coverage = 1034,                 /* -ftest-coverage */
  OPT_ftest_forall_temp = 1035,              /* -ftest-forall-temp */
  /* OPT_fthis_is_variable = 1036, */        /* -fthis-is-variable */
  OPT_fthread_jumps = 1037,                  /* -fthread-jumps */
  OPT_fthreadsafe_statics = 1038,            /* -fthreadsafe-statics */
  OPT_ftime_report = 1039,                   /* -ftime-report */
  OPT_ftime_report_details = 1040,           /* -ftime-report-details */
  OPT_ftls_model_ = 1041,                    /* -ftls-model= */
  OPT_ftoplevel_reorder = 1042,              /* -ftoplevel-reorder */
  OPT_ftracer = 1043,                        /* -ftracer */
  OPT_ftrack_macro_expansion = 1044,         /* -ftrack-macro-expansion */
  OPT_ftrack_macro_expansion_ = 1045,        /* -ftrack-macro-expansion= */
  OPT_ftrampolines = 1046,                   /* -ftrampolines */
  OPT_ftrapping_math = 1047,                 /* -ftrapping-math */
  OPT_ftrapv = 1048,                         /* -ftrapv */
  OPT_ftree_bit_ccp = 1049,                  /* -ftree-bit-ccp */
  OPT_ftree_builtin_call_dce = 1050,         /* -ftree-builtin-call-dce */
  OPT_ftree_ccp = 1051,                      /* -ftree-ccp */
  OPT_ftree_ch = 1052,                       /* -ftree-ch */
  /* OPT_ftree_coalesce_inlined_vars = 1053, *//* -ftree-coalesce-inlined-vars */
  OPT_ftree_coalesce_vars = 1054,            /* -ftree-coalesce-vars */
  OPT_ftree_copy_prop = 1055,                /* -ftree-copy-prop */
  /* OPT_ftree_copyrename = 1056, */         /* -ftree-copyrename */
  OPT_ftree_cselim = 1057,                   /* -ftree-cselim */
  OPT_ftree_dce = 1058,                      /* -ftree-dce */
  OPT_ftree_dominator_opts = 1059,           /* -ftree-dominator-opts */
  OPT_ftree_dse = 1060,                      /* -ftree-dse */
  OPT_ftree_forwprop = 1061,                 /* -ftree-forwprop */
  OPT_ftree_fre = 1062,                      /* -ftree-fre */
  OPT_ftree_loop_distribute_patterns = 1063, /* -ftree-loop-distribute-patterns */
  OPT_ftree_loop_distribution = 1064,        /* -ftree-loop-distribution */
  OPT_ftree_loop_if_convert = 1065,          /* -ftree-loop-if-convert */
  /* OPT_ftree_loop_if_convert_stores = 1066, *//* -ftree-loop-if-convert-stores */
  OPT_ftree_loop_im = 1067,                  /* -ftree-loop-im */
  OPT_ftree_loop_ivcanon = 1068,             /* -ftree-loop-ivcanon */
  /* OPT_ftree_loop_linear = 1069, */        /* -ftree-loop-linear */
  OPT_ftree_loop_optimize = 1070,            /* -ftree-loop-optimize */
  OPT_ftree_loop_vectorize = 1071,           /* -ftree-loop-vectorize */
  OPT_ftree_lrs = 1072,                      /* -ftree-lrs */
  OPT_ftree_parallelize_loops_ = 1073,       /* -ftree-parallelize-loops= */
  OPT_ftree_partial_pre = 1074,              /* -ftree-partial-pre */
  OPT_ftree_phiprop = 1075,                  /* -ftree-phiprop */
  OPT_ftree_pre = 1076,                      /* -ftree-pre */
  OPT_ftree_pta = 1077,                      /* -ftree-pta */
  OPT_ftree_reassoc = 1078,                  /* -ftree-reassoc */
  /* OPT_ftree_salias = 1079, */             /* -ftree-salias */
  OPT_ftree_scev_cprop = 1080,               /* -ftree-scev-cprop */
  OPT_ftree_sink = 1081,                     /* -ftree-sink */
  OPT_ftree_slp_vectorize = 1082,            /* -ftree-slp-vectorize */
  OPT_ftree_slsr = 1083,                     /* -ftree-slsr */
  OPT_ftree_sra = 1084,                      /* -ftree-sra */
  /* OPT_ftree_store_ccp = 1085, */          /* -ftree-store-ccp */
  /* OPT_ftree_store_copy_prop = 1086, */    /* -ftree-store-copy-prop */
  OPT_ftree_switch_conversion = 1087,        /* -ftree-switch-conversion */
  OPT_ftree_tail_merge = 1088,               /* -ftree-tail-merge */
  OPT_ftree_ter = 1089,                      /* -ftree-ter */
  /* OPT_ftree_vect_loop_version = 1090, */  /* -ftree-vect-loop-version */
  OPT_ftree_vectorize = 1091,                /* -ftree-vectorize */
  /* OPT_ftree_vectorizer_verbose_ = 1092, *//* -ftree-vectorizer-verbose= */
  OPT_ftree_vrp = 1093,                      /* -ftree-vrp */
  OPT_funconstrained_commons = 1094,         /* -funconstrained-commons */
  OPT_funderscoring = 1095,                  /* -funderscoring */
  OPT_funit_at_a_time = 1096,                /* -funit-at-a-time */
  OPT_funroll_all_loops = 1097,              /* -funroll-all-loops */
  OPT_funroll_loops = 1098,                  /* -funroll-loops */
  /* OPT_funsafe_loop_optimizations = 1099, *//* -funsafe-loop-optimizations */
  OPT_funsafe_math_optimizations = 1100,     /* -funsafe-math-optimizations */
  OPT_funsigned_bitfields = 1101,            /* -funsigned-bitfields */
  OPT_funsigned_char = 1102,                 /* -funsigned-char */
  OPT_funswitch_loops = 1103,                /* -funswitch-loops */
  OPT_funwind_tables = 1104,                 /* -funwind-tables */
  OPT_fuse_cxa_atexit = 1105,                /* -fuse-cxa-atexit */
  OPT_fuse_cxa_get_exception_ptr = 1106,     /* -fuse-cxa-get-exception-ptr */
  OPT_fuse_ld_bfd = 1107,                    /* -fuse-ld=bfd */
  OPT_fuse_ld_gold = 1108,                   /* -fuse-ld=gold */
  OPT_fuse_linker_plugin = 1109,             /* -fuse-linker-plugin */
  OPT_fvar_tracking = 1110,                  /* -fvar-tracking */
  OPT_fvar_tracking_assignments = 1111,      /* -fvar-tracking-assignments */
  OPT_fvar_tracking_assignments_toggle = 1112,/* -fvar-tracking-assignments-toggle */
  OPT_fvar_tracking_uninit = 1113,           /* -fvar-tracking-uninit */
  OPT_fvariable_expansion_in_unroller = 1114,/* -fvariable-expansion-in-unroller */
  /* OPT_fvect_cost_model = 1115, */         /* -fvect-cost-model */
  OPT_fvect_cost_model_ = 1116,              /* -fvect-cost-model= */
  OPT_fverbose_asm = 1117,                   /* -fverbose-asm */
  /* OPT_fversion = 1118, */                 /* -fversion */
  OPT_fvisibility_inlines_hidden = 1119,     /* -fvisibility-inlines-hidden */
  OPT_fvisibility_ms_compat = 1120,          /* -fvisibility-ms-compat */
  OPT_fvisibility_ = 1121,                   /* -fvisibility= */
  OPT_fvpt = 1122,                           /* -fvpt */
  /* OPT_fvtable_gc = 1123, */               /* -fvtable-gc */
  /* OPT_fvtable_thunks = 1124, */           /* -fvtable-thunks */
  OPT_fvtable_verify_ = 1125,                /* -fvtable-verify= */
  OPT_fvtv_counts = 1126,                    /* -fvtv-counts */
  OPT_fvtv_debug = 1127,                     /* -fvtv-debug */
  OPT_fweak = 1128,                          /* -fweak */
  OPT_fweb = 1129,                           /* -fweb */
  /* OPT_fwhole_file = 1130, */              /* -fwhole-file */
  OPT_fwhole_program = 1131,                 /* -fwhole-program */
  OPT_fwide_exec_charset_ = 1132,            /* -fwide-exec-charset= */
  OPT_fworking_directory = 1133,             /* -fworking-directory */
  OPT_fwpa = 1134,                           /* -fwpa */
  OPT_fwpa_ = 1135,                          /* -fwpa= */
  OPT_fwrapv = 1136,                         /* -fwrapv */
  OPT_fwrapv_pointer = 1137,                 /* -fwrapv-pointer */
  /* OPT_fxref = 1138, */                    /* -fxref */
  /* OPT_fzee = 1139, */                     /* -fzee */
  OPT_fzero_initialized_in_bss = 1140,       /* -fzero-initialized-in-bss */
  OPT_fzero_link = 1141,                     /* -fzero-link */
  OPT_g = 1142,                              /* -g */
  OPT_gant = 1143,                           /* -gant */
  OPT_gas_loc_support = 1144,                /* -gas-loc-support */
  OPT_gas_locview_support = 1145,            /* -gas-locview-support */
  /* OPT_gcoff = 1146, */                    /* -gcoff */
  /* OPT_gcoff1 = 1147, */                   /* -gcoff1 */
  /* OPT_gcoff2 = 1148, */                   /* -gcoff2 */
  /* OPT_gcoff3 = 1149, */                   /* -gcoff3 */
  OPT_gcolumn_info = 1150,                   /* -gcolumn-info */
  OPT_gdwarf = 1151,                         /* -gdwarf */
  OPT_gdwarf_ = 1152,                        /* -gdwarf- */
  OPT_gen_decls = 1153,                      /* -gen-decls */
  OPT_ggdb = 1154,                           /* -ggdb */
  OPT_ggnu_pubnames = 1155,                  /* -ggnu-pubnames */
  OPT_ginline_points = 1156,                 /* -ginline-points */
  OPT_ginternal_reset_location_views = 1157, /* -ginternal-reset-location-views */
  OPT_gnat = 1158,                           /* -gnat */
  OPT_gnatO = 1159,                          /* -gnatO */
  OPT_gno_ = 1160,                           /* -gno- */
  OPT_gno_pubnames = 1161,                   /* -gno-pubnames */
  OPT_gpubnames = 1162,                      /* -gpubnames */
  OPT_grecord_gcc_switches = 1163,           /* -grecord-gcc-switches */
  OPT_gsplit_dwarf = 1164,                   /* -gsplit-dwarf */
  OPT_gstabs = 1165,                         /* -gstabs */
  OPT_gstabs_ = 1166,                        /* -gstabs+ */
  OPT_gstatement_frontiers = 1167,           /* -gstatement-frontiers */
  OPT_gstrict_dwarf = 1168,                  /* -gstrict-dwarf */
  OPT_gtoggle = 1169,                        /* -gtoggle */
  OPT_gvariable_location_views = 1170,       /* -gvariable-location-views */
  OPT_gvariable_location_views_incompat5 = 1171,/* -gvariable-location-views=incompat5 */
  OPT_gvms = 1172,                           /* -gvms */
  OPT_gxcoff = 1173,                         /* -gxcoff */
  OPT_gxcoff_ = 1174,                        /* -gxcoff+ */
  OPT_gz = 1175,                             /* -gz */
  OPT_gz_ = 1176,                            /* -gz= */
  OPT_h = 1177,                              /* -h */
  OPT_idirafter = 1178,                      /* -idirafter */
  OPT_imacros = 1179,                        /* -imacros */
  OPT_imultiarch = 1180,                     /* -imultiarch */
  OPT_imultilib = 1181,                      /* -imultilib */
  OPT_include = 1182,                        /* -include */
  OPT_iplugindir_ = 1183,                    /* -iplugindir= */
  OPT_iprefix = 1184,                        /* -iprefix */
  OPT_iquote = 1185,                         /* -iquote */
  OPT_isysroot = 1186,                       /* -isysroot */
  OPT_isystem = 1187,                        /* -isystem */
  OPT_iwithprefix = 1188,                    /* -iwithprefix */
  OPT_iwithprefixbefore = 1189,              /* -iwithprefixbefore */
  OPT_k8 = 1190,                             /* -k8 */
  OPT_l = 1191,                              /* -l */
  OPT_lang_asm = 1192,                       /* -lang-asm */
  OPT_mabi_ = 1193,                          /* -mabi= */
  OPT_mabicalls = 1194,                      /* -mabicalls */
  OPT_mabs_ = 1195,                          /* -mabs= */
  OPT_mandroid = 1196,                       /* -mandroid */
  OPT_march_ = 1197,                         /* -march= */
  OPT_mbionic = 1198,                        /* -mbionic */
  OPT_mbranch_cost_ = 1199,                  /* -mbranch-cost= */
  OPT_mbranch_likely = 1200,                 /* -mbranch-likely */
  OPT_mcheck_zero_division = 1201,           /* -mcheck-zero-division */
  OPT_mcode_readable_ = 1202,                /* -mcode-readable= */
  OPT_mcompact_branches_ = 1203,             /* -mcompact-branches= */
  OPT_mdebug = 1204,                         /* -mdebug */
  OPT_mdebugd = 1205,                        /* -mdebugd */
  OPT_mdivide_breaks = 1206,                 /* -mdivide-breaks */
  OPT_mdivide_traps = 1207,                  /* -mdivide-traps */
  OPT_mdmx = 1208,                           /* -mdmx */
  OPT_mdouble_float = 1209,                  /* -mdouble-float */
  OPT_mdsp = 1210,                           /* -mdsp */
  OPT_mdspr2 = 1211,                         /* -mdspr2 */
  OPT_meb = 1212,                            /* -meb */
  OPT_mel = 1213,                            /* -mel */
  OPT_membedded_data = 1214,                 /* -membedded-data */
  OPT_meva = 1215,                           /* -meva */
  OPT_mexplicit_relocs = 1216,               /* -mexplicit-relocs */
  OPT_mextern_sdata = 1217,                  /* -mextern-sdata */
  OPT_mfix_24k = 1218,                       /* -mfix-24k */
  OPT_mfix_r10000 = 1219,                    /* -mfix-r10000 */
  OPT_mfix_r4000 = 1220,                     /* -mfix-r4000 */
  OPT_mfix_r4400 = 1221,                     /* -mfix-r4400 */
  OPT_mfix_rm7000 = 1222,                    /* -mfix-rm7000 */
  OPT_mfix_sb1 = 1223,                       /* -mfix-sb1 */
  OPT_mfix_vr4120 = 1224,                    /* -mfix-vr4120 */
  OPT_mfix_vr4130 = 1225,                    /* -mfix-vr4130 */
  OPT_mfix4300 = 1226,                       /* -mfix4300 */
  OPT_mflip_mips16 = 1227,                   /* -mflip-mips16 */
  OPT_mflush_func_ = 1228,                   /* -mflush-func= */
  OPT_mfp_exceptions = 1229,                 /* -mfp-exceptions */
  OPT_mfp32 = 1230,                          /* -mfp32 */
  OPT_mfp64 = 1231,                          /* -mfp64 */
  OPT_mfpxx = 1232,                          /* -mfpxx */
  OPT_mframe_header_opt = 1233,              /* -mframe-header-opt */
  /* OPT_mfused_madd = 1234, */              /* -mfused-madd */
  OPT_mglibc = 1235,                         /* -mglibc */
  OPT_mgp32 = 1236,                          /* -mgp32 */
  OPT_mgp64 = 1237,                          /* -mgp64 */
  OPT_mgpopt = 1238,                         /* -mgpopt */
  OPT_mhard_float = 1239,                    /* -mhard-float */
  OPT_mimadd = 1240,                         /* -mimadd */
  OPT_minterlink_compressed = 1241,          /* -minterlink-compressed */
  OPT_minterlink_mips16 = 1242,              /* -minterlink-mips16 */
  OPT_mips = 1243,                           /* -mips */
  OPT_mips16 = 1244,                         /* -mips16 */
  OPT_mips3d = 1245,                         /* -mips3d */
  OPT_mllsc = 1246,                          /* -mllsc */
  OPT_mload_store_pairs = 1247,              /* -mload-store-pairs */
  OPT_mlocal_sdata = 1248,                   /* -mlocal-sdata */
  OPT_mlong_calls = 1249,                    /* -mlong-calls */
  OPT_mlong32 = 1250,                        /* -mlong32 */
  OPT_mlong64 = 1251,                        /* -mlong64 */
  OPT_mlra = 1252,                           /* -mlra */
  OPT_mlxc1_sxc1 = 1253,                     /* -mlxc1-sxc1 */
  OPT_mmad = 1254,                           /* -mmad */
  OPT_mmadd4 = 1255,                         /* -mmadd4 */
  OPT_mmcount_ra_address = 1256,             /* -mmcount-ra-address */
  OPT_mmcu = 1257,                           /* -mmcu */
  OPT_mmemcpy = 1258,                        /* -mmemcpy */
  OPT_mmicromips = 1259,                     /* -mmicromips */
  OPT_mmsa = 1260,                           /* -mmsa */
  OPT_mmt = 1261,                            /* -mmt */
  OPT_mmusl = 1262,                          /* -mmusl */
  OPT_mnan_ = 1263,                          /* -mnan= */
  OPT_mno_float = 1264,                      /* -mno-float */
  OPT_mno_flush_func = 1265,                 /* -mno-flush-func */
  OPT_mno_mdmx = 1266,                       /* -mno-mdmx */
  OPT_mno_mips16 = 1267,                     /* -mno-mips16 */
  OPT_mno_mips3d = 1268,                     /* -mno-mips3d */
  OPT_modd_spreg = 1269,                     /* -modd-spreg */
  OPT_mpaired_single = 1270,                 /* -mpaired-single */
  OPT_mplt = 1271,                           /* -mplt */
  OPT_mr10k_cache_barrier_ = 1272,           /* -mr10k-cache-barrier= */
  OPT_mrelax_pic_calls = 1273,               /* -mrelax-pic-calls */
  OPT_mshared = 1274,                        /* -mshared */
  OPT_msingle_float = 1275,                  /* -msingle-float */
  OPT_msmartmips = 1276,                     /* -msmartmips */
  OPT_msoft_float = 1277,                    /* -msoft-float */
  OPT_msplit_addresses = 1278,               /* -msplit-addresses */
  OPT_msym32 = 1279,                         /* -msym32 */
  OPT_msynci = 1280,                         /* -msynci */
  OPT_mtune_ = 1281,                         /* -mtune= */
  OPT_muclibc = 1282,                        /* -muclibc */
  OPT_muninit_const_in_rodata = 1283,        /* -muninit-const-in-rodata */
  OPT_mvirt = 1284,                          /* -mvirt */
  OPT_mvr4130_align = 1285,                  /* -mvr4130-align */
  OPT_mxgot = 1286,                          /* -mxgot */
  OPT_mxpa = 1287,                           /* -mxpa */
  OPT_n = 1288,                              /* -n */
  OPT_no_canonical_prefixes = 1289,          /* -no-canonical-prefixes */
  OPT_no_integrated_cpp = 1290,              /* -no-integrated-cpp */
  OPT_no_pie = 1291,                         /* -no-pie */
  OPT_noasmopt = 1292,                       /* -noasmopt */
  OPT_nocpp = 1293,                          /* -nocpp */
  OPT_nodefaultlibs = 1294,                  /* -nodefaultlibs */
  OPT_nostartfiles = 1295,                   /* -nostartfiles */
  OPT_nostdinc = 1296,                       /* -nostdinc */
  OPT_nostdinc__ = 1297,                     /* -nostdinc++ */
  OPT_nostdlib = 1298,                       /* -nostdlib */
  OPT_o = 1299,                              /* -o */
  OPT_p = 1300,                              /* -p */
  OPT_pass_exit_codes = 1301,                /* -pass-exit-codes */
  /* OPT_pedantic = 1302, */                 /* -pedantic */
  OPT_pedantic_errors = 1303,                /* -pedantic-errors */
  OPT_pg = 1304,                             /* -pg */
  OPT_pie = 1305,                            /* -pie */
  OPT_pipe = 1306,                           /* -pipe */
  OPT_posix = 1307,                          /* -posix */
  OPT_print_file_name_ = 1308,               /* -print-file-name= */
  OPT_print_libgcc_file_name = 1309,         /* -print-libgcc-file-name */
  OPT_print_multi_directory = 1310,          /* -print-multi-directory */
  OPT_print_multi_lib = 1311,                /* -print-multi-lib */
  OPT_print_multi_os_directory = 1312,       /* -print-multi-os-directory */
  OPT_print_multiarch = 1313,                /* -print-multiarch */
  OPT_print_objc_runtime_info = 1314,        /* -print-objc-runtime-info */
  OPT_print_prog_name_ = 1315,               /* -print-prog-name= */
  OPT_print_search_dirs = 1316,              /* -print-search-dirs */
  OPT_print_sysroot = 1317,                  /* -print-sysroot */
  OPT_print_sysroot_headers_suffix = 1318,   /* -print-sysroot-headers-suffix */
  OPT_profile = 1319,                        /* -profile */
  OPT_pthread = 1320,                        /* -pthread */
  OPT_quiet = 1321,                          /* -quiet */
  OPT_r = 1322,                              /* -r */
  OPT_rdynamic = 1323,                       /* -rdynamic */
  OPT_remap = 1324,                          /* -remap */
  OPT_s = 1325,                              /* -s */
  OPT_save_temps = 1326,                     /* -save-temps */
  OPT_save_temps_ = 1327,                    /* -save-temps= */
  OPT_shared = 1328,                         /* -shared */
  OPT_shared_libgcc = 1329,                  /* -shared-libgcc */
  /* OPT_specs = 1330, */                    /* -specs */
  OPT_specs_ = 1331,                         /* -specs= */
  OPT_static = 1332,                         /* -static */
  OPT_static_libasan = 1333,                 /* -static-libasan */
  OPT_static_libgcc = 1334,                  /* -static-libgcc */
  OPT_static_libgfortran = 1335,             /* -static-libgfortran */
  OPT_static_libgo = 1336,                   /* -static-libgo */
  OPT_static_liblsan = 1337,                 /* -static-liblsan */
  OPT_static_libmpx = 1338,                  /* -static-libmpx */
  OPT_static_libmpxwrappers = 1339,          /* -static-libmpxwrappers */
  OPT_static_libstdc__ = 1340,               /* -static-libstdc++ */
  OPT_static_libtsan = 1341,                 /* -static-libtsan */
  OPT_static_libubsan = 1342,                /* -static-libubsan */
  OPT_static_pie = 1343,                     /* -static-pie */
  /* OPT_std_c__03 = 1344, */                /* -std=c++03 */
  /* OPT_std_c__0x = 1345, */                /* -std=c++0x */
  OPT_std_c__11 = 1346,                      /* -std=c++11 */
  OPT_std_c__14 = 1347,                      /* -std=c++14 */
  OPT_std_c__17 = 1348,                      /* -std=c++17 */
  /* OPT_std_c__1y = 1349, */                /* -std=c++1y */
  /* OPT_std_c__1z = 1350, */                /* -std=c++1z */
  OPT_std_c__2a = 1351,                      /* -std=c++2a */
  OPT_std_c__98 = 1352,                      /* -std=c++98 */
  OPT_std_c11 = 1353,                        /* -std=c11 */
  OPT_std_c17 = 1354,                        /* -std=c17 */
  /* OPT_std_c18 = 1355, */                  /* -std=c18 */
  /* OPT_std_c1x = 1356, */                  /* -std=c1x */
  /* OPT_std_c89 = 1357, */                  /* -std=c89 */
  OPT_std_c90 = 1358,                        /* -std=c90 */
  OPT_std_c99 = 1359,                        /* -std=c99 */
  /* OPT_std_c9x = 1360, */                  /* -std=c9x */
  OPT_std_f2003 = 1361,                      /* -std=f2003 */
  OPT_std_f2008 = 1362,                      /* -std=f2008 */
  OPT_std_f2008ts = 1363,                    /* -std=f2008ts */
  OPT_std_f2018 = 1364,                      /* -std=f2018 */
  OPT_std_f95 = 1365,                        /* -std=f95 */
  OPT_std_gnu = 1366,                        /* -std=gnu */
  /* OPT_std_gnu__03 = 1367, */              /* -std=gnu++03 */
  /* OPT_std_gnu__0x = 1368, */              /* -std=gnu++0x */
  OPT_std_gnu__11 = 1369,                    /* -std=gnu++11 */
  OPT_std_gnu__14 = 1370,                    /* -std=gnu++14 */
  OPT_std_gnu__17 = 1371,                    /* -std=gnu++17 */
  /* OPT_std_gnu__1y = 1372, */              /* -std=gnu++1y */
  /* OPT_std_gnu__1z = 1373, */              /* -std=gnu++1z */
  OPT_std_gnu__2a = 1374,                    /* -std=gnu++2a */
  OPT_std_gnu__98 = 1375,                    /* -std=gnu++98 */
  OPT_std_gnu11 = 1376,                      /* -std=gnu11 */
  OPT_std_gnu17 = 1377,                      /* -std=gnu17 */
  /* OPT_std_gnu18 = 1378, */                /* -std=gnu18 */
  /* OPT_std_gnu1x = 1379, */                /* -std=gnu1x */
  /* OPT_std_gnu89 = 1380, */                /* -std=gnu89 */
  OPT_std_gnu90 = 1381,                      /* -std=gnu90 */
  OPT_std_gnu99 = 1382,                      /* -std=gnu99 */
  /* OPT_std_gnu9x = 1383, */                /* -std=gnu9x */
  /* OPT_std_iso9899_1990 = 1384, */         /* -std=iso9899:1990 */
  OPT_std_iso9899_199409 = 1385,             /* -std=iso9899:199409 */
  /* OPT_std_iso9899_1999 = 1386, */         /* -std=iso9899:1999 */
  /* OPT_std_iso9899_199x = 1387, */         /* -std=iso9899:199x */
  /* OPT_std_iso9899_2011 = 1388, */         /* -std=iso9899:2011 */
  /* OPT_std_iso9899_2017 = 1389, */         /* -std=iso9899:2017 */
  /* OPT_std_iso9899_2018 = 1390, */         /* -std=iso9899:2018 */
  OPT_std_legacy = 1391,                     /* -std=legacy */
  OPT_symbolic = 1392,                       /* -symbolic */
  OPT_t = 1393,                              /* -t */
  OPT_time = 1394,                           /* -time */
  OPT_time_ = 1395,                          /* -time= */
  OPT_tno_android_cc = 1396,                 /* -tno-android-cc */
  OPT_tno_android_ld = 1397,                 /* -tno-android-ld */
  OPT_traditional = 1398,                    /* -traditional */
  OPT_traditional_cpp = 1399,                /* -traditional-cpp */
  OPT_trigraphs = 1400,                      /* -trigraphs */
  OPT_u = 1401,                              /* -u */
  OPT_undef = 1402,                          /* -undef */
  OPT_v = 1403,                              /* -v */
  OPT_version = 1404,                        /* -version */
  OPT_w = 1405,                              /* -w */
  OPT_wrapper = 1406,                        /* -wrapper */
  OPT_x = 1407,                              /* -x */
  OPT_z = 1408,                              /* -z */
  N_OPTS,
  OPT_SPECIAL_unknown,
  OPT_SPECIAL_ignore,
  OPT_SPECIAL_program_name,
  OPT_SPECIAL_input_file
};

#ifdef GCC_C_COMMON_C
/* Mapping from cpp message reasons to the options that enable them.  */
#include <cpplib.h>
struct cpp_reason_option_codes_t
{
  const int reason;		/* cpplib message reason.  */
  const int option_code;	/* gcc option that controls this message.  */
};

static const struct cpp_reason_option_codes_t cpp_reason_option_codes[] = {
  {CPP_W_BUILTIN_MACRO_REDEFINED,           OPT_Wbuiltin_macro_redefined},
  {CPP_W_CXX_OPERATOR_NAMES,                OPT_Wc___compat},
  {CPP_W_CXX11_COMPAT,                      OPT_Wc__11_compat},
  {CPP_W_C90_C99_COMPAT,                    OPT_Wc90_c99_compat},
  {CPP_W_COMMENTS,                          OPT_Wcomment},
  {CPP_W_WARNING_DIRECTIVE,                 OPT_Wcpp},
  {CPP_W_DATE_TIME,                         OPT_Wdate_time},
  {CPP_W_DEPRECATED,                        OPT_Wdeprecated},
  {CPP_W_ENDIF_LABELS,                      OPT_Wendif_labels},
  {CPP_W_EXPANSION_TO_DEFINED,              OPT_Wexpansion_to_defined},
  {CPP_W_INVALID_PCH,                       OPT_Winvalid_pch},
  {CPP_W_LITERAL_SUFFIX,                    OPT_Wliteral_suffix},
  {CPP_W_LONG_LONG,                         OPT_Wlong_long},
  {CPP_W_MISSING_INCLUDE_DIRS,              OPT_Wmissing_include_dirs},
  {CPP_W_MULTICHAR,                         OPT_Wmultichar},
  {CPP_W_NORMALIZE,                         OPT_Wnormalized_},
  {CPP_W_PEDANTIC,                          OPT_Wpedantic},
  {CPP_W_TRADITIONAL,                       OPT_Wtraditional},
  {CPP_W_TRIGRAPHS,                         OPT_Wtrigraphs},
  {CPP_W_UNDEF,                             OPT_Wundef},
  {CPP_W_UNUSED_MACROS,                     OPT_Wunused_macros},
  {CPP_W_VARIADIC_MACROS,                   OPT_Wvariadic_macros},
  {CPP_W_NONE,                              0},
};
#endif

#endif /* OPTIONS_H */
